<?php

class Poco_Merlin_Config {
	private $config = [];

	private $wizard;

	public function __construct() {
		$this->init();

		add_action('merlin_import_files', [$this, 'import_files']);
		add_action('merlin_after_all_import', [$this, 'after_import_setup'], 10, 1);
		add_filter('merlin_generate_child_functions_php', [$this, 'render_child_functions_php']);

        add_action( 'admin_post_custom_setup_data', [$this, 'custom_setup_data' ]);
        add_action('admin_enqueue_scripts', array($this, 'admin_scripts'), 10);

		//Fix Oneclick
		$this->fix_oneclick();
	}

	public function admin_scripts() {
        global $poco_version;
        wp_enqueue_script('poco-admin-script', get_template_directory_uri() . '/assets/js/admin/admin.js', array('jquery'), $poco_version, true);
    }

	private function init() {
		$this->wizard = new Merlin(
			$config = array(
				// Location / directory where Merlin WP is placed in your theme.
				'merlin_url'         => 'merlin',
				// The wp-admin page slug where Merlin WP loads.
				'parent_slug'        => 'themes.php',
				// The wp-admin parent page slug for the admin menu item.
				'capability'         => 'manage_options',
				// The capability required for this menu to be displayed to the user.
				'dev_mode'           => true,
				// Enable development mode for testing.
				'license_step'       => false,
				// EDD license activation step.
				'license_required'   => false,
				// Require the license activation step.
				'license_help_url'   => '',
				// URL for the 'license-tooltip'.
				'edd_remote_api_url' => '',
				'directory'          => 'inc/merlin',
				// EDD_Theme_Updater_Admin remote_api_url.
				'edd_item_name'      => '',
				// EDD_Theme_Updater_Admin item_name.
				'edd_theme_slug'     => '',
				// EDD_Theme_Updater_Admin item_slug.
			),
			$strings = array(
				'admin-menu'          => esc_html__('Theme Setup', 'poco'),

				/* translators: 1: Title Tag 2: Theme Name 3: Closing Title Tag */
				'title%s%s%s%s'       => esc_html__('%1$s%2$s Themes &lsaquo; Theme Setup: %3$s%4$s', 'poco'),
				'return-to-dashboard' => esc_html__('Return to the dashboard', 'poco'),
				'ignore'              => esc_html__('Disable this wizard', 'poco'),

				'btn-skip'                 => esc_html__('Skip', 'poco'),
				'btn-next'                 => esc_html__('Next', 'poco'),
				'btn-start'                => esc_html__('Start', 'poco'),
				'btn-no'                   => esc_html__('Cancel', 'poco'),
				'btn-plugins-install'      => esc_html__('Install', 'poco'),
				'btn-child-install'        => esc_html__('Install', 'poco'),
				'btn-content-install'      => esc_html__('Install', 'poco'),
				'btn-import'               => esc_html__('Import', 'poco'),
				'btn-license-activate'     => esc_html__('Activate', 'poco'),
				'btn-license-skip'         => esc_html__('Later', 'poco'),

				/* translators: Theme Name */
				'license-header%s'         => esc_html__('Activate %s', 'poco'),
				/* translators: Theme Name */
				'license-header-success%s' => esc_html__('%s is Activated', 'poco'),
				/* translators: Theme Name */
				'license%s'                => esc_html__('Enter your license key to enable remote updates and theme support.', 'poco'),
				'license-label'            => esc_html__('License key', 'poco'),
				'license-success%s'        => esc_html__('The theme is already registered, so you can go to the next step!', 'poco'),
				'license-json-success%s'   => esc_html__('Your theme is activated! Remote updates and theme support are enabled.', 'poco'),
				'license-tooltip'          => esc_html__('Need help?', 'poco'),

				/* translators: Theme Name */
				'welcome-header%s'         => esc_html__('Welcome to %s', 'poco'),
				'welcome-header-success%s' => esc_html__('Hi. Welcome back', 'poco'),
				'welcome%s'                => esc_html__('This wizard will set up your theme, install plugins, and import content. It is optional & should take only a few minutes.', 'poco'),
				'welcome-success%s'        => esc_html__('You may have already run this theme setup wizard. If you would like to proceed anyway, click on the "Start" button below.', 'poco'),

				'child-header'         => esc_html__('Install Child Theme', 'poco'),
				'child-header-success' => esc_html__('You\'re good to go!', 'poco'),
				'child'                => esc_html__('Let\'s build & activate a child theme so you may easily make theme changes.', 'poco'),
				'child-success%s'      => esc_html__('Your child theme has already been installed and is now activated, if it wasn\'t already.', 'poco'),
				'child-action-link'    => esc_html__('Learn about child themes', 'poco'),
				'child-json-success%s' => esc_html__('Awesome. Your child theme has already been installed and is now activated.', 'poco'),
				'child-json-already%s' => esc_html__('Awesome. Your child theme has been created and is now activated.', 'poco'),

				'plugins-header'         => esc_html__('Install Plugins', 'poco'),
				'plugins-header-success' => esc_html__('You\'re up to speed!', 'poco'),
				'plugins'                => esc_html__('Let\'s install some essential WordPress plugins to get your site up to speed.', 'poco'),
				'plugins-success%s'      => esc_html__('The required WordPress plugins are all installed and up to date. Press "Next" to continue the setup wizard.', 'poco'),
				'plugins-action-link'    => esc_html__('Advanced', 'poco'),

				'import-header'      => esc_html__('Import Content', 'poco'),
				'import'             => esc_html__('Let\'s import content to your website, to help you get familiar with the theme.', 'poco'),
				'import-action-link' => esc_html__('Advanced', 'poco'),

				'ready-header'      => esc_html__('All done. Have fun!', 'poco'),

				/* translators: Theme Author */
				'ready%s'           => esc_html__('Your theme has been all set up. Enjoy your new theme by %s.', 'poco'),
				'ready-action-link' => esc_html__('Extras', 'poco'),
				'ready-big-button'  => esc_html__('View your website', 'poco'),
				'ready-link-1'      => sprintf('<a href="%1$s" target="_blank">%2$s</a>', 'https://wordpress.org/support/', esc_html__('Explore WordPress', 'poco')),
				'ready-link-2'      => sprintf('<a href="%1$s" target="_blank">%2$s</a>', 'https://themebeans.com/contact/', esc_html__('Get Theme Support', 'poco')),
				'ready-link-3'      => sprintf('<a href="%1$s">%2$s</a>', admin_url('customize.php'), esc_html__('Start Customizing', 'poco')),
			)
		);

		add_action('widgets_init', [$this, 'widgets_init']);
	}

	public function import_files(){
            return array(
                array(
					'import_file_name'           => 'home 1',
					'home'                       => 'home-1',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux.json'),
							'option_name' => 'poco_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home_1.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'poco' ),
					'preview_url'                => 'https://demo2.wpopal.com/poco/home-1',
				),

                array(
					'import_file_name'           => 'home 2',
					'home'                       => 'home-2',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux.json'),
							'option_name' => 'poco_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home_2.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'poco' ),
					'preview_url'                => 'https://demo2.wpopal.com/poco/home-2',
				),

                array(
					'import_file_name'           => 'home 3',
					'home'                       => 'home-3',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux.json'),
							'option_name' => 'poco_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home_3.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'poco' ),
					'preview_url'                => 'https://demo2.wpopal.com/poco/home-3',
				),

                array(
					'import_file_name'           => 'home 4',
					'home'                       => 'home-4',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux.json'),
							'option_name' => 'poco_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home_4.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'poco' ),
					'preview_url'                => 'https://demo2.wpopal.com/poco/home-4',
				),
            );
        }

	public function after_import_setup($selected_import) {
		$selected_import = ($this->import_files())[$selected_import];
		$check_oneclick  = get_option('poco_check_oneclick', []);

		$this->set_demo_menus();
		wp_delete_post(1, true);

		// setup Home page
		$home = get_page_by_path($selected_import['home']);

		if ($home) {
			update_option('show_on_front', 'page');
			update_option('page_on_front', $home->ID);
		}

		// Setup Options
		$options = $this->get_all_options();
		// Elementor
		$active_kit_id = Elementor\Plugin::$instance->kits_manager->get_active_id();
		update_post_meta($active_kit_id, '_elementor_page_settings', $options['elementor']);

		if (!isset($check_oneclick['elementor'])) {
			$this->fixelementor();
			$check_oneclick['elementor'] = true;
		}

		$this->setup_header_footer($selected_import['home']);


		$this->license_elementor_pro();

		update_option('poco_check_oneclick', $check_oneclick);
	}

	private function fixelementorhome($slug) {
		$datas = $this->get_data_elementor();
		$home  = get_page_by_path($slug);
		update_post_meta($home->ID, '_elementor_data', wp_slash(wp_json_encode($datas[$slug])));
	}

	public function render_child_functions_php() {
		$output
			= "<?php
/**
 * Theme functions and definitions.
 */
		 
		 ";

		return $output;
	}

	public function widgets_init() {
		require_once get_parent_theme_file_path('/inc/merlin/includes/recent-post.php');
		register_widget('Poco_WP_Widget_Recent_Posts');
		if (poco_is_woocommerce_activated()) {
			require_once get_parent_theme_file_path('/inc/merlin/includes/class-wc-widget-layered-nav.php');
			register_widget('Poco_Widget_Layered_Nav');
		}
	}

	private function setup_header_footer($id) {
		$this->reset_header_footer();
		$options = ($this->get_all_header_footer())[$id];
		foreach ($options['header'] as $header_options) {
			$header = get_page_by_path($header_options['slug'], OBJECT, 'elementor_library');
			if ($header) {
				update_post_meta($header->ID, '_elementor_conditions', $header_options['conditions']);
			}
		}

		foreach ($options['footer'] as $footer_options) {
			$footer = get_page_by_path($footer_options['slug'], OBJECT, 'elementor_library');
			if ($footer) {
				update_post_meta($footer->ID, '_elementor_conditions', $footer_options['conditions']);
			}
		}

		$cache = new ElementorPro\Modules\ThemeBuilder\Classes\Conditions_Cache();
		$cache->regenerate();
	}

	private function get_all_header_footer() {
		return [
			'home-1' => [
				'header' => [
					[
						'slug'       => 'headerbuilder-1',
						'conditions' => ['include/general'],
					]
				],
				'footer' => [
					[
						'slug'       => 'footerbuilder-1',
						'conditions' => ['include/general'],
					]
				]
			],
			'home-2' => [
				'header' => [
					[
						'slug'       => 'headerbuilder-1',
						'conditions' => ['include/general'],
					]
				],
				'footer' => [
					[
						'slug'       => 'footerbuilder-2',
						'conditions' => ['include/general'],
					]
				]
			],
			'home-3' => [
				'header' => [
					[
						'slug'       => 'headerbuilder-2',
						'conditions' => ['include/general'],
					]
				],
				'footer' => [
					[
						'slug'       => 'footerbuilder-1',
						'conditions' => ['include/general'],
					]
				]
			],
			'home-4' => [
				'header' => [
					[
						'slug'       => 'headerbuilder-3',
						'conditions' => ['include/general'],
					]
				],
				'footer' => [
					[
						'slug'       => 'footerbuilder-3',
						'conditions' => ['include/general'],
					]
				]
			],
		];
	}

	private function reset_header_footer() {
		$footer_args = array(
			'post_type'      => 'elementor_library',
			'posts_per_page' => -1,
			'meta_query'     => array(
				array(
					'key'     => '_elementor_template_type',
					'compare' => 'IN',
					'value'   => ['footer', 'header']
				),
			)
		);
		$footer      = new WP_Query($footer_args);
		while ($footer->have_posts()) : $footer->the_post();
			update_post_meta(get_the_ID(), '_elementor_conditions', []);
		endwhile;
		wp_reset_postdata();
	}

	private function fixelementor() {
		$datas = $this->get_data_elementor();
		$query = new WP_Query(array(
			'post_type'      => [
				'page',
				'elementor_library',
			],
			'posts_per_page' => -1
		));
		while ($query->have_posts()): $query->the_post();
			global $post;
			$postid = get_the_ID();
			if (get_post_meta($post->ID, '_elementor_edit_mode', true) === 'builder') {
				$data = json_decode(get_post_meta($postid, '_elementor_data', true));
				if (!boolval($data)) {
					if (isset($datas[$post->post_name])) {
						update_post_meta($postid, '_elementor_data', wp_slash(wp_json_encode($datas[$post->post_name])));
					}
				}
			}
		endwhile;
		wp_reset_postdata();
	}

	private function license_elementor_pro() {
		if (defined('ELEMENTOR_PRO_VERSION')) {
			$data = [
				'success'          => true,
				'license'          => 'valid',
				'item_id'          => false,
				'item_name'        => 'Elementor Pro',
				'is_local'         => false,
				'license_limit'    => '1000',
				'site_count'       => '1000',
				'activations_left' => 1,
				'expires'          => 'lifetime',
				'customer_email'   => 'info@wpopal.com'
			];
			update_option('elementor_pro_license_key', 'Licence Hacked');
			ElementorPro\License\API::set_license_data($data, '+2 years');
		}
	}

	public function get_all_options(){
            $options = [];
            $options['elementor'] = json_decode('{"default_generic_fonts":"Sans-serif","container_width":{"unit":"px","size":"1290","sizes":[]},"viewport_md":"","viewport_lg":"","system_colors":[{"_id":"primary","title":"Primary","color":"#FFC222"},{"_id":"secondary","title":"Secondary","color":"#00A149"},{"_id":"text","title":"Body","color":"#808080"},{"_id":"accent","title":"Heading","color":"#1E1D23"}],"custom_colors":[{"_id":"1d12e908","title":"Light","color":"#999999"},{"_id":"76261577","title":"Color Border","color":"#E5E5E5"},{"_id":"74ad7d3c","title":"Saved Color #3","color":"#7A7A7A"},{"_id":"2154a27d","title":"Saved Color #4","color":"#61CE70"},{"_id":"1401abc0","title":"Saved Color #5","color":"#4054B2"},{"_id":"5bdd244e","title":"Saved Color #6","color":"#23A455"},{"_id":"48e5bc8c","title":"Saved Color #7","color":"#000"},{"_id":"26c59e90","title":"Saved Color #8","color":"#FFF"}],"system_typography":[{"_id":"primary","title":"Primary Headline","typography_typography":"custom"},{"_id":"secondary","title":"Secondary Headline","typography_typography":"custom"},{"_id":"text","title":"Body Text","typography_typography":"custom"},{"_id":"accent","title":"Accent Text","typography_typography":"custom"}],"site_name":"poco","site_description":"Just another WordPress site","page_title_selector":"h1.entry-title","activeItemIndex":1,"custom_typography":[],"__globals__":{"button_typography_typography":"","button_text_color":"globals/colors?id=accent","button_background_color":""},"button_background_color":"#FFC222","button_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"button_hover_text_color":"#FFFFFF","button_padding":{"unit":"px","top":"20","right":"45","bottom":"20","left":"45","isLinked":false},"button_typography_typography":"custom","button_typography_text_transform":"uppercase","button_typography_line_height":{"unit":"em","size":1,"sizes":[]},"button_typography_font_size":{"unit":"px","size":14,"sizes":[]},"button_hover_background_color":"#EEAC00","button_typography_font_weight":"700"}', true);

            return $options;
        }

	public function set_demo_menus() {
		$main_menu = get_term_by('name', 'Main Menu', 'nav_menu');

		set_theme_mod(
			'nav_menu_locations',
			array(
				'primary'  => $main_menu->term_id,
				'handheld' => $main_menu->term_id,
			)
		);
	}

	private function fix_oneclick() {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );

		if(!current_user_can('administrator')){
			return;
		}
		if (isset($_GET['opal-setup-data-elementor'])) {
			add_action('init', function(){
				$this->fixelementor();
			});
		}

		if (isset($_GET['opal-setup-data-hf'])) {
			add_action('init', function(){
				$home = (isset($_GET['opal-data-home']) && $_GET['opal-data-home']) ? $_GET['opal-data-home'] : 'home-1';
				$this->setup_header_footer($home);
			});
		}

		if (isset($_GET['opal-setup-data-elementor-options'])) {
			add_action('init', function(){
				$options = $this->get_all_options();
				// Elementor
				$active_kit_id = Elementor\Plugin::$instance->kits_manager->get_active_id();
				update_post_meta($active_kit_id, '_elementor_page_settings', $options['elementor']);
			});
		}
	}

    /**
     * Add options page
     */
    public function add_plugin_page() {
        // This page will be under "Settings"
            add_options_page(
            'Custom Setup Theme',
            'Custom Setup Theme',
            'manage_options',
            'custom-setup-settings',
            array( $this, 'create_admin_page' )
        );
    }

    /**
     * Options page callback
     */
    public function create_admin_page() {
        // Set class property
        $this->options = get_option('poco_options_setup');

        $header_data = $this->get_data_elementor_template('header');
        $footer_data = $this->get_data_elementor_template('footer');

        $profile = $this->get_all_header_footer();

        $homepage = [];
        foreach ($profile as $key=>$value){
            $homepage[$key] = ucfirst( str_replace('-', ' ', $key) );
        }
        ?>
        <div class="wrap">
        <h1><?php esc_html_e('Custom Setup Themes', 'poco') ?></h1>
        <form method="post" action="<?php echo admin_url('admin-post.php'); ?>">
            <table class="form-table">
                <tr>
                    <th>
                        <label><?php esc_html_e('Setup Themes', 'poco') ?></label>
                    </th>
                    <td>
                        <fieldset>
                            <ul>
                                <li>
                                    <label><?php esc_html_e('Setup Theme', 'poco') ?>:
                                        <select name="setup-theme">
                                            <option value="profile" selected>Select Profile</option>
                                             <option value="custom_theme">Custom Header and Footer</option>
                                        </select>
                                    </label>
                                </li>
                                <li class="profile setup-theme">
                                    <label><?php esc_html_e('Profile', 'poco') ?>:
                                        <select name="opal-data-home">
                                            <option value="" selected> Select Profile</option>
                                            <?php foreach ($homepage as $id => $home) { ?>
                                                <option value="<?php echo esc_attr($id); ?>">
                                                    <?php echo esc_attr($home); ?>
                                                </option>
                                            <?php } ?>
                                        </select>
                                    </label>
                                </li>
                                <li class="custom_theme setup-theme">
                                    <label><?php esc_html_e('Header', 'poco') ?>:
                                        <select name="header">
                                            <option value="" selected>Select Header</option>
                                            <?php foreach ($header_data as $id => $header) { ?>
                                                <option value="<?php echo esc_attr($id); ?>">
                                                    <?php echo esc_attr($header); ?>
                                                </option>
                                            <?php } ?>
                                        </select>
                                    </label>
                                </li>
                                <li class="custom_theme setup-theme">
                                    <label><?php esc_html_e('Footer', 'poco') ?>:
                                        <select name="footer">
                                            <option value="" selected >Select Footer</option>
                                            <?php foreach ($footer_data as $id => $footer) { ?>
                                                <option value="<?php echo esc_attr($id); ?>">
                                                    <?php echo esc_attr($footer); ?>
                                                </option>
                                            <?php } ?>
                                        </select>
                                    </label>
                                </li>
                                <li>
                                    <input type="checkbox" id="update_elementor" name="opal-setup-data-elementor" value="1">
                                    <label><?php esc_html_e('Update Elementor Content', 'poco') ?></label>
                                </li>
                                <li>
                                    <input type="checkbox" id="update_elementor" name="opal-setup-data-elementor-options" value="1">
                                    <label><?php esc_html_e('Update Elementor Options', 'poco') ?></label>
                                </li>
                            </ul>
                        </fieldset>
                    </td>
                </tr>
            </table>
            <input type="hidden" name="action" value="custom_setup_data">
            <?php submit_button(esc_html('Setup Now!')); ?>
        </form>
        <?php  if (isset($_GET['saved'])) { ?>
            <div class="updated">
                <p><?php esc_html_e('Success! Have been setup for your website', 'poco'); ?></p>
            </div>
        <?php }
    }

    private function get_data_elementor_template($type){
        $args = array(
            'post_type'      => 'elementor_library',
            'posts_per_page' => -1,
            'meta_query'     => array(
                array(
                    'key'     => '_elementor_template_type',
                    'compare' => '=',
                    'value'   => $type
                ),
            )
        );
        $data = new WP_Query($args);
        $select_data = [];
        while ($data->have_posts()): $data->the_post();
            $select_data[get_the_ID()] = get_the_title();
        endwhile;
        wp_reset_postdata();

        return $select_data;
    }

    private function reset_elementor_conditions($type) {
		$args = array(
			'post_type'      => 'elementor_library',
			'posts_per_page' => -1,
			'meta_query'     => array(
				array(
					'key'     => '_elementor_template_type',
					'compare' => '=',
					'value'   => $type
				),
			)
		);
		$query = new WP_Query($args);
		while ($query->have_posts()) : $query->the_post();
			update_post_meta(get_the_ID(), '_elementor_conditions', []);
		endwhile;
		wp_reset_postdata();
	}

    public function custom_setup_data(){
        if(isset($_POST)){

            if(isset($_POST['setup-theme'])){
                if( $_POST['setup-theme'] == 'profile'){
                    if (isset($_POST['opal-data-home']) && !empty($_POST['opal-data-home'])) {
                        $home = (isset($_POST['opal-data-home']) && $_POST['opal-data-home']) ? $_POST['opal-data-home'] : 'home-1';
                         $this->reset_elementor_conditions('header');
                         $this->reset_elementor_conditions('footer');
                        $this->setup_header_footer($home);
                    }
                }else{

                     if(isset($_POST['header']) && !empty($_POST['header'])){
                        $header = $_POST['header'];
                        $this->reset_elementor_conditions('header');
                        update_post_meta($header, '_elementor_conditions', ['include/general']);

                    }

                    if(isset($_POST['footer']) && !empty($_POST['footer'])){
                        $footer= $_POST['footer'];
                        $this->reset_elementor_conditions('footer');
                        update_post_meta($footer, '_elementor_conditions', ['include/general']);
                    }

                }

            }


            if (isset($_POST['opal-setup-data-elementor'])) {
                $this->fixelementor();
            }

            if (isset($_POST['opal-setup-data-elementor-options'])) {
                $options = $this->get_all_options();
                // Elementor
                $active_kit_id = Elementor\Plugin::$instance->kits_manager->get_active_id();
                update_post_meta($active_kit_id, '_elementor_page_settings', $options['elementor']);

                $cache = new ElementorPro\Modules\ThemeBuilder\Classes\Conditions_Cache();
                $cache->regenerate();

                Elementor\Plugin::$instance->files_manager->clear_cache();
            }



            wp_redirect(admin_url('options-general.php?page=custom-setup-settings&saved=1'));
            exit;
        }
    }


	private function get_data_elementor() {
		return json_decode('{"contact-us-page":[{"id":"25d3bd8f","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"10","right":0,"bottom":"80","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"html_tag":"div"},"elements":[{"id":"54881db8","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"55c16ec9","elType":"widget","settings":{"title":"Call us or visit place","align":"left","align_tablet":"center","title_color":"#1E1D23","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":""},"typography_letter_spacing":{"unit":"px","size":-1.399999999999999911182158029987476766109466552734375,"sizes":[]},"text_shadow_text_shadow":{"horizontal":0,"vertical":-1,"blur":10,"color":"rgba(0,0,0,0.3)"},"typography_line_height":{"unit":"px","size":35,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.8000000000000000444089209850062616169452667236328125,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-1.0500000000000000444089209850062616169452667236328125,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"7c605b59","elType":"widget","settings":{"editor":"Lorem ipsum dolor sit amet, consectetur adipiscing elit. ","_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"align_mobile":"center","align_tablet":"center","align":"left"},"elements":[],"widgetType":"text-editor"},{"id":"77a122f3","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"30","html_tag":"div"},"elements":[{"id":"6b3656a6","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"379caa4c","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-mobile-android-alt","library":"poco-icon"},"title_text":"Phone: ","description_text":"+ 44 123 456 78 90 <br\/>\n+ 844 123 444 77 88","icon_space":{"unit":"px","size":25,"sizes":[]},"icon_space_tablet":{"unit":"px","size":15,"sizes":[]},"icon_space_mobile":{"unit":"px","size":5,"sizes":[]},"text_align":"left","text_align_tablet":"center","title_bottom_space_tablet":{"unit":"px","size":5,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":16,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"5c0b2d98","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"1e16946e","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-map-marker-check","library":"poco-icon"},"title_text":"Address","description_text":"Box 565, Pinney\'s Beach, Charlestown,<br\/> Nevis, West Indies, Caribbean","icon_space":{"unit":"px","size":25,"sizes":[]},"icon_space_tablet":{"unit":"px","size":15,"sizes":[]},"icon_space_mobile":{"unit":"px","size":5,"sizes":[]},"text_align":"left","text_align_tablet":"center","title_bottom_space_tablet":{"unit":"px","size":5,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":16,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"62d1096c","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"376cba91","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-envelope","library":"poco-icon"},"title_text":"Email: ","description_text":"contact@example.com <br\/>\ninfo@example.com","icon_space":{"unit":"px","size":25,"sizes":[]},"icon_space_tablet":{"unit":"px","size":15,"sizes":[]},"icon_space_mobile":{"unit":"px","size":5,"sizes":[]},"text_align":"left","text_align_tablet":"center","title_bottom_space_tablet":{"unit":"px","size":5,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":16,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"62359854","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"html_tag":"div"},"elements":[{"id":"2e0ab5ce","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"border_border":"solid","border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_width_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_color":"#E1E1E1","border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true}},"elements":[{"id":"69231eb7","elType":"section","settings":{"layout":"full_width","gap":"no","content_position":"middle","structure":"20","html_tag":"div"},"elements":[{"id":"404ebd78","elType":"column","settings":{"_column_size":50,"_inline_size":null,"_inline_size_tablet":100,"space_between_widgets":0,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"40","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"2c8f292e","elType":"widget","settings":{"address":"EAST NEW YORK","height":{"unit":"px","size":660,"sizes":[]},"height_mobile":{"unit":"px","size":320,"sizes":[]},"_border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"0","isLinked":false},"_border_color":"#020101F0","_box_shadow_box_shadow":{"horizontal":0,"vertical":5,"blur":11,"spread":0,"color":"rgba(0,0,0,0.5)"},"_background_hover_transition":{"unit":"px","size":0,"sizes":[]},"height_tablet":{"unit":"px","size":480,"sizes":[]},"css_filters_css_filter":"custom","_border_radius":{"unit":"px","top":"5","right":"0","bottom":"0","left":"5","isLinked":false},"_border_radius_tablet":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true}},"elements":[],"widgetType":"google_maps"}],"isInner":true},{"id":"42d70d9a","elType":"column","settings":{"_column_size":50,"_inline_size":null,"_inline_size_tablet":100,"align_tablet":"center","space_between_widgets":0,"padding":{"unit":"px","top":"30","right":"80","bottom":"30","left":"80","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"70aa307b","elType":"widget","settings":{"title":"Send us a message","align":"left","align_tablet":"center","title_color":"#1E1D23","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":""},"typography_letter_spacing":{"unit":"px","size":-1.399999999999999911182158029987476766109466552734375,"sizes":[]},"text_shadow_text_shadow":{"horizontal":0,"vertical":-1,"blur":10,"color":"rgba(0,0,0,0.3)"},"typography_line_height":{"unit":"px","size":35,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.8000000000000000444089209850062616169452667236328125,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-1.0500000000000000444089209850062616169452667236328125,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"1b324b9c","elType":"widget","settings":{"editor":"Lorem ipsum dolor sit amet, consectetur adipiscing elit. ","_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"align_mobile":"center","align_tablet":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"27010321","elType":"widget","settings":{"form_name":"New Form","form_fields":[{"custom_id":"name","placeholder":" Your name","_id":"3e7ea59"},{"custom_id":"email","field_type":"email","required":"true","placeholder":"Email","_id":"7707ab7"},{"custom_id":"field_44fbad9","required":"true","placeholder":"Subject","_id":"44fbad9"},{"field_type":"textarea","rows":8,"custom_id":"field_e8d520d","_id":"e8d520d","placeholder":"Comment"}],"input_size":"xs","button_size":"md","button_align":"start","step_next_label":"Next","step_previous_label":"Previous","button_text":"submit","email_to":"admin@admin.com","email_subject":"New message from \"poco\"","email_content":"[all-fields]","email_from":"email@dev.wpopal.com","email_from_name":"poco","email_to_2":"admin@admin.com","email_subject_2":"New message from \"poco\"","email_content_2":"[all-fields]","email_from_2":"email@dev.wpopal.com","email_from_name_2":"poco","email_reply_to_2":"admin@admin.com","success_message":"The form was sent successfully.","error_message":"An error occured.","required_field_message":"This field is required.","invalid_message":"There\'s something wrong. The form is invalid.","column_gap":{"unit":"px","size":30,"sizes":[]},"row_gap":{"unit":"px","size":15,"sizes":[]},"field_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"field_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"field_text_padding":{"unit":"px","top":"10","right":"10","bottom":"10","left":"10","isLinked":true},"field_text_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_background_color":"#FFC222","button_text_color":"#000000","previous_button_text_color":"#000000","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"field_typography_typography":"custom","field_typography_font_size":{"unit":"px","size":15,"sizes":[]},"field_background_color":"#FFFFFF","field_border_color":"#E1E1E1","button_typography_line_height":{"unit":"px","size":"","sizes":[]},"button_border_radius":{"unit":"%","top":"","right":"","bottom":"","left":"","isLinked":true},"button_text_padding":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"label_spacing":{"unit":"px","size":"","sizes":[]},"html_spacing":{"unit":"px","size":"","sizes":[]},"mailchimp_fields_map":[],"drip_fields_map":[],"activecampaign_fields_map":[],"getresponse_fields_map":[],"convertkit_fields_map":[],"mailerlite_fields_map":[],"__globals__":{"button_background_color":"","field_text_color":"globals\/colors?id=1d12e908"},"button_align_tablet":"center","button_align_mobile":"center","_element_width_tablet":"initial","_element_custom_width_tablet":{"unit":"px","size":550,"sizes":[]}},"elements":[],"widgetType":"form"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false}],"about-us-page":[{"id":"51f9afe8","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","structure":"20","padding":{"unit":"px","top":"0","right":"30","bottom":"100","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"80","left":"15","isLinked":false},"html_tag":"div"},"elements":[{"id":"18afe1b3","elType":"column","settings":{"_column_size":50,"_inline_size":41.659999999999996589394868351519107818603515625,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"50","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"133e2572","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector1-h3.png","id":584},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"%","size":-40,"sizes":[]},"_offset_y":{"unit":"%","size":5,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes"},"elements":[],"widgetType":"image"},{"id":"32cc9caa","elType":"widget","settings":{"editor":"Wellome!","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_text_transform":"capitalize","align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":24,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"39855e41","elType":"widget","settings":{"title":"Best burger ideas \n& traditions from the \nwhole world","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_line_height":{"unit":"px","size":60,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"__globals__":{"title_color":""},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"title_color":"#1E1D23","align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"1206821f","elType":"widget","settings":{"editor":"Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.<br><br>\nMauris tempus erat laoreet turpis lobortis, eu tincidunt erat fermentum. Aliquam non tincidunt urna. Integer tincidunt nec nisl vitae ullamcorper. Proin sed ultrices erat.","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"},{"id":"de5c9ac","elType":"widget","settings":{"text":"Contact now","align_mobile":"center","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/contact-us\/","is_external":"","nofollow":"","custom_attributes":""}},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"42ea2511","elType":"column","settings":{"_column_size":50,"_inline_size":58.340000000000003410605131648480892181396484375,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"60","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[{"id":"1a26e3fa","elType":"section","settings":{"gap":"no","structure":"20","html_tag":"div"},"elements":[{"id":"f971559","elType":"column","settings":{"_column_size":50,"_inline_size":41.659999999999996589394868351519107818603515625,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"30","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[{"id":"2acf5180","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image1-h4.jpg","id":744},"image_size":"full","image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"hover_animation":"float","motion_fx_translateY_effect":"yes","_animation":"opal-move-up","_animation_delay":200,"align_mobile":"center"},"elements":[],"widgetType":"image"},{"id":"3e79546a","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector2-h3.png","id":585},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"%","size":-40,"sizes":[]},"_offset_orientation_v":"end","_offset_y":{"unit":"%","size":-10,"sizes":[]},"_offset_y_end":{"unit":"%","size":20,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true},{"id":"239f8ec9","elType":"column","settings":{"_column_size":50,"_inline_size":58.31099999999999994315658113919198513031005859375,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"10","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"5861f822","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image2-h4.jpg","id":745},"image_size":"full","image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"hover_animation":"float","motion_fx_translateY_speed":{"unit":"px","size":"","sizes":[]},"_animation":"opal-move-up","_animation_delay":400,"align_mobile":"center","_element_custom_width_mobile":{"unit":"%","size":50,"sizes":[]}},"elements":[],"widgetType":"image"},{"id":"2a4ec53e","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image3-h4.jpg","id":746},"image_size":"full","align":"left","image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"hover_animation":"float","motion_fx_translateY_effect":"yes","_animation":"opal-move-up","_animation_delay":600,"align_mobile":"center"},"elements":[],"widgetType":"image"},{"id":"5dab8929","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector3-h3.png","id":586},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x":{"unit":"%","size":-40,"sizes":[]},"_offset_y":{"unit":"%","size":45,"sizes":[]},"_offset_y_end":{"unit":"%","size":13,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"342825f","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","custom_height":{"unit":"px","size":560,"sizes":[]},"height":"min-height","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/bg-video.jpg","id":3321},"background_repeat":"no-repeat","background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","background_overlay_background":"classic","background_overlay_color":"#000000","background_overlay_opacity":{"unit":"px","size":0.59999999999999997779553950749686919152736663818359375,"sizes":[]},"background_motion_fx_translateY_speed":{"unit":"px","size":7,"sizes":[]},"custom_height_tablet":{"unit":"px","size":460,"sizes":[]},"custom_height_mobile":{"unit":"px","size":360,"sizes":[]},"background_position":"center center","padding":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false},"html_tag":"div"},"elements":[{"id":"7866bab8","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"c61f21c","elType":"widget","settings":{"video_link":"https:\/\/www.youtube.com\/watch?v=dLC54mz--Dk","_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"video_hover_bgcolor":"#EEAC00","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"poco-video-popup"},{"id":"54cd3190","elType":"widget","settings":{"title":"Make the thing Anything is Possible","typography_typography":"custom","typography_font_size":{"unit":"px","size":52,"sizes":[]},"typography_line_height":{"unit":"px","size":50,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"__globals__":{"title_color":""},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"title_color":"#FFFFFF","align_mobile":"center","align":"center","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":36,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-0.1000000000000000055511151231257827021181583404541015625,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.08000000000000000166533453693773481063544750213623046875,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"6d803c72","elType":"widget","settings":{"editor":"Enjoy our luscious dishes wherever you want ","align":"center","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_font_weight":"500","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":18,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":16,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":22,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"53921392","elType":"widget","settings":{"text":"ORDER NOW","align_mobile":"center","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/contact-us\/","is_external":"","nofollow":"","custom_attributes":""},"align":"center"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"611332ff","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","custom_height":{"unit":"px","size":650,"sizes":[]},"structure":"20","margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"custom_height_mobile":{"unit":"px","size":350,"sizes":[]},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"reverse_order_mobile":"reverse-mobile","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"html_tag":"div"},"elements":[{"id":"47bc6a4a","elType":"column","settings":{"_column_size":50,"_inline_size":45,"content_position":"center","padding":{"unit":"px","top":"150","right":"120","bottom":"100","left":"0","isLinked":false},"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"3332005f","elType":"widget","settings":{"editor":"<p>Our Quality<\/p>","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":25,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"typography_font_size_mobile":{"unit":"px","size":20,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"70b9e808","elType":"widget","settings":{"title":"Chicken","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":68,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.8000000000000000444089209850062616169452667236328125,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"11b45454","elType":"widget","settings":{"editor":"<p>Quality is our #1 ingredient. That\u2019s why our Chicken Wings, Chicken Bites and Grilled Chicken Topping are made from chickens raised without antibiotics and fed an all vegetable-grain diet, with no animal by-products. Plus, our Bites are made with 100% chicken breast meat.<\/p>","align":"left","typography_typography":"custom","typography_line_height":{"unit":"px","size":30,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"a8008f2","elType":"widget","settings":{"text":"ORDER NOW","typography_font_weight":"400","typography_line_height":{"unit":"px","size":20,"sizes":[]},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":"","vertical":0,"blur":10,"spread":0,"color":"rgba(0,0,0,0.5)"},"align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"2a6574d7","elType":"column","settings":{"_column_size":50,"_inline_size":55,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-right","margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"content_position":"center","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-4.png","id":1536},"background_position":"center center","background_repeat":"no-repeat","background_size":"auto","background_size_tablet":"contain","background_size_mobile":"initial","background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","background_motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"space_between_widgets":0,"background_bg_width_mobile":{"unit":"%","size":0,"sizes":[]}},"elements":[{"id":"b1052a3","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-5.png","id":1497},"image_size":"full","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"0","isLinked":false},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"space_mobile":{"unit":"px","size":"","sizes":[]},"motion_fx_devices":["desktop","tablet"],"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"5fd46c1b","elType":"section","settings":{"gap":"no","custom_height":{"unit":"px","size":650,"sizes":[]},"stretch_section":"section-stretched","structure":"20","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"custom_height_mobile":{"unit":"px","size":350,"sizes":[]},"margin_mobile":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"45af4828","elType":"column","settings":{"_column_size":50,"_inline_size":50,"animation":"opal-move-left","margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"content_position":"center","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-4.png","id":1536},"background_position":"center center","background_repeat":"no-repeat","background_size":"auto","background_size_tablet":"contain","background_size_mobile":"initial","background_motion_fx_translateY_effect":"yes","background_motion_fx_translateY_speed":{"unit":"px","size":"","sizes":[]},"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"space_between_widgets":0,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"background_bg_width_mobile":{"unit":"%","size":0,"sizes":[]}},"elements":[{"id":"3311cc37","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-6.png","id":1540},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"align_mobile":"center","space_mobile":{"unit":"%","size":80,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"1afc88b9","elType":"column","settings":{"_column_size":50,"_inline_size":50,"content_position":"center","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"125","isLinked":false},"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"4b71f4c4","elType":"widget","settings":{"editor":"<p>Our Quaity<\/p>","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":25,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":20,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"1cb23783","elType":"widget","settings":{"title":"Burger","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":68,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":0.8000000000000000444089209850062616169452667236328125,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"3998144e","elType":"widget","settings":{"editor":"<p>Some of the world\u2019s best cheese is made close to home! All our deliciously melty Mozzarella is made with 100% Canadian milk. We\u2019re proud to support Canadian dairy farmers.<\/p>","align":"left","typography_typography":"custom","typography_line_height":{"unit":"px","size":30,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"77219b6e","elType":"widget","settings":{"text":"ORDER NOW","typography_font_weight":"400","typography_line_height":{"unit":"px","size":20,"sizes":[]},"align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"4a45920a","elType":"section","settings":{"gap":"no","custom_height":{"unit":"px","size":600,"sizes":[]},"stretch_section":"section-stretched","structure":"20","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"custom_height_mobile":{"unit":"px","size":350,"sizes":[]},"reverse_order_mobile":"reverse-mobile","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"html_tag":"div"},"elements":[{"id":"bf45937","elType":"column","settings":{"_column_size":50,"_inline_size":45,"content_position":"center","padding":{"unit":"px","top":"100","right":"120","bottom":"150","left":"0","isLinked":false},"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"6773c4df","elType":"widget","settings":{"editor":"<p>Our Quaity<\/p>","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":25,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":20,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"22915d21","elType":"widget","settings":{"title":"Pizza Douch","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":68,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.8000000000000000444089209850062616169452667236328125,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"5bc12fc1","elType":"widget","settings":{"editor":"<p>Quality is our #1 ingredient. That\u2019s why our Chicken Wings, Chicken Bites and Grilled Chicken Topping are made from chickens raised without antibiotics and fed an all vegetable-grain diet, with no animal by-products. Plus, our Bites are made with 100% chicken breast meat.<\/p>","align":"left","typography_typography":"custom","typography_line_height":{"unit":"px","size":30,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"7f125095","elType":"widget","settings":{"text":"ORDER NOW","typography_font_weight":"400","typography_line_height":{"unit":"px","size":20,"sizes":[]},"align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"1cc89235","elType":"column","settings":{"_column_size":50,"_inline_size":55,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-right","margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"15","right":"0","bottom":"15","left":"0","isLinked":false},"content_position":"center","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-4.png","id":1536},"background_position":"center center","background_repeat":"no-repeat","background_size":"auto","background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","background_motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"space_between_widgets":0,"background_position_tablet":"center center","background_size_tablet":"contain","background_size_mobile":"initial","background_bg_width_mobile":{"unit":"%","size":0,"sizes":[]}},"elements":[{"id":"3a1bb72","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-7.png","id":1546},"image_size":"full","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"0","isLinked":false},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"38340909","elType":"section","settings":{"content_width":{"unit":"px","size":1070,"sizes":[]},"gap":"no","height":"min-height","custom_height":{"unit":"px","size":420,"sizes":[]},"stretch_section":"section-stretched","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/bg3-h4.jpg","id":736},"background_repeat":"no-repeat","background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","background_overlay_background":"classic","background_overlay_opacity":{"unit":"px","size":0.59999999999999997779553950749686919152736663818359375,"sizes":[]},"margin":{"unit":"px","top":"30","right":0,"bottom":"80","left":0,"isLinked":false},"__globals__":{"background_overlay_color":"globals\/colors?id=48e5bc8c"},"custom_height_tablet":{"unit":"px","size":380,"sizes":[]},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"animation_duration":"fast","html_tag":"div","padding":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"6e827b4d","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"400f816d","elType":"widget","settings":{"testimonials":[{"testimonial_icon":"fa fa-quote-left","testimonial_title":"","testimonial_content":"\u201cForget the trendy pizza shops, This hidden spot makes the best New York-style pizza slice in naples\u201d","testimonial_name":"Stephen Tindle","testimonial_job":"CEO,apple","testimonial_rating":"4","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-1.jpg","id":2531},"_id":"c4af6a8"},{"testimonial_title":"","testimonial_content":"\"I would be lost without restaurant. I would like to personally thank you for your outstanding product.\"","testimonial_name":"Nina Margaret ","testimonial_job":"CEO,apple","_id":"362dce0","testimonial_icon":"fa fa-quote-left","testimonial_rating":"5","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-2.jpg","id":2532}},{"testimonial_rating":"4","testimonial_content":"\"I am completely blown away. I would also like to say thank you to all your staff. It\'s really wonderful.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-4.jpg","id":2535},"testimonial_name":"Clara","testimonial_job":"Manager","_id":"4caa9d3"},{"testimonial_rating":"5","testimonial_content":"\"Without food, we would have gone bankrupt by now. Thanks food! The service was excellent.\"","testimonial_name":"John Doe","testimonial_job":"Manager","_id":"2966dc3","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-3.jpg","id":2534}}],"padding_estimonial_wrapper":{"unit":"%","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"icon_color":"#FFCC00","icon_size":{"unit":"px","size":40,"sizes":[]},"name_text_color":"#FFFFFF","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_text_transform":"uppercase","enable_carousel":"yes","__globals__":{"content_content_color":"globals\/colors?id=26c59e90"},"navigation":"both","_animation":"opal-move-up","animation_duration":"fast","icon_spacing":{"unit":"px","size":0,"sizes":[]},"content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":30,"sizes":[]},"button_color":"#FFFFFF","testimonial_style":"style2","content_typography_font_weight":"normal","name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"name_padding":{"unit":"px","top":"25","right":"0","bottom":"3","left":"0","isLinked":false},"button_color_normal":"#FFFFFF42","padding_estimonial_wrapper_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"content_typography_line_height":{"unit":"px","size":42,"sizes":[]},"content_spacing":{"unit":"px","size":15,"sizes":[]},"image_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"name_typography_line_height":{"unit":"px","size":20,"sizes":[]},"job_text_color":"#FFFFFF","job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":15,"sizes":[]},"content_typography_font_size_mobile":{"unit":"px","size":22,"sizes":[]},"content_typography_line_height_mobile":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"poco-testimonials"}],"isInner":false}],"isInner":false},{"id":"64c99aa8","elType":"section","settings":{"gap":"no","content_position":"middle","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"30","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"5a131bbb","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"align_mobile":"center","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"5","left":"0","isLinked":false}},"elements":[{"id":"5aea1ca7","elType":"widget","settings":{"editor":"Always Quality","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":25,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":22,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align":"center"},"elements":[],"widgetType":"text-editor"},{"id":"6f9d9750","elType":"widget","settings":{"title":"Our Talented Chefs","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"align":"center","typography_line_height_mobile":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"}],"isInner":false}],"isInner":false},{"id":"4ad47682","elType":"section","settings":{"content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","stretch_section":"section-stretched","structure":"30","margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"6a226eb1","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","margin_mobile":{"unit":"px","top":"0","right":"15","bottom":"30","left":"15","isLinked":false},"align_mobile":"center"},"elements":[{"id":"474058ca","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-1-2.jpg","id":353},"name":"william smith","job":"Chef","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false},{"id":"6cfbeb50","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":150,"margin_mobile":{"unit":"px","top":"0","right":"15","bottom":"30","left":"15","isLinked":false},"align_mobile":"center"},"elements":[{"id":"bed0a01","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-2-1.jpg","id":354},"name":"John Doe","job":"Manager","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false},{"id":"76390468","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":300,"align_mobile":"center"},"elements":[{"id":"3a72b2aa","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-6-1.jpg","id":358},"name":"Bradd L.","job":"Chef","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false}],"isInner":false},{"id":"5a35ffdb","elType":"section","settings":{"gap":"no","custom_height":{"unit":"px","size":370,"sizes":[]},"stretch_section":"section-stretched","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/bg3-h3-3.jpg","id":3113},"margin":{"unit":"px","top":"0","right":0,"bottom":"-40","left":0,"isLinked":false},"padding":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"background_xpos_tablet":{"unit":"px","size":-1000,"sizes":[]},"background_repeat":"no-repeat","background_size":"cover","margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"background_color":"#F3F0E7","html_tag":"div","background_position":"center center","height":"min-height","custom_height_tablet":{"unit":"px","size":300,"sizes":[]},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"4c337762","elType":"column","settings":{"_column_size":100,"_inline_size":null,"padding_mobile":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false},"space_between_widgets":0,"space_between_widgets_mobile":0,"align":"center"},"elements":[{"id":"3e18a34d","elType":"widget","settings":{"editor":"<p>We guarantee<\/p>","align":"center","text_color":"#FFC222","typography_typography":"custom","typography_font_size":{"unit":"px","size":32,"sizes":[]},"typography_line_height":{"unit":"px","size":30,"sizes":[]},"typography_font_family":"Norican","_animation":"fadeInUp","animation_duration":"fast","typography_font_size_tablet":{"unit":"px","size":28,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"typography_font_size_mobile":{"unit":"px","size":24,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"5","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"76279728","elType":"widget","settings":{"title":"30 Minutes Delivery!","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_line_height":{"unit":"px","size":70,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"fadeInUp","__globals__":{"title_color":"globals\/colors?id=accent"},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation_duration":"fast","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":48,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.8000000000000000444089209850062616169452667236328125,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"3867aa2e","elType":"widget","settings":{"editor":"If you\'re having a meeting, working late at night and need an extra push. Let us know and we will be there","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"fadeInUp","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation_duration":"fast","_element_width":"initial","_element_width_tablet":"initial","_element_custom_width":{"unit":"px","size":510,"sizes":[]},"_element_custom_width_tablet":{"unit":"px","size":450,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"5929b46","elType":"widget","settings":{"text":"make an order","align":"center","typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":20,"sizes":[]},"_animation":"fadeInUp","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"home-1":[{"id":"09a9b55","elType":"section","settings":{"gap":"no","height":"min-height","custom_height":{"unit":"px","size":740,"sizes":[]},"stretch_section":"section-stretched","background_background":"classic","background_color":"#333333","structure":"20","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_shape-1.png","id":582},"background_position":"center right","background_repeat":"no-repeat","background_overlay_background":"gradient","background_overlay_color":"#FFFFFF00","background_overlay_color_b":"#000000","background_overlay_gradient_type":"radial","background_overlay_opacity":{"unit":"px","size":0.5500000000000000444089209850062616169452667236328125,"sizes":[]},"custom_height_tablet":{"unit":"px","size":580,"sizes":[]},"background_position_tablet":"top right","background_size_tablet":"initial","background_bg_width_tablet":{"unit":"%","size":85,"sizes":[]},"padding":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"custom_height_mobile":{"unit":"px","size":400,"sizes":[]},"background_position_mobile":"bottom center","content_position":"middle","html_tag":"div","padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"75c185e","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"motion_fx_translateY_direction":"negative","motion_fx_translateY_effect":"yes","motion_fx_translateY_speed":{"unit":"px","size":3,"sizes":[]},"motion_fx_devices":["desktop"]},"elements":[{"id":"9fb7848","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_tomato.png","id":1216},"image_size":"full","width_tablet":{"unit":"px","size":320,"sizes":[]},"_z_index":2,"_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-125,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":-160,"sizes":[]},"_offset_y":{"unit":"px","size":-260,"sizes":[]},"_offset_y_tablet":{"unit":"px","size":-229,"sizes":[]},"motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"motion_fx_motion_fx_mouse":"yes","motion_fx_mouseTrack_effect":"yes","motion_fx_mouseTrack_speed":{"unit":"px","size":0.5,"sizes":[]},"_animation":"opal-move-down","animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"e686770","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_shape-7.png","id":2507},"image_size":"full","width_tablet":{"unit":"px","size":280,"sizes":[]},"_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":-462,"sizes":[]},"_offset_x_tablet":{"unit":"px","size":-90,"sizes":[]},"_offset_y":{"unit":"px","size":-120,"sizes":[]},"_offset_y_tablet":{"unit":"px","size":-180,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":3,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"opal-move-right","animation_duration":"fast","width_mobile":{"unit":"px","size":220,"sizes":[]},"_offset_x_mobile":{"unit":"px","size":-70,"sizes":[]},"_offset_y_mobile":{"unit":"px","size":-60,"sizes":[]},"hide_tablet":"hidden-tablet"},"elements":[],"widgetType":"image"},{"id":"268e9b8","elType":"widget","settings":{"title":"UNLIMITED <br> MEDIUM <span style=\"color:#ffcc00;\">PIZZAS<\/span>","typography_typography":"custom","typography_font_size":{"unit":"px","size":76,"sizes":[]},"typography_line_height":{"unit":"px","size":78,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":62,"sizes":[]},"_z_index_tablet":3,"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":48,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":53,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=26c59e90"},"_animation":"opal-move-up","animation_duration":"fast","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":6,"color":"#000000"},"_z_index":3},"elements":[],"widgetType":"heading"},{"id":"d61946d","elType":"widget","settings":{"title":"Medium 2-topping* pizza","header_size":"h4","title_color":"#00A149","typography_typography":"custom","typography_font_size":{"unit":"px","size":32,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_z_index_tablet":3,"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":28,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":24,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"c70d70d","elType":"widget","settings":{"editor":"*Additional charge for premium toppings. Minimum of 2 required.","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":0.450000000000000011102230246251565404236316680908203125,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index_tablet":3,"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":16,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":"","sizes":[]},"typography_line_height_mobile":{"unit":"px","size":22,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"33cf7f0","elType":"widget","settings":{"text":"ORDER NOW","size":"md","_margin":{"unit":"px","top":"0","right":"40","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","icon_indent":{"unit":"px","size":0,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_z_index_tablet":3,"_element_width_tablet":"inherit","align_mobile":"center","_animation":"opal-move-up","animation_duration":"fast","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/menu-restaurant\/","is_external":"","nofollow":"","custom_attributes":""},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":1,"blur":5,"spread":0,"color":"rgba(0,0,0,0.5)"}},"elements":[],"widgetType":"button"},{"id":"3751600","elType":"widget","settings":{"title":"$12.99","header_size":"h3","title_color":"#00A149","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","_z_index_tablet":3,"typography_line_height":{"unit":"px","size":55,"sizes":[]},"_animation":"tada"},"elements":[],"widgetType":"heading"},{"id":"1b9facb","elType":"widget","settings":{"title":"$19.99","header_size":"h5","title_color":"#FFFFFF61","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_element_width":"auto","_z_index_tablet":3,"_animation":"rollIn","_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"72a8ae8","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"align":"flex-end"},"elements":[{"id":"8a77603","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_shape-4.png","id":1189},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-500,"sizes":[]},"_offset_y":{"unit":"px","size":-97,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":3,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"opal-move-left","animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"d6c52a4","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_shape-6.png","id":1232},"image_size":"full","width":{"unit":"px","size":1060,"sizes":[]},"width_tablet":{"unit":"px","size":800,"sizes":[]},"_margin":{"unit":"px","top":"-60","right":"-315","bottom":"0","left":"-200","isLinked":false},"_margin_tablet":{"unit":"px","top":"-60","right":"-350","bottom":"0","left":"-200","isLinked":false},"_z_index":1,"_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":0,"sizes":[]},"width_mobile":{"unit":"%","size":0,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":3,"sizes":[]},"motion_fx_translateX_effect":"yes","motion_fx_translateX_speed":{"unit":"px","size":3,"sizes":[]},"motion_fx_rotateZ_effect":"yes","motion_fx_rotateZ_speed":{"unit":"px","size":0.299999999999999988897769753748434595763683319091796875,"sizes":[]}},"elements":[],"widgetType":"image"},{"id":"f6b15a7","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_pizza.png","id":565},"image_size":"full","align":"right","_margin":{"unit":"px","top":"-30","right":"-65","bottom":"0","left":"0","isLinked":false},"motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"_z_index":2,"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"motion_fx_devices":["desktop","tablet"],"_animation":"rubberBand","motion_fx_motion_fx_scrolling":"yes"},"elements":[],"widgetType":"image"},{"id":"c8dbd7f","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_shape-5.png","id":1302},"image_size":"full","align":"left","width_tablet":{"unit":"px","size":180,"sizes":[]},"_position":"absolute","_offset_x_tablet":{"unit":"px","size":-60,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end_tablet":{"unit":"px","size":-60,"sizes":[]},"_animation":"rotateInDownRight","_animation_delay":100,"motion_fx_motion_fx_mouse":"yes","motion_fx_mouseTrack_effect":"yes","motion_fx_mouseTrack_direction":"negative","motion_fx_mouseTrack_speed":{"unit":"px","size":0.5,"sizes":[]},"motion_fx_tilt_effect":"yes","motion_fx_tilt_speed":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"image"},{"id":"b6ace4e","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_shape-5.png","id":1190},"image_size":"full","width_tablet":{"unit":"px","size":88,"sizes":[]},"_z_index_tablet":2,"_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-194,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":0,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end":{"unit":"px","size":-10,"sizes":[]},"_offset_y_end_tablet":{"unit":"px","size":-110,"sizes":[]},"_offset_x_end_mobile":{"size":-21,"unit":"px"},"_offset_y_end_mobile":{"size":256.5,"unit":"px"},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"motion_fx_mouseTrack_effect":"yes","motion_fx_mouseTrack_direction":"negative","motion_fx_mouseTrack_speed":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625,"sizes":[]},"_animation":"rollIn","_animation_delay":150,"motion_fx_rotateZ_effect":"yes","motion_fx_rotateZ_speed":{"unit":"px","size":0.5,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"c7aafad","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"30","left":0,"isLinked":false},"html_tag":"div","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"493353b","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"0a07289","elType":"widget","settings":{"text":"menus","align":"center","typography_text_transform":"uppercase","_margin":{"unit":"px","top":"-30","right":"0","bottom":"0","left":"0","isLinked":false},"icon_indent":{"unit":"px","size":0,"sizes":[]},"_z_index_mobile":2,"_z_index":3,"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/menu-restaurant\/","is_external":"","nofollow":"","custom_attributes":""},"typography_typography":"custom"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"2bcf1c2","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"80","background_background":"classic","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"content_width":{"unit":"px","size":1380,"sizes":[]},"html_tag":"div","content_position":"bottom"},"elements":[{"id":"90d8e39","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_inline_size_tablet":25,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"112be55","elType":"widget","settings":{"categories":"pizza","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/category-11.png","id":2986},"tilte_typography_typography":"custom","categories_name":"Combo","tilte_typography_font_weight":"700"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"647483c","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_inline_size_tablet":25,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":50},"elements":[{"id":"39ac049","elType":"widget","settings":{"categories":"pasta","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/category-22.png","id":2987},"categories_name":"Kids menus","tilte_typography_typography":"custom","tilte_typography_font_weight":"700","tilte_typography_line_height":{"unit":"px","size":"","sizes":[]}},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"7769185","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_inline_size_tablet":25,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":100},"elements":[{"id":"c0f01d1","elType":"widget","settings":{"categories":"pizza","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/category3.png","id":395},"tilte_typography_typography":"custom","categories_name":"Pizza","tilte_typography_font_weight":"700"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"2ad2673","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_inline_size_tablet":25,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":150},"elements":[{"id":"3e99d3a","elType":"widget","settings":{"categories":"burgers","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/category-44.png","id":2989},"tilte_typography_typography":"custom","categories_name":"Box meals","tilte_typography_font_weight":"700"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"cc968fb","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_inline_size_tablet":25,"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"de79125","elType":"widget","settings":{"categories":"burgers","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/category5.png","id":397},"tilte_typography_typography":"custom","categories_name":"Burger","tilte_typography_font_weight":"700"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"7df9dad","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_inline_size_tablet":25,"animation":"opal-move-up","animation_duration":"fast","animation_delay":250},"elements":[{"id":"1d024d7","elType":"widget","settings":{"categories":"pasta","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/category-33.png","id":2988},"tilte_typography_typography":"custom","categories_name":"chicken","tilte_typography_font_weight":"700"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"4553024","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50,"_inline_size_tablet":25,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"d606711","elType":"widget","settings":{"categories":"cold-drinks","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/category7.png","id":399},"tilte_typography_typography":"custom","categories_name":"Sauces","tilte_typography_font_weight":"700"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"3a66b15","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50,"_inline_size_tablet":25,"animation":"opal-move-up","animation_duration":"fast","animation_delay":350},"elements":[{"id":"04fa65d","elType":"widget","settings":{"categories":"hot-drinks","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/category-55.png","id":2990},"tilte_typography_typography":"custom","categories_name":"drinks","tilte_typography_font_weight":"700"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false}],"isInner":false},{"id":"de17b53","elType":"section","settings":{"content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","stretch_section":"section-stretched","structure":"30","background_background":"classic","background_color":"#F7F2E2","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"padding":{"unit":"px","top":"100","right":"15","bottom":"100","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"html_tag":"div"},"elements":[{"id":"1ae5499","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_inline_size_tablet":50},"elements":[{"id":"2f4f455","elType":"widget","settings":{"bg_image":{"url":"","id":""},"bg_image_size":"full","subtitle":"","title":"Any day <br> offers","description":"new  phenomenon<br> burger taste","button":"$12.90","min-height":{"unit":"px","size":240,"sizes":[]},"alignment":"left","vertical_position":"top","padding":{"unit":"px","top":"35","right":"30","bottom":"30","left":"40","isLinked":false},"box_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":28,"sizes":[]},"title_typography_line_height":{"unit":"px","size":30,"sizes":[]},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":12,"sizes":[]},"description_typography_text_transform":"uppercase","description_typography_line_height":{"unit":"px","size":20,"sizes":[]},"title_color":"#1E1D23","description_color":"#1E1D23","button_text_color":"#00A850","button_background_color":"#02010100","button_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"content_animation":"","overlay_color_hover":"#02010100","effect_duration":{"unit":"px","size":400,"sizes":[]},"padding_tablet":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"title_spacing":{"unit":"px","size":10,"sizes":[]},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":20,"sizes":[]},"description_shadow_text_shadow_type":"yes","description_shadow_text_shadow":{"horizontal":1,"vertical":1,"blur":10,"color":"#FFFFFF"},"graphic_element":"image","graphic_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_banner1-2.png","id":2183},"graphic_image_2":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_banner1-1.png","id":2182},"graphic_image_hover":"yes","_background_background":"classic","_background_color":"#FFFFFF","_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"button_typography_font_weight":"700"},"elements":[],"widgetType":"poco-banner"}],"isInner":false},{"id":"dd90ecc","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_inline_size_tablet":50},"elements":[{"id":"b28c977","elType":"widget","settings":{"bg_image":{"url":"","id":""},"bg_image_size":"full","subtitle":"","title":"Other<br> flavors","description":"Save room.<br> we made salats","button":"$12.90","min-height":{"unit":"px","size":240,"sizes":[]},"alignment":"left","vertical_position":"top","padding":{"unit":"px","top":"35","right":"30","bottom":"30","left":"40","isLinked":false},"box_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":28,"sizes":[]},"title_typography_line_height":{"unit":"px","size":30,"sizes":[]},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":12,"sizes":[]},"description_typography_text_transform":"uppercase","description_typography_line_height":{"unit":"px","size":20,"sizes":[]},"title_color":"#FFFFFF","description_color":"#FFFFFF","button_text_color":"#FFC222","button_background_color":"#02010100","button_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"content_animation":"","overlay_color_hover":"#02010112","effect_duration":{"unit":"px","size":400,"sizes":[]},"padding_tablet":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"title_spacing":{"unit":"px","size":10,"sizes":[]},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":20,"sizes":[]},"description_shadow_text_shadow_type":"yes","description_shadow_text_shadow":{"horizontal":0,"vertical":1,"blur":5,"color":"#00A149"},"graphic_element":"image","graphic_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_banner2-1.png","id":2161},"graphic_image_2":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_banner2-2.png","id":2162},"graphic_image_hover":"yes","title_shadow_text_shadow_type":"yes","title_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#00A149"},"_background_background":"classic","_background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_banner2.jpg","id":2164},"_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"button_typography_font_weight":"700"},"elements":[],"widgetType":"poco-banner"}],"isInner":false},{"id":"bc5f90f","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"30","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_inline_size_tablet":100,"align_tablet":"center"},"elements":[{"id":"5895776","elType":"widget","settings":{"bg_image":{"url":"","id":""},"bg_image_size":"full","subtitle":"","title":"Find a Poco<br>  store<br> near you","description":"","button":"Contact us","min-height":{"unit":"px","size":240,"sizes":[]},"alignment":"left","vertical_position":"top","padding":{"unit":"px","top":"35","right":"30","bottom":"30","left":"40","isLinked":false},"box_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":28,"sizes":[]},"title_typography_line_height":{"unit":"px","size":30,"sizes":[]},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":14,"sizes":[]},"description_typography_text_transform":"uppercase","description_typography_line_height":{"unit":"px","size":20,"sizes":[]},"title_color":"#1E1D23","button_background_color":"#02010100","button_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"content_animation":"","overlay_color_hover":"#02010112","effect_duration":{"unit":"px","size":400,"sizes":[]},"padding_tablet":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"title_spacing":{"unit":"px","size":20,"sizes":[]},"graphic_element":"image","graphic_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_banner2-1.png","id":2161},"graphic_image_2":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_banner3.png","id":2167},"graphic_image_hover":"yes","_background_background":"classic","_background_color":"#FFFFFF","_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"_element_width_tablet":"initial","_element_width_mobile":"inherit","_element_custom_width_tablet":{"unit":"%","size":50,"sizes":[]},"description_typography_font_weight":"700","__globals__":{"description_color":"globals\/colors?id=primary","button_text_color":"globals\/colors?id=primary","button_hover_text_color":"globals\/colors?id=accent"},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/contact-us\/","is_external":"","nofollow":"","custom_attributes":""},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14,"sizes":[]},"button_typography_font_weight":"700","button_typography_text_transform":"uppercase","button_typography_line_height":{"unit":"em","size":4.5999999999999996447286321199499070644378662109375,"sizes":[]},"button_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]}},"elements":[],"widgetType":"poco-banner"}],"isInner":false}],"isInner":false},{"id":"0299175","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"background_background":"classic","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"html_tag":"div"},"elements":[{"id":"73a57b4","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"content_position":"center","align":"center"},"elements":[{"id":"cfe1357","elType":"widget","settings":{"title":"Popular dishes","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"86e9af6","elType":"widget","settings":{"tabs":[{"tab_title":"pizza","_id":"8f6b32a","limit":8,"product_type":"best_selling"},{"tab_title":"sushi","limit":8,"orderby":"title","_id":"4db1d15"},{"tab_title":"salats","limit":8,"product_type":"best_selling","_id":"3243272"},{"tab_title":"burger","limit":8,"_id":"eb12372"},{"tab_title":"Dersest","limit":8,"_id":"9c18288"}],"column":"4","tab_header_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"align_items":"center","header_margin":{"unit":"px","size":10,"sizes":[]},"border_tabs_radius":{"unit":"px","top":"28","right":"28","bottom":"28","left":"28","isLinked":true},"__globals__":{"tab_typography_typography":"","title_color":"globals\/colors?id=accent","title_active_color":""},"tab_typography_typography":"custom","tab_typography_font_size":{"unit":"px","size":14,"sizes":[]},"tab_typography_text_transform":"uppercase","tab_title_spacing":{"unit":"px","size":90,"sizes":[]},"tab_title_vertical_padding":{"unit":"px","size":15,"sizes":[]},"title_hover_border_color":"#FFC222","title_background_active_color":"#FFC222","title_active_border_color":"#FFC222","border_tabs_title_border":"solid","border_tabs_title_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_tabs_title_color":"#EDEDED","_z_index":2,"header_margin_tablet":{"unit":"px","size":10,"sizes":[]},"tab_title_spacing_tablet":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"-15","bottom":"10","left":"-15","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"tab_header_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"tab_title_padding":{"unit":"px","top":"15","right":"45","bottom":"15","left":"45","isLinked":false},"title_color":"#1E1D23","tab_typography_font_weight":"700","_margin_mobile":{"unit":"px","top":"0","right":"-15","bottom":"0","left":"-15","isLinked":false}},"elements":[],"widgetType":"poco-products-tabs"},{"id":"42675e3","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector2-h3.png","id":585},"image_size":"full","_z_index":1,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"_element_width":"auto","_position":"absolute","_offset_x":{"unit":"%","size":40.5,"sizes":[]},"_offset_y":{"unit":"%","size":50,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"cac2a6f","elType":"widget","settings":{"text":"All products ","align":"center","typography_text_transform":"uppercase","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/shop\/","is_external":"","nofollow":"","custom_attributes":""}},"elements":[],"widgetType":"button"},{"id":"a468712","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector3-h3.png","id":586},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-122,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end":{"unit":"px","size":36,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"b578c9b","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector1-h3.png","id":584},"image_size":"full","_z_index":1,"_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":-103,"sizes":[]},"_offset_y":{"unit":"px","size":230,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"4b39605","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","structure":"20","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_bg.jpg","id":773},"background_position":"center center","background_size":"cover","height":"min-height","custom_height":{"unit":"px","size":320,"sizes":[]},"column_position":"stretch","content_position":"top","background_overlay_background":"classic","background_overlay_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_img.png","id":776},"background_overlay_position":"initial","background_overlay_xpos":{"unit":"px","size":90,"sizes":[]},"background_overlay_repeat":"no-repeat","background_overlay_opacity":{"unit":"px","size":1,"sizes":[]},"margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"padding":{"unit":"px","top":"110","right":"30","bottom":"110","left":"30","isLinked":false},"background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","custom_height_mobile":{"unit":"px","size":0,"sizes":[]},"background_overlay_position_tablet":"bottom left","background_overlay_size_tablet":"initial","background_overlay_size_mobile":"initial","background_overlay_bg_width_tablet":{"unit":"px","size":600,"sizes":[]},"background_overlay_bg_width_mobile":{"unit":"px","size":300,"sizes":[]},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"964209b","elType":"column","settings":{"_column_size":50,"_inline_size":59.7000000000000028421709430404007434844970703125,"space_between_widgets":0,"_inline_size_tablet":45,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"60","left":"0","isLinked":false},"animation":"opal-move-right","animation_duration":"fast"},"elements":[{"id":"52e7759","elType":"widget","settings":{"title":"Get Up to","header_size":"h5","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"5","left":"290","isLinked":false},"_z_index":2,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"typography_font_family":"Norican","_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"5","left":"60","isLinked":false},"motion_fx_devices":["desktop","tablet"]},"elements":[],"widgetType":"heading"},{"id":"4f992c7","elType":"widget","settings":{"title":"50%","title_color":"#FFCD02","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_line_height":{"unit":"px","size":40,"sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"290","isLinked":false},"_z_index":2,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"60","isLinked":false},"motion_fx_devices":["desktop","tablet"]},"elements":[],"widgetType":"heading"},{"id":"cb80cda","elType":"widget","settings":{"title":"Off","title_color":"#1E1D23","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":40,"sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"290","isLinked":false},"_z_index":2,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"60","isLinked":false},"motion_fx_devices":["desktop","tablet"]},"elements":[],"widgetType":"heading"},{"id":"045ad61","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_think.png","id":852},"_z_index":1,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":233,"sizes":[]},"_offset_y":{"unit":"px","size":-28,"sizes":[]},"image_size":"full","motion_fx_devices":["desktop","tablet"],"_offset_x_tablet":{"unit":"px","size":0,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"1459bd0","elType":"column","settings":{"_column_size":50,"_inline_size":40.2999999999999971578290569595992565155029296875,"space_between_widgets":0,"content_position":"center","align":"flex-end","_inline_size_tablet":55},"elements":[{"id":"481ba65","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_thunder-1.png","id":822},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":145,"sizes":[]},"_offset_y":{"unit":"px","size":-30,"sizes":[]},"hide_mobile":"hidden-phone","motion_fx_devices":["desktop","tablet"],"_animation":"opal-helix","animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"c1efbba","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_thunder-2.png","id":824},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":80,"sizes":[]},"_offset_y":{"unit":"px","size":12,"sizes":[]},"hide_mobile":"hidden-phone","motion_fx_devices":["desktop","tablet"],"_animation":"opal-helix","animation_duration":"fast","_animation_delay":50},"elements":[],"widgetType":"image"},{"id":"c659e0d","elType":"widget","settings":{"title":"Hot  Fresh","header_size":"h3","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"typography_font_family":"Norican","align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":32,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":35,"sizes":[]},"text_shadow_text_shadow":{"horizontal":3,"vertical":0,"blur":4,"color":"#000000"},"text_shadow_text_shadow_type":"yes"},"elements":[],"widgetType":"heading"},{"id":"85fe9da","elType":"widget","settings":{"title":"hotdog","title_color":"#FFCD02","typography_typography":"custom","typography_font_size":{"unit":"px","size":120,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":125,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":80,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":60,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":85,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":65,"sizes":[]},"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":0,"vertical":1,"blur":5,"color":"rgba(0, 0, 0, 0.5)"}},"elements":[],"widgetType":"heading"},{"id":"9412328","elType":"widget","settings":{"text":"ORDER NOW","align_mobile":"center","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/menu-restaurant\/","is_external":"","nofollow":"","custom_attributes":""},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":1,"blur":5,"spread":0,"color":"rgba(0,0,0,0.5)"},"background_color":"#FFFFFF","__globals__":{"button_background_hover_color":"globals\/colors?id=primary"}},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"266ef16","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","structure":"20","margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"46cccc2","elType":"column","settings":{"_column_size":50,"_inline_size":68.2000000000000028421709430404007434844970703125,"content_position":"top","align":"space-between","space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"985ff27","elType":"section","settings":{"layout":"full_width","gap":"no","content_position":"middle","structure":"20","margin":{"unit":"px","top":"-5","right":0,"bottom":"0","left":0,"isLinked":false},"html_tag":"div"},"elements":[{"id":"7d415eb","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"135d724","elType":"widget","settings":{"title":"Top recipes","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"header_size":"h3","__globals__":{"title_color":"globals\/colors?id=accent"},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"e3760c6","elType":"column","settings":{"_column_size":50,"_inline_size":null,"align":"flex-end","align_mobile":"center","space_between_widgets":0},"elements":[{"id":"09e4d3f","elType":"widget","settings":{"icon_list":[{"text":"See all","selected_icon":{"value":"","library":""},"_id":"ac595d4","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/shop\/","is_external":"","nofollow":"","custom_attributes":""}}],"_element_width":"auto","_offset_orientation_h":"end","_offset_x":{"unit":"px","size":30,"sizes":[]},"_offset_x_end":{"size":507.17200000000002546585164964199066162109375,"unit":"px"},"__globals__":{"text_color":"globals\/colors?id=accent","text_color_hover":"globals\/colors?id=primary"},"_padding":{"unit":"px","top":"0","right":"6","bottom":"0","left":"0","isLinked":false},"_offset_y":{"size":18,"unit":"px"}},"elements":[],"widgetType":"icon-list"},{"id":"8a1cc2c","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-angle-right","library":"poco-icon"},"view":"stacked","shape":"square","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"size":{"unit":"px","size":12,"sizes":[]},"border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"_element_width":"auto","_offset_orientation_h":"end","__globals__":{"primary_color":"globals\/colors?id=secondary","hover_primary_color":""},"primary_color":"#00A149","_padding":{"unit":"px","top":"8","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon"}],"isInner":true}],"isInner":true},{"id":"85af1f6","elType":"widget","settings":{"column":"2","product_type":"best_selling","product_layout":"list","_margin":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"poco-products"}],"isInner":false},{"id":"8723802","elType":"column","settings":{"_column_size":50,"_inline_size":31.800000000000000710542735760100185871124267578125,"space_between_widgets":0,"_inline_size_tablet":100,"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"ad32a8b","elType":"widget","settings":{"bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_banner-4.jpg","id":2983},"bg_image_size":"full","subtitle":"Super Delicious","title":"CHICKEN","description":"<span style=\"font-size:18px;\">call us now:<\/span> <br> <span style=\"color:#f00000;\">1-800-555-333<\/span>","button":"","min-height":{"unit":"px","size":550,"sizes":[]},"vertical_position":"top","padding":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"box_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":70,"sizes":[]},"title_typography_line_height":{"unit":"px","size":70,"sizes":[]},"subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":42,"sizes":[]},"subtitle_typography_line_height":{"unit":"px","size":45,"sizes":[]},"description_typography_typography":"custom","description_typography_font_family":"Lilita One","description_typography_font_size":{"unit":"px","size":30,"sizes":[]},"description_typography_line_height":{"unit":"px","size":30,"sizes":[]},"title_color":"#F00000","content_animation":"","effect_duration":{"unit":"px","size":400,"sizes":[]},"subtitle_typography_font_family":"Norican","description_typography_text_transform":"uppercase","__globals__":{"subtitle_typography_typography":""},"transformation":"","content-stretch":"yes","overlay_color_hover":"#02010100","title_spacing":{"unit":"px","size":10,"sizes":[]}},"elements":[],"widgetType":"poco-banner"}],"isInner":false}],"isInner":false},{"id":"74d57d0","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","background_background":"classic","background_color":"#F7F2E2","padding":{"unit":"px","top":"100","right":"30","bottom":"100","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"ad5538c","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"d24478c","elType":"widget","settings":{"title":"What  your client says","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"header_size":"h3","__globals__":{"title_color":"globals\/colors?id=accent"},"align_mobile":"center","_element_width_mobile":"inherit","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"align":"center","typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"0bc5012","elType":"widget","settings":{"testimonials":[{"testimonial_icon":"","testimonial_title":"","testimonial_content":"\u201cForget the trendy pizza shops, This hidden spot makes the best New York-style pizza slice in naples\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-2.jpg","id":2532},"testimonial_name":"Nina Margaret ","testimonial_job":"CEO,apple","_id":"44240e3","testimonial_rating":"4"},{"testimonial_icon":"","testimonial_title":"","testimonial_content":"\"I would be lost without restaurant. I would like to personally thank you for your outstanding product.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-1.jpg","id":2531},"testimonial_name":"Rose","testimonial_job":"Design","_id":"5211bae","testimonial_rating":5},{"testimonial_icon":"","testimonial_title":"","testimonial_content":"\"I am completely blown away. I would also like to say thank you to all your staff. It\'s really wonderful.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-4.jpg","id":2535},"testimonial_name":"Clara","testimonial_job":"Design","_id":"e8cf9d6","testimonial_rating":"3"},{"testimonial_title":"Testimonial title","testimonial_content":"\"I would be lost without restaurant. I would like to personally thank you for your outstanding product.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-3.jpg","id":2534},"testimonial_name":"John Doe","testimonial_job":"Design","_id":"b11e9eb","testimonial_rating":5}],"testimonial_alignment":"left","column":"3","enable_carousel":"yes","padding_estimonial_wrapper":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":true},"color_testimonial_wrapper":"#FFFFFF","wrapper_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"image_margin":{"unit":"px","top":"0","right":"15","bottom":"25","left":"0","isLinked":false},"navigation":"both","padding_estimonial_wrapper_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"next_horizontal":"right","next_horizontal_value_tablet":{"unit":"px","size":0,"sizes":[]},"prev_horizontal":"left","prev_horizontal_value_tablet":{"unit":"px","size":0,"sizes":[]},"column_tablet":"2"},"elements":[],"widgetType":"poco-testimonials"}],"isInner":false}],"isInner":false},{"id":"bd77b00","elType":"section","settings":{"layout":"full_width","gap":"no","overflow":"hidden","stretch_section":"section-stretched","structure":"30","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"background_background":"classic","background_color":"#FFC900","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"html_tag":"div"},"elements":[{"id":"f615cfb","elType":"column","settings":{"_column_size":33,"_inline_size":32.030000000000001136868377216160297393798828125,"space_between_widgets":0,"background_background":"classic","background_color":"#00A850","padding":{"unit":"px","top":"80","right":"30","bottom":"55","left":"60","isLinked":false},"z_index":1,"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"60","right":"30","bottom":"60","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"87ce3b9","elType":"widget","settings":{"title":"Fast Food","header_size":"h3","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"typography_font_family":"Norican","typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"_z_index":2,"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#00A850"},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_line_height_tablet":{"unit":"px","size":26,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"5da6085","elType":"widget","settings":{"title":"meals","title_color":"#FFCD02","typography_typography":"custom","typography_font_size":{"unit":"px","size":90,"sizes":[]},"typography_text_transform":"capitalize","typography_line_height":{"unit":"px","size":90,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-2.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"_z_index":2,"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":80,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-1.850000000000000088817841970012523233890533447265625,"sizes":[]},"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":2,"vertical":0,"blur":6,"color":"#00A850"},"typography_font_size_mobile":{"unit":"px","size":48,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":55,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"fde2824","elType":"widget","settings":{"editor":"new phenomenon <br> burger taste","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":26,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":1.350000000000000088817841970012523233890533447265625,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index":2,"texteditor_shadow_text_shadow_type":"yes","texteditor_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#00A850"},"typography_font_size_mobile":{"unit":"px","size":16,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":20,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"d399d0e","elType":"widget","settings":{"title":"$19.90","title_color":"#FFCD02","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":45,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index":2,"typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"edcc818","elType":"widget","settings":{"text":"ORDER NOW","_z_index":2,"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/menu-restaurant\/","is_external":"","nofollow":"","custom_attributes":""},"_animation":"opal-move-up","animation_duration":"fast","background_color":"#FFFFFF","button_background_hover_color":"#000000","__globals__":{"button_background_hover_color":""}},"elements":[],"widgetType":"button"},{"id":"2b8e0b9","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_shape-8.png","id":2529},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-30,"sizes":[]},"_offset_y":{"unit":"px","size":-80,"sizes":[]},"_css_classes":"img-hover"},"elements":[],"widgetType":"image"},{"id":"5b714cc","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_shape-2.png","id":942},"image_size":"full","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_element_width":"initial","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"size":-364.875,"unit":"px"},"_offset_orientation_v":"end","motion_fx_tilt_effect":"yes","motion_fx_tilt_speed":{"unit":"px","size":2,"sizes":[]},"width_tablet":{"unit":"px","size":420,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":-180,"sizes":[]},"_offset_y_end_tablet":{"unit":"px","size":50,"sizes":[]},"_element_custom_width":{"unit":"px","size":629,"sizes":[]},"_offset_y_end":{"size":-39,"unit":"px"},"motion_fx_motion_fx_scrolling":"yes","_element_width_tablet":"initial","_element_width_mobile":"initial","_element_custom_width_tablet":{"unit":"px","size":380,"sizes":[]},"_element_custom_width_mobile":{"unit":"px","size":270,"sizes":[]},"_offset_x_end_mobile":{"unit":"px","size":-130,"sizes":[]},"_offset_y_end_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-left","animation_duration":"fast"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"907c784","elType":"column","settings":{"_column_size":33,"_inline_size":35.92999999999999971578290569595992565155029296875,"space_between_widgets":0,"background_background":"classic","background_color":"#DB731E","padding":{"unit":"px","top":"80","right":"30","bottom":"55","left":"60","isLinked":false},"z_index":2,"_inline_size_tablet":50,"content_position_tablet":"center","padding_tablet":{"unit":"px","top":"60","right":"30","bottom":"60","left":"30","isLinked":false},"background_position":"center right","background_repeat":"no-repeat","padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"0b1cbb8","elType":"widget","settings":{"title":"House","header_size":"h3","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"typography_font_family":"Norican","typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#DB731E"},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_line_height_tablet":{"unit":"px","size":26,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"8e07c22","elType":"widget","settings":{"title":"Burgers","title_color":"#FFCD02","typography_typography":"custom","typography_font_size":{"unit":"px","size":90,"sizes":[]},"typography_text_transform":"capitalize","typography_line_height":{"unit":"px","size":90,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-2.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"_z_index":2,"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":80,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-1.850000000000000088817841970012523233890533447265625,"sizes":[]},"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":2,"vertical":0,"blur":6,"color":"#DB731E"},"typography_font_size_mobile":{"unit":"px","size":48,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":55,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"c3b0248","elType":"widget","settings":{"editor":"new phenomenon <br> burger taste","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":26,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":1.350000000000000088817841970012523233890533447265625,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index":2,"texteditor_shadow_text_shadow_type":"yes","texteditor_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#DB731E"},"typography_font_size_mobile":{"unit":"px","size":16,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":20,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"5f9d042","elType":"widget","settings":{"title":"$12.90","title_color":"#FFCD02","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":45,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index":2,"typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"7086bfd","elType":"widget","settings":{"text":"ORDER NOW","_z_index":2,"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/menu-restaurant\/","is_external":"","nofollow":"","custom_attributes":""},"_animation":"opal-move-up","animation_duration":"fast","background_color":"#FFFFFF","button_background_hover_color":"#000000","__globals__":{"button_background_hover_color":""}},"elements":[],"widgetType":"button"},{"id":"a9c5939","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_shape-8.png","id":2529},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-30,"sizes":[]},"_offset_y":{"unit":"px","size":-80,"sizes":[]},"_css_classes":"img-hover"},"elements":[],"widgetType":"image"},{"id":"f6a0f5b","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_shape-3.png","id":949},"image_size":"full","_element_width":"initial","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"size":-240,"unit":"px"},"_offset_orientation_v":"end","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"motion_fx_mouseTrack_direction":"negative","motion_fx_tilt_effect":"yes","motion_fx_tilt_direction":"negative","motion_fx_tilt_speed":{"unit":"px","size":2,"sizes":[]},"_offset_y_end":{"size":"","unit":"px"},"width_tablet":{"unit":"px","size":300,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":-130,"sizes":[]},"_element_custom_width":{"unit":"px","size":478,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","_element_width_tablet":"initial","_element_width_mobile":"initial","_element_custom_width_tablet":{"unit":"px","size":280,"sizes":[]},"_element_custom_width_mobile":{"unit":"px","size":240,"sizes":[]},"_animation":"opal-move-left","animation_duration":"fast","_animation_delay":100},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"b9a5ce7","elType":"column","settings":{"_column_size":33,"_inline_size":31.70400000000000062527760746888816356658935546875,"space_between_widgets":0,"background_background":"classic","background_color":"#FFC900","padding":{"unit":"px","top":"80","right":"30","bottom":"55","left":"60","isLinked":false},"z_index":2,"_inline_size_tablet":55,"padding_tablet":{"unit":"px","top":"60","right":"50","bottom":"60","left":"30","isLinked":false},"align_tablet":"center","align_mobile":"flex-start","padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"f875236","elType":"widget","settings":{"title":"Hot  Fresh","header_size":"h3","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"typography_font_family":"Norican","typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"_z_index_tablet":2,"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#FFC900"},"align_tablet":"center","align_mobile":"left","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_line_height_tablet":{"unit":"px","size":26,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":0,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"7d85a07","elType":"widget","settings":{"title":"salats","title_color":"#CD4414","typography_typography":"custom","typography_font_size":{"unit":"px","size":90,"sizes":[]},"typography_text_transform":"capitalize","typography_line_height":{"unit":"px","size":90,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-2.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":60,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-1.850000000000000088817841970012523233890533447265625,"sizes":[]},"_z_index":2,"_z_index_tablet":2,"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":2,"vertical":0,"blur":6,"color":"#FFC900"},"align_tablet":"center","align_mobile":"left","typography_font_size_mobile":{"unit":"px","size":48,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":55,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"0b191b1","elType":"widget","settings":{"editor":"new phenomenon burger taste","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":26,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":1.350000000000000088817841970012523233890533447265625,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index":2,"_z_index_tablet":2,"_element_width":"initial","_element_width_tablet":"initial","_element_custom_width":{"unit":"px","size":230,"sizes":[]},"_element_custom_width_tablet":{"unit":"px","size":300,"sizes":[]},"texteditor_shadow_text_shadow_type":"yes","texteditor_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#FFC900"},"align_tablet":"center","align_mobile":"left","typography_font_size_mobile":{"unit":"px","size":16,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":20,"sizes":[]},"_element_width_mobile":"initial","_element_custom_width_mobile":{"unit":"px","size":240,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"458e9e6","elType":"widget","settings":{"title":"$10.90","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":45,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"},"_z_index":2,"_z_index_tablet":2,"align_tablet":"center","align_mobile":"left","typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"c1517d1","elType":"widget","settings":{"text":"ORDER NOW","_z_index":2,"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/menu-restaurant\/","is_external":"","nofollow":"","custom_attributes":""},"_animation":"opal-move-up","animation_duration":"fast","background_color":"#FFFFFF","button_background_hover_color":"#000000","__globals__":{"button_background_hover_color":""},"align_tablet":"center","align_mobile":"left"},"elements":[],"widgetType":"button"},{"id":"17dbf6f","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_shape-8.png","id":2529},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-30,"sizes":[]},"_offset_y":{"unit":"px","size":-80,"sizes":[]},"_css_classes":"img-hover","_offset_x_end_tablet":{"unit":"px","size":-300,"sizes":[]},"_offset_x_end_mobile":{"unit":"px","size":-30,"sizes":[]}},"elements":[],"widgetType":"image"},{"id":"bb11c67","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_shape-4.png","id":965},"image_size":"full","_element_width":"initial","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-394,"sizes":[]},"_offset_orientation_v":"end","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"motion_fx_mouseTrack_direction":"negative","motion_fx_tilt_effect":"yes","motion_fx_tilt_speed":{"unit":"px","size":2,"sizes":[]},"_offset_y_end":{"unit":"px","size":-115,"sizes":[]},"width_tablet":{"unit":"px","size":500,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":-430,"sizes":[]},"_element_custom_width":{"unit":"px","size":680,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","_element_width_tablet":"initial","_element_width_mobile":"initial","_element_custom_width_tablet":{"unit":"px","size":450,"sizes":[]},"_element_custom_width_mobile":{"unit":"px","size":350,"sizes":[]},"_offset_x_end_mobile":{"unit":"px","size":-190,"sizes":[]},"_offset_y_end_tablet":{"unit":"px","size":0,"sizes":[]},"_offset_y_end_mobile":{"unit":"px","size":-35,"sizes":[]},"_animation":"opal-move-left","animation_duration":"fast","_animation_delay":200},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"865282a","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"299caaf","elType":"column","settings":{"_column_size":100,"_inline_size":null,"align":"space-between","space_between_widgets":0},"elements":[{"id":"8dee7c0","elType":"section","settings":{"layout":"full_width","gap":"no","content_position":"middle","structure":"20","html_tag":"div"},"elements":[{"id":"8e287d2","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"b84ed27","elType":"widget","settings":{"title":"Latest news","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"header_size":"h3","__globals__":{"title_color":"globals\/colors?id=accent"},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"ee284dd","elType":"column","settings":{"_column_size":50,"_inline_size":null,"align":"flex-end","align_mobile":"center","space_between_widgets":0},"elements":[{"id":"0918c43","elType":"widget","settings":{"icon_list":[{"text":"See all","selected_icon":{"value":"","library":""},"_id":"ac595d4","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/blog\/","is_external":"","nofollow":"","custom_attributes":""}}],"_element_width":"auto","_offset_orientation_h":"end","_offset_x":{"unit":"px","size":30,"sizes":[]},"_offset_x_end":{"size":507.17200000000002546585164964199066162109375,"unit":"px"},"__globals__":{"text_color":"globals\/colors?id=accent","text_color_hover":"globals\/colors?id=primary"},"_padding":{"unit":"px","top":"0","right":"6","bottom":"0","left":"0","isLinked":false},"_offset_y":{"size":18,"unit":"px"}},"elements":[],"widgetType":"icon-list"},{"id":"5075e4b","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-angle-right","library":"poco-icon"},"view":"stacked","shape":"square","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"size":{"unit":"px","size":12,"sizes":[]},"border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"_element_width":"auto","_offset_orientation_h":"end","__globals__":{"primary_color":"globals\/colors?id=secondary","hover_primary_color":""},"primary_color":"#00A149","_padding":{"unit":"px","top":"8","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon"}],"isInner":true}],"isInner":true},{"id":"9030153","elType":"widget","settings":{"posts_per_page":3,"pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","_margin":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"column":"3","column_tablet":"2","_margin_tablet":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"background_post_top_background":"classic","background_post_top_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_background_post.jpg","id":2378},"background_post_top_position":"center center","background_post_top_repeat":"no-repeat","background_post_top_size":"cover","enable_carousel":"yes","navigation":"none","_margin_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"poco-post-grid"}],"isInner":false}],"isInner":false}],"footerbuilder-3":[{"id":"e151791","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","custom_height":{"unit":"px","size":300,"sizes":[]},"structure":"30","background_background":"classic","background_position":"center center","background_repeat":"repeat","background_size":"auto","padding":{"unit":"px","top":"100","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"70","right":"0","bottom":"0","left":"0","isLinked":false},"background_color":"#FFFFFF","html_tag":"div"},"elements":[{"id":"ba847a6","elType":"column","settings":{"_column_size":33,"_inline_size":44,"_inline_size_tablet":35,"content_position":"center","space_between_widgets":0},"elements":[{"id":"18a5ec8","elType":"widget","settings":{"text":"Divider","color":"#EBEBEB","gap":{"unit":"px","size":0,"sizes":[]},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"divider"}],"isInner":false},{"id":"e0b3de8","elType":"column","settings":{"_column_size":33,"_inline_size":11.33200000000000073896444519050419330596923828125,"_inline_size_tablet":30,"_inline_size_mobile":100,"content_position":"center","space_between_widgets":0},"elements":[{"id":"b1e4e29","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/logo_footer.png","id":242},"image_size":"full"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"f82e995","elType":"column","settings":{"_column_size":33,"_inline_size":44,"_inline_size_tablet":35,"content_position":"center","space_between_widgets":0},"elements":[{"id":"a7c46bd","elType":"widget","settings":{"text":"Divider","color":"#EBEBEB","gap":{"unit":"px","size":0,"sizes":[]},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"e536872","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","structure":"40","background_background":"classic","background_position":"center center","background_repeat":"repeat","background_size":"auto","padding":{"unit":"px","top":"90","right":"30","bottom":"90","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"55","right":"15","bottom":"55","left":"15","isLinked":false},"background_color":"#FFFFFF","html_tag":"div"},"elements":[{"id":"27f6c26","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"40","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"95b278a","elType":"widget","settings":{"title":"Address","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"heading"},{"id":"3305550","elType":"widget","settings":{"editor":"570 8th Ave,<br>New York, NY 10018<br>United States","align":"center","text_color":"#808080"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"cc9c40d","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"be05208","elType":"widget","settings":{"title":"Book a table","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"heading"},{"id":"2a7404b","elType":"widget","settings":{"editor":"Dogfood och Sliders foodtruck. <br>Under Om oss kan ni l\u00e4sa","align":"center","text_color":"#808080","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"51fe398","elType":"widget","settings":{"title":"(850) 435-4155","align":"center","title_color":"#FFC222","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]}},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"e6bc773","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"47f6f1e","elType":"widget","settings":{"title":"Opening hours","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"heading"},{"id":"f65480a","elType":"widget","settings":{"editor":"<p>Monday - Friday: 8am - 4pm <br \/>Saturday: 9am - 5pm<\/p>","align":"center","text_color":"#808080","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"9f69204","elType":"widget","settings":{"social_icon_list":[{"social_icon":{"value":"fab fa-facebook","library":"fa-brands"},"_id":"c78d038","link":{"url":"https:\/\/www.facebook.com\/opalwordpress\/","is_external":"true","nofollow":"","custom_attributes":""}},{"social_icon":{"value":"fab fa-twitter","library":"fa-brands"},"_id":"e637b0c","link":{"url":"#","is_external":"true","nofollow":"","custom_attributes":""}},{"social_icon":{"value":"fab fa-youtube","library":"fa-brands"},"_id":"2308be0","link":{"url":"https:\/\/www.youtube.com\/user\/WPOpalTheme","is_external":"true","nofollow":"","custom_attributes":""}},{"_id":"1205e8e","link":{"url":"#","is_external":"true","nofollow":"","custom_attributes":""}}],"shape":"circle","icon_color":"custom","icon_primary_color":"#FFC222","icon_secondary_color":"#1E1D23","icon_size":{"unit":"px","size":12,"sizes":[]},"icon_padding":{"unit":"em","size":1,"sizes":[]},"icon_padding_tablet":{"unit":"em","size":0.6999999999999999555910790149937383830547332763671875,"sizes":[]},"icon_spacing":{"unit":"px","size":10,"sizes":[]},"hover_primary_color":"#EEAC00","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"__globals__":{"icon_primary_color":"globals\/colors?id=primary","hover_primary_color":"","icon_secondary_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"social-icons"}],"isInner":false},{"id":"14b1a34","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"f8751e3","elType":"widget","settings":{"title":"newsletter","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"heading"},{"id":"d664e67","elType":"widget","settings":{"editor":"Subscribe to the weekly newsletter for all <br>the latest updates","align":"center","text_color":"#808080","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"ae4acd0","elType":"widget","settings":{"form_name":"New Form","form_fields":[{"custom_id":"email","field_type":"email","required":"true","field_label":" Email","placeholder":"Your Email ...","width":"66","_id":"59b8ee3","width_mobile":"66"}],"show_labels":"","button_width":"33","button_width_mobile":"33","step_next_label":"Next","step_previous_label":"Previous","button_text":"Subscribe","email_to":"admin@admin.com","email_subject":"New message from \"poco\"","email_content":"[all-fields]","email_from":"email@dev.wpopal.com","email_from_name":"poco","email_to_2":"admin@admin.com","email_subject_2":"New message from \"poco\"","email_content_2":"[all-fields]","email_from_2":"email@dev.wpopal.com","email_from_name_2":"poco","email_reply_to_2":"admin@admin.com","success_message":"The form was sent successfully.","error_message":"An error occured.","required_field_message":"This field is required.","invalid_message":"There\'s something wrong. The form is invalid.","column_gap":{"unit":"px","size":"","sizes":[]},"row_gap":{"unit":"px","size":"","sizes":[]},"field_text_color":"#808080","field_background_color":"rgba(255, 255, 255, 0)","field_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"field_text_padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14,"sizes":[]},"button_background_color":"#FFC222","button_text_color":"#000000","button_background_hover_color":"#EEAC00","button_hover_color":"#000000","button_text_padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_padding":{"unit":"px","top":"6","right":"6","bottom":"6","left":"6","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","_border_radius":{"unit":"px","top":"3","right":"3","bottom":"3","left":"3","isLinked":true},"custom_css":".elementor-form{\n    margin: 0\n}","mailchimp_fields_map":[],"drip_fields_map":[],"activecampaign_fields_map":[],"getresponse_fields_map":[],"convertkit_fields_map":[],"mailerlite_fields_map":[],"button_border_radius":{"unit":"px","top":"3","right":"3","bottom":"3","left":"3","isLinked":true},"button_align":"end"},"elements":[],"widgetType":"form"}],"isInner":false}],"isInner":false},{"id":"ac8c8d6","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","height":"min-height","custom_height":{"unit":"px","size":90,"sizes":[]},"structure":"20","background_background":"classic","background_color":"#1E1D23","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"50","right":"15","bottom":"50","left":"15","isLinked":false},"custom_height_mobile":{"unit":"px","size":0,"sizes":[]},"html_tag":"div"},"elements":[{"id":"8749e93","elType":"column","settings":{"_column_size":50,"_inline_size":null,"content_position":"center","space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[{"id":"f0bb4db","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2020 <strong><a href=\"#\"><span style=\"color: #ffc222;\">pocofood<\/span><\/a><\/strong>. All Rights Reserved.<\/p>","align":"left","align_mobile":"center","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"8226cca","elType":"column","settings":{"_column_size":50,"_inline_size":null,"content_position":"center","space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"cec995a","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/footer_img1.png","id":323},"image_size":"full","align":"right","align_mobile":"center"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false}],"footerbuilder-2":[{"id":"cdcb4f8","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","custom_height":{"unit":"px","size":"","sizes":[]},"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/background_footer2a.jpg","id":3141},"background_position":"center center","background_repeat":"no-repeat","background_size":"cover","background_motion_fx_translateY_effect":"yes","background_motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"layout":"full_width","custom_height_mobile":{"unit":"px","size":300,"sizes":[]},"html_tag":"div","padding":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"50","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[{"id":"9ad0ae2","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"4419622","elType":"section","settings":{"content_width":{"unit":"px","size":740,"sizes":[]},"gap":"no","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"84b0bab","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"0a2d279","elType":"widget","settings":{"title":"Join For Hot Offers","align":"center","typography_font_size":{"unit":"px","size":24,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"title_color":"#1E1D23","__globals__":{"title_color":""},"typography_typography":"custom","typography_text_transform":"capitalize"},"elements":[],"widgetType":"heading"},{"id":"2fa3e34","elType":"widget","settings":{"form_name":"New Form","form_fields":[{"custom_id":"email","field_type":"email","required":"true","field_label":" Email","placeholder":"Enter email","width":"80","_id":"59b8ee3","width_mobile":"66"}],"show_labels":"","button_width":"20","button_width_mobile":"33","step_next_label":"Next","step_previous_label":"Previous","button_text":"Subscribe","email_to":"admin@admin.com","email_subject":"New message from \"poco\"","email_content":"[all-fields]","email_from":"email@dev.wpopal.com","email_from_name":"poco","email_to_2":"admin@admin.com","email_subject_2":"New message from \"poco\"","email_content_2":"[all-fields]","email_from_2":"email@dev.wpopal.com","email_from_name_2":"poco","email_reply_to_2":"admin@admin.com","success_message":"The form was sent successfully.","error_message":"An error occured.","required_field_message":"This field is required.","invalid_message":"There\'s something wrong. The form is invalid.","column_gap":{"unit":"px","size":"","sizes":[]},"row_gap":{"unit":"px","size":"","sizes":[]},"field_text_color":"#414141","field_background_color":"rgba(255, 255, 255, 0)","field_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"field_text_padding":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":false},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14,"sizes":[]},"button_background_color":"#FFC222","button_text_color":"#000000","button_background_hover_color":"#EEAC00","button_hover_color":"#FFF","button_text_padding":{"unit":"px","top":"20","right":"0","bottom":"20","left":"0","isLinked":false},"_padding":{"unit":"px","top":"7","right":"7","bottom":"7","left":"7","isLinked":true},"_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#262626","_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"custom_css":".elementor-form{\n    margin: 0\n}","_background_background":"classic","_background_color":"#FFFFFF","_padding_mobile":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"mailchimp_fields_map":[],"drip_fields_map":[],"activecampaign_fields_map":[],"getresponse_fields_map":[],"convertkit_fields_map":[],"mailerlite_fields_map":[],"__globals__":{"button_hover_color":""},"button_typography_text_transform":"uppercase","button_border_radius":{"unit":"px","top":"3","right":"3","bottom":"3","left":"3","isLinked":true}},"elements":[],"widgetType":"form"},{"id":"ddc822f","elType":"widget","settings":{"editor":"<p>\u00a0I have read and agree to the Privacy Policy.<\/p>","align":"center","typography_typography":"custom","_margin":{"unit":"px","top":"10","right":"0","bottom":"0","left":"0","isLinked":false},"__globals__":{"text_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"7e45e052","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","custom_height":{"unit":"px","size":300,"sizes":[]},"structure":"30","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/shape_dot.png","id":2832},"background_position":"center center","background_repeat":"repeat","background_size":"auto","padding":{"unit":"px","top":"100","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"70","right":"0","bottom":"0","left":"0","isLinked":false},"html_tag":"div","background_color":"#181818"},"elements":[{"id":"2e10c050","elType":"column","settings":{"_column_size":33,"_inline_size":44,"_inline_size_tablet":35,"content_position":"center","space_between_widgets":0},"elements":[{"id":"3440396b","elType":"widget","settings":{"text":"Divider","color":"#303030","gap":{"unit":"px","size":0,"sizes":[]},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"divider"}],"isInner":false},{"id":"3f508f5d","elType":"column","settings":{"_column_size":33,"_inline_size":11.33200000000000073896444519050419330596923828125,"_inline_size_tablet":30,"_inline_size_mobile":100,"content_position":"center","space_between_widgets":0},"elements":[{"id":"18fdccf2","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/logo_footer.png","id":242},"image_size":"full","_z_index":2},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"b205c97","elType":"column","settings":{"_column_size":33,"_inline_size":44,"_inline_size_tablet":35,"content_position":"center","space_between_widgets":0},"elements":[{"id":"18f10b5c","elType":"widget","settings":{"text":"Divider","color":"#303030","gap":{"unit":"px","size":0,"sizes":[]},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"16a8d2ff","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","structure":"40","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/shape_dot.png","id":2832},"background_position":"center center","background_repeat":"repeat","background_size":"auto","padding":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"55","right":"15","bottom":"55","left":"15","isLinked":false},"html_tag":"div","background_color":"#181818"},"elements":[{"id":"4d4133d7","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"40","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"15d20ee6","elType":"widget","settings":{"title":"Address","align":"center","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"23961a19","elType":"widget","settings":{"editor":"<p>570 8th Ave,<\/p><p>New York, NY 10018<br \/>United States<\/p>","align":"center","text_color":"#B0B0B0","typography_typography":"custom"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"80df9e3","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"3cdaed3","elType":"widget","settings":{"title":"Book a table","align":"center","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"8245589","elType":"widget","settings":{"editor":"Dogfood och Sliders foodtruck. <br>Under Om oss kan ni l\u00e4sa","align":"center","text_color":"#B0B0B0","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"387178c1","elType":"widget","settings":{"title":"(850) 435-4155","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=primary"}},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"6ed31ea3","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"7966a183","elType":"widget","settings":{"title":"Opening hours","align":"center","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"251c610d","elType":"widget","settings":{"editor":"<p>Monday - Friday: <span style=\"color: #ffffff;\">8am - 4pm<\/span> <br \/>Saturday: <span style=\"color: #ffffff;\">9am - 5pm<\/span><\/p>","align":"center","text_color":"#B0B0B0","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"58cb1543","elType":"widget","settings":{"social_icon_list":[{"social_icon":{"value":"fab fa-facebook","library":"fa-brands"},"_id":"c78d038","link":{"url":"https:\/\/www.facebook.com\/opalwordpress\/","is_external":"true","nofollow":"","custom_attributes":""}},{"social_icon":{"value":"fab fa-twitter","library":"fa-brands"},"_id":"e637b0c","link":{"url":"#","is_external":"true","nofollow":"","custom_attributes":""}},{"social_icon":{"value":"fab fa-youtube","library":"fa-brands"},"_id":"2308be0","link":{"url":"https:\/\/www.youtube.com\/user\/WPOpalTheme","is_external":"true","nofollow":"","custom_attributes":""}},{"_id":"1205e8e","link":{"url":"#","is_external":"true","nofollow":"","custom_attributes":""}}],"shape":"circle","icon_color":"custom","icon_primary_color":"#FFFFFF","icon_secondary_color":"#000000","icon_size":{"unit":"px","size":12,"sizes":[]},"icon_padding":{"unit":"em","size":1,"sizes":[]},"icon_padding_tablet":{"unit":"em","size":0.6999999999999999555910790149937383830547332763671875,"sizes":[]},"icon_spacing":{"unit":"px","size":10,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"__globals__":{"hover_primary_color":"globals\/colors?id=primary"}},"elements":[],"widgetType":"social-icons"}],"isInner":false},{"id":"27bd23","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"4fc55826","elType":"widget","settings":{"title":"newsletter","align":"center","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"295a3437","elType":"widget","settings":{"editor":"Subscribe to the weekly newsletter for all <br>the latest updates","align":"center","text_color":"#B0B0B0","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"2d9b0d32","elType":"widget","settings":{"form_name":"New Form","form_fields":[{"custom_id":"email","field_type":"email","required":"true","field_label":" Email","placeholder":"Your Email ...","width":"66","_id":"59b8ee3","width_mobile":"66"}],"show_labels":"","button_width":"33","button_width_mobile":"33","step_next_label":"Next","step_previous_label":"Previous","button_text":"Subscribe","email_to":"admin@admin.com","email_subject":"New message from \"poco\"","email_content":"[all-fields]","email_from":"email@dev.wpopal.com","email_from_name":"poco","email_to_2":"admin@admin.com","email_subject_2":"New message from \"poco\"","email_content_2":"[all-fields]","email_from_2":"email@dev.wpopal.com","email_from_name_2":"poco","email_reply_to_2":"admin@admin.com","success_message":"The form was sent successfully.","error_message":"An error occured.","required_field_message":"This field is required.","invalid_message":"There\'s something wrong. The form is invalid.","column_gap":{"unit":"px","size":"","sizes":[]},"row_gap":{"unit":"px","size":"","sizes":[]},"field_text_color":"#FFFFFF","field_background_color":"rgba(255, 255, 255, 0)","field_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"field_text_padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14,"sizes":[]},"button_background_color":"#FFC222","button_text_color":"#000000","button_background_hover_color":"#EEAC00","button_hover_color":"#FFFFFF","button_text_padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_padding":{"unit":"px","top":"6","right":"6","bottom":"6","left":"6","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#262626","_border_radius":{"unit":"px","top":"3","right":"3","bottom":"3","left":"3","isLinked":true},"custom_css":".elementor-form{\n    margin: 0\n}","mailchimp_fields_map":[],"drip_fields_map":[],"activecampaign_fields_map":[],"getresponse_fields_map":[],"convertkit_fields_map":[],"mailerlite_fields_map":[],"button_typography_text_transform":"capitalize","button_border_radius":{"unit":"px","top":"3","right":"3","bottom":"3","left":"3","isLinked":true}},"elements":[],"widgetType":"form"}],"isInner":false}],"isInner":false},{"id":"f4014f6","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","height":"min-height","custom_height":{"unit":"px","size":90,"sizes":[]},"structure":"20","background_background":"classic","background_color":"#00A850","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"50","right":"15","bottom":"50","left":"15","isLinked":false},"custom_height_mobile":{"unit":"px","size":0,"sizes":[]},"html_tag":"div"},"elements":[{"id":"7fc28a81","elType":"column","settings":{"_column_size":50,"_inline_size":null,"content_position":"center","space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[{"id":"3e8c9cfb","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2020 <a href=\"#\"><span style=\"color: #ffc222;\">pocofood<\/span><\/a>. All Rights Reserved.<\/p>","align":"left","align_mobile":"center","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"5a292068","elType":"column","settings":{"_column_size":50,"_inline_size":null,"content_position":"center","space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"724f5db6","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/footer_img1.png","id":323},"image_size":"full","align":"right","align_mobile":"center"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false}],"footerbuilder-1":[{"id":"6a93e41","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","custom_height":{"unit":"px","size":300,"sizes":[]},"structure":"30","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/shape_dot.png","id":2832},"background_position":"center center","background_repeat":"repeat","background_size":"auto","padding":{"unit":"px","top":"100","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"70","right":"0","bottom":"0","left":"0","isLinked":false},"html_tag":"div","background_color":"#181818"},"elements":[{"id":"b87eed8","elType":"column","settings":{"_column_size":33,"_inline_size":44,"_inline_size_tablet":35,"content_position":"center","space_between_widgets":0},"elements":[{"id":"87e368a","elType":"widget","settings":{"text":"Divider","color":"#303030","gap":{"unit":"px","size":0,"sizes":[]},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"divider"}],"isInner":false},{"id":"e8f9bfa","elType":"column","settings":{"_column_size":33,"_inline_size":11.33200000000000073896444519050419330596923828125,"_inline_size_tablet":30,"_inline_size_mobile":100,"content_position":"center","space_between_widgets":0},"elements":[{"id":"39d3d6a","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/logo_footer.png","id":242},"image_size":"full","_z_index":2},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"c96e8e3","elType":"column","settings":{"_column_size":33,"_inline_size":44,"_inline_size_tablet":35,"content_position":"center","space_between_widgets":0},"elements":[{"id":"8a1f74f","elType":"widget","settings":{"text":"Divider","color":"#303030","gap":{"unit":"px","size":0,"sizes":[]},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"767f29b","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","structure":"40","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/shape_dot.png","id":2832},"background_position":"center center","background_repeat":"repeat","background_size":"auto","padding":{"unit":"px","top":"90","right":"30","bottom":"90","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"55","right":"15","bottom":"55","left":"15","isLinked":false},"html_tag":"div","background_color":"#181818"},"elements":[{"id":"8e3017a","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"40","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"07ab53f","elType":"widget","settings":{"title":"Address","align":"center","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"d79e6ab","elType":"widget","settings":{"editor":"<p>570 8th Ave,<\/p><p>New York, NY 10018<br \/>United States<\/p>","align":"center","text_color":"#B0B0B0","typography_typography":"custom"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"be127cd","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"122488f","elType":"widget","settings":{"title":"Book a table","align":"center","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"46e739d","elType":"widget","settings":{"editor":"Dogfood och Sliders foodtruck. <br>Under Om oss kan ni l\u00e4sa","align":"center","text_color":"#B0B0B0","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"ffe8195","elType":"widget","settings":{"title":"(850) 435-4155","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=primary"}},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"b56da81","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"e820bf4","elType":"widget","settings":{"title":"Opening hours","align":"center","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"c96c212","elType":"widget","settings":{"editor":"<p>Monday - Friday: <span style=\"color: #ffffff;\">8am - 4pm<\/span> <br \/>Saturday: <span style=\"color: #ffffff;\">9am - 5pm<\/span><\/p>","align":"center","text_color":"#B0B0B0","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"1f00e8b","elType":"widget","settings":{"social_icon_list":[{"social_icon":{"value":"fab fa-facebook","library":"fa-brands"},"_id":"c78d038","link":{"url":"https:\/\/www.facebook.com\/opalwordpress\/","is_external":"true","nofollow":"","custom_attributes":""}},{"social_icon":{"value":"fab fa-twitter","library":"fa-brands"},"_id":"e637b0c","link":{"url":"#","is_external":"true","nofollow":"","custom_attributes":""}},{"social_icon":{"value":"fab fa-youtube","library":"fa-brands"},"_id":"2308be0","link":{"url":"https:\/\/www.youtube.com\/user\/WPOpalTheme","is_external":"true","nofollow":"","custom_attributes":""}},{"_id":"1205e8e","link":{"url":"#","is_external":"true","nofollow":"","custom_attributes":""}}],"shape":"circle","icon_color":"custom","icon_primary_color":"#FFFFFF","icon_secondary_color":"#000000","icon_size":{"unit":"px","size":12,"sizes":[]},"icon_padding":{"unit":"em","size":1,"sizes":[]},"icon_padding_tablet":{"unit":"em","size":0.6999999999999999555910790149937383830547332763671875,"sizes":[]},"icon_spacing":{"unit":"px","size":10,"sizes":[]},"__globals__":{"hover_primary_color":"globals\/colors?id=primary"}},"elements":[],"widgetType":"social-icons"}],"isInner":false},{"id":"ab48871","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"895f57d","elType":"widget","settings":{"title":"newsletter","align":"center","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"5c5698f","elType":"widget","settings":{"editor":"Subscribe to the weekly newsletter for all <br>the latest updates","align":"center","text_color":"#B0B0B0","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"52a6810","elType":"widget","settings":{"form_name":"New Form","form_fields":[{"custom_id":"email","field_type":"email","required":"true","field_label":" Email","placeholder":"Your Email ...","width":"66","_id":"59b8ee3","width_mobile":"66"}],"show_labels":"","button_width":"33","button_width_mobile":"33","step_next_label":"Next","step_previous_label":"Previous","button_text":"Subscribe","email_to":"admin@admin.com","email_subject":"New message from \"poco\"","email_content":"[all-fields]","email_from":"email@dev.wpopal.com","email_from_name":"poco","email_to_2":"admin@admin.com","email_subject_2":"New message from \"poco\"","email_content_2":"[all-fields]","email_from_2":"email@dev.wpopal.com","email_from_name_2":"poco","email_reply_to_2":"admin@admin.com","success_message":"The form was sent successfully.","error_message":"An error occured.","required_field_message":"This field is required.","invalid_message":"There\'s something wrong. The form is invalid.","column_gap":{"unit":"px","size":"","sizes":[]},"row_gap":{"unit":"px","size":"","sizes":[]},"field_text_color":"#FFFFFF","field_background_color":"rgba(255, 255, 255, 0)","field_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"field_text_padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14,"sizes":[]},"button_background_color":"#FFC222","button_text_color":"#000000","button_background_hover_color":"#EEAC00","button_hover_color":"#FFFFFF","button_text_padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_padding":{"unit":"px","top":"6","right":"6","bottom":"6","left":"6","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#262626","_border_radius":{"unit":"px","top":"3","right":"3","bottom":"3","left":"3","isLinked":true},"custom_css":".elementor-form{\n    margin: 0\n}","mailchimp_fields_map":[],"drip_fields_map":[],"activecampaign_fields_map":[],"getresponse_fields_map":[],"convertkit_fields_map":[],"mailerlite_fields_map":[],"button_typography_text_transform":"uppercase","button_border_radius":{"unit":"px","top":"3","right":"3","bottom":"3","left":"3","isLinked":true},"button_align":"end"},"elements":[],"widgetType":"form"}],"isInner":false}],"isInner":false},{"id":"9fed234","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","height":"min-height","custom_height":{"unit":"px","size":90,"sizes":[]},"structure":"20","background_background":"classic","background_color":"#00A850","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"50","right":"15","bottom":"50","left":"15","isLinked":false},"custom_height_mobile":{"unit":"px","size":0,"sizes":[]},"html_tag":"div"},"elements":[{"id":"70dd110","elType":"column","settings":{"_column_size":50,"_inline_size":null,"content_position":"center","space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[{"id":"4914e14","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2020 <a href=\"#\"><span style=\"color: #ffc222;\">pocofood<\/span><\/a>. All Rights Reserved.<\/p>","align":"left","align_mobile":"center","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"f3d3c5c","elType":"column","settings":{"_column_size":50,"_inline_size":null,"content_position":"center","space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"f9b0642","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/footer_img1.png","id":323},"image_size":"full","align":"right","align_mobile":"center"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false}],"headerbuilder-3":[{"id":"b35f925","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","background_background":"classic","background_color":"#1E1D23","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"hide_mobile":"hidden-phone","content_width":{"unit":"px","size":1820,"sizes":[]},"stretch_section":"section-stretched","padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"custom_css":"@media(min-width: 1600px){\n    selector{\n        padding-left: 50px;\n        padding-right: 50px;\n    }\n}","html_tag":"div"},"elements":[{"id":"e4b488b","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"242b16e","elType":"widget","settings":{"view":"inline","icon_list":[{"text":"CALL US: +381 65 666 6666","selected_icon":{"value":"poco-icon- poco-icon-mobile-android-alt","library":"poco-icon"},"_id":"813be61"},{"text":"71 Madison Ave","selected_icon":{"value":"poco-icon- poco-icon-map-marker-check","library":"poco-icon"},"_id":"5585adb"}],"space_between":{"unit":"px","size":40,"sizes":[]},"icon_color":"#FFFFFF","icon_self_align":"left","text_color":"#FFFFFF","text_indent":{"unit":"px","size":6,"sizes":[]},"icon_typography_typography":"custom","icon_typography_font_size":{"unit":"px","size":13,"sizes":[]},"custom_css":".elementor-icon-list-text{\n    padding-top: 2px;\n}"},"elements":[],"widgetType":"icon-list"}],"isInner":false},{"id":"394ae5f","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"d23e779","elType":"widget","settings":{"social_icon_list":[{"social_icon":{"value":"fab fa-facebook","library":"fa-brands"},"_id":"c78d038","link":{"url":"https:\/\/www.facebook.com\/opalwordpress\/","is_external":"true","nofollow":"","custom_attributes":""}},{"social_icon":{"value":"fab fa-twitter","library":"fa-brands"},"_id":"e637b0c","link":{"url":"#","is_external":"true","nofollow":"","custom_attributes":""}},{"social_icon":{"value":"fab fa-youtube","library":"fa-brands"},"_id":"2308be0","link":{"url":"https:\/\/www.youtube.com\/user\/WPOpalTheme","is_external":"true","nofollow":"","custom_attributes":""}},{"_id":"1205e8e","link":{"url":"#","is_external":"true","nofollow":"","custom_attributes":""}}],"shape":"circle","icon_color":"custom","icon_primary_color":"#FFFFFF00","icon_secondary_color":"#FFFFFF","icon_size":{"unit":"px","size":14,"sizes":[]},"icon_padding":{"unit":"em","size":1,"sizes":[]},"icon_padding_tablet":{"unit":"em","size":0.6999999999999999555910790149937383830547332763671875,"sizes":[]},"icon_spacing":{"unit":"px","size":"","sizes":[]},"__globals__":{"hover_primary_color":"","hover_secondary_color":"globals\/colors?id=primary"},"align":"right","hover_primary_color":"#FFC22200","hover_secondary_color":"#FFC222","_margin":{"unit":"px","top":"0","right":"-14","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false},{"id":"125474f","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","structure":"30","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"background_background":"classic","z_index":999,"__globals__":{"background_color":""},"padding_tablet":{"unit":"px","top":"10","right":"30","bottom":"10","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"10","right":"15","bottom":"10","left":"15","isLinked":false},"content_width":{"unit":"px","size":1820,"sizes":[]},"height":"min-height","custom_height":{"unit":"px","size":120,"sizes":[]},"custom_height_tablet":{"unit":"px","size":0,"sizes":[]},"custom_height_mobile":{"unit":"px","size":0,"sizes":[]},"html_tag":"div","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"css_classes":"sticky-header","sticky":"top","sticky_on":["desktop"],"sticky_effects_offset":90,"background_color":"#FFF","custom_css":"@media(min-width: 1600px){\n    selector{\n        padding-left: 50px;\n        padding-right: 50px;\n    }\n}"},"elements":[{"id":"33ee03b","elType":"column","settings":{"_column_size":33,"_inline_size":13.455999999999999516830939683131873607635498046875,"space_between_widgets":0,"_inline_size_tablet":100,"content_position":"center","align":"space-between","_inline_size_mobile":100,"padding_tablet":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"67ab468","elType":"widget","settings":{"_element_width":"auto","hide_desktop":"hidden-desktop"},"elements":[],"widgetType":"poco-vertical-menu"},{"id":"f963035","elType":"widget","settings":{"site_logo_aligrment":"left","_element_width":"auto","site_logo_width":{"unit":"px","size":125,"sizes":[]},"site_logo_width_mobile":{"unit":"px","size":"","sizes":[]}},"elements":[],"widgetType":"poco-site-logo"},{"id":"1aba23a","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-phone-plus","library":"poco-icon"},"link":{"url":"tel:1718-904-4450","is_external":"","nofollow":"","custom_attributes":""},"size":{"unit":"px","size":27,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"-10","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"-10","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_element_width_tablet":"auto","hide_desktop":"hidden-desktop","__globals__":{"primary_color":"","hover_primary_color":""},"primary_color":"#1E1D23"},"elements":[],"widgetType":"icon"}],"isInner":false},{"id":"107e844","elType":"column","settings":{"_column_size":33,"_inline_size":54.3539999999999992041921359486877918243408203125,"space_between_widgets":0,"content_position":"center","hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"8d88a8a","elType":"widget","settings":{"nav_menu_aligrment":"left","_padding":{"unit":"%","top":"0","right":"0","bottom":"0","left":"3","isLinked":false},"custom_css":"@media(max-width: 1300px){\n    selector .main-navigation{\n        text-align: left;\n    }\n}"},"elements":[],"widgetType":"poco-nav-menu"}],"isInner":false},{"id":"a9252f9","elType":"column","settings":{"_column_size":33,"_inline_size":31.946000000000001506350599811412394046783447265625,"space_between_widgets":0,"content_position":"center","align":"flex-end","custom_css":"selector .elementor-widget-wrap{\n    flex-wrap: nowrap;\n}","_inline_size_tablet":30,"_inline_size_mobile":30,"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone"},"elements":[{"id":"a577a61","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-scooter","library":"poco-icon"},"title_text":"Call and Order in","description_text":"+1 718-904-4450","position":"left","primary_color":"#00A149","icon_size":{"unit":"px","size":45,"sizes":[]},"title_bottom_space":{"unit":"px","size":0,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":13,"sizes":[]},"title_typography_font_weight":"500","description_color":"#FFC222","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":24,"sizes":[]},"description_typography_font_weight":"700","description_typography_line_height":{"unit":"em","size":1,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","custom_css":"\n@media(max-width: 1200px){\n    selector .elementor-icon-box-icon{\n    display: none;\n}\n}","__globals__":{"title_color":"globals\/colors?id=1d12e908","description_color":"globals\/colors?id=primary","primary_color":"globals\/colors?id=secondary"}},"elements":[],"widgetType":"icon-box"},{"id":"fe534fa","elType":"widget","settings":{"show_account":"yes","show_wishlist":"yes","show_cart":"yes","_element_width":"auto","_margin":{"unit":"px","top":"0","right":"-5","bottom":"0","left":"0","isLinked":false},"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone"},"elements":[],"widgetType":"poco-header-group"}],"isInner":false}],"isInner":false}],"headerbuilder-2":[{"id":"c5f1e0f","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","structure":"30","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"background_background":"classic","z_index":99,"__globals__":{"background_color":""},"background_color":"#1E1D23","padding_tablet":{"unit":"px","top":"20","right":"30","bottom":"20","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"10","right":"15","bottom":"10","left":"15","isLinked":false},"height":"min-height","custom_height":{"unit":"px","size":120,"sizes":[]},"css_classes":"sticky-header","sticky":"top","sticky_on":["desktop"],"sticky_effects_offset":90,"html_tag":"div","custom_height_tablet":{"unit":"px","size":0,"sizes":[]},"custom_height_mobile":{"unit":"px","size":0,"sizes":[]}},"elements":[{"id":"cd46426","elType":"column","settings":{"_column_size":33,"_inline_size":12,"space_between_widgets":0,"_inline_size_tablet":100,"content_position":"center","align":"space-between","_inline_size_mobile":100,"padding_tablet":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"663446d","elType":"widget","settings":{"_element_width":"auto","hide_desktop":"hidden-desktop","__globals__":{"icon_menu_color":"globals\/colors?id=26c59e90"}},"elements":[],"widgetType":"poco-vertical-menu"},{"id":"b0d6f03","elType":"widget","settings":{"site_logo_aligrment":"left","_element_width":"auto","site_logo_aligrment_mobile":"center","site_logo_width_mobile":{"unit":"px","size":"","sizes":[]},"site_logo_width":{"unit":"px","size":125,"sizes":[]}},"elements":[],"widgetType":"poco-site-logo"},{"id":"6b02bdd","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-phone-plus","library":"poco-icon"},"link":{"url":"tel:1718-904-4450","is_external":"","nofollow":"","custom_attributes":""},"size":{"unit":"px","size":27,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"-10","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"-10","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_element_width_tablet":"auto","hide_desktop":"hidden-desktop","__globals__":{"primary_color":""},"primary_color":"#FFFFFF"},"elements":[],"widgetType":"icon"}],"isInner":false},{"id":"3b9215c","elType":"column","settings":{"_column_size":33,"_inline_size":48.2950000000000017053025658242404460906982421875,"space_between_widgets":0,"content_position":"center","hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"0a6b4cb","elType":"widget","settings":{"nav_menu_aligrment":"left","sub_menu_color":"#1E1D23","__globals__":{"menu_title_color":"","menu_title_color_hover":"globals\/colors?id=primary","menu_title_color_action":"globals\/colors?id=primary"},"menu_item_color_hover":"#99999908","menu_item_color_action":"#99999908","menu_title_color":"#FFF","menu_title_color_hover":"#FFC222","menu_title_color_action":"#FFC222"},"elements":[],"widgetType":"poco-nav-menu"}],"isInner":false},{"id":"05eacbc","elType":"column","settings":{"_column_size":33,"_inline_size":39.368999999999999772626324556767940521240234375,"space_between_widgets":0,"content_position":"center","hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","align":"flex-end","margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"707ab05","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-scooter","library":"poco-icon"},"title_text":"Call and Order in","description_text":"+1 718-904-4450","position":"left","primary_color":"#00A149","icon_size":{"unit":"px","size":45,"sizes":[]},"title_bottom_space":{"unit":"px","size":0,"sizes":[]},"title_color":"#FFFFFF","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":13,"sizes":[]},"title_typography_font_weight":"500","description_color":"#FFC222","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":24,"sizes":[]},"description_typography_font_weight":"700","description_typography_line_height":{"unit":"em","size":1,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","custom_css":"\n@media(max-width: 1200px){\n    selector .elementor-icon-box-icon{\n    display: none;\n}\n}","__globals__":{"title_color":"","description_color":"globals\/colors?id=primary","primary_color":"globals\/colors?id=secondary"}},"elements":[],"widgetType":"icon-box"},{"id":"ea7e022","elType":"widget","settings":{"show_account":"yes","show_wishlist":"yes","show_cart":"yes","account_dark":"yes","style_dark":"yes","_element_width":"auto"},"elements":[],"widgetType":"poco-header-group"}],"isInner":false}],"isInner":false}],"headerbuilder-1":[{"id":"ac18908","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","background_background":"classic","background_color":"#1E1D23","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"hide_mobile":"hidden-phone","z_index":999,"html_tag":"div"},"elements":[{"id":"58091b2","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"08c9e1d","elType":"widget","settings":{"view":"inline","icon_list":[{"text":"CALL US: +381 65 666 6666","selected_icon":{"value":"poco-icon- poco-icon-mobile-android-alt","library":"poco-icon"},"_id":"813be61"},{"text":"71 Madison Ave","selected_icon":{"value":"poco-icon- poco-icon-map-marker-check","library":"poco-icon"},"_id":"5585adb"}],"space_between":{"unit":"px","size":40,"sizes":[]},"icon_color":"#FFFFFF","icon_self_align":"left","text_color":"#FFFFFF","text_indent":{"unit":"px","size":6,"sizes":[]},"icon_typography_typography":"custom","icon_typography_font_size":{"unit":"px","size":13,"sizes":[]},"custom_css":".elementor-icon-list-text{\n    padding-top: 2px;\n}"},"elements":[],"widgetType":"icon-list"}],"isInner":false},{"id":"1320fa4","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"9a5ce2e","elType":"widget","settings":{"social_icon_list":[{"social_icon":{"value":"fab fa-facebook","library":"fa-brands"},"_id":"c78d038","link":{"url":"https:\/\/www.facebook.com\/opalwordpress\/","is_external":"true","nofollow":"","custom_attributes":""}},{"social_icon":{"value":"fab fa-twitter","library":"fa-brands"},"_id":"e637b0c","link":{"url":"#","is_external":"true","nofollow":"","custom_attributes":""}},{"social_icon":{"value":"fab fa-youtube","library":"fa-brands"},"_id":"2308be0","link":{"url":"https:\/\/www.youtube.com\/user\/WPOpalTheme","is_external":"true","nofollow":"","custom_attributes":""}},{"_id":"1205e8e","link":{"url":"#","is_external":"true","nofollow":"","custom_attributes":""}}],"shape":"circle","icon_color":"custom","icon_primary_color":"#FFFFFF00","icon_secondary_color":"#FFFFFF","icon_size":{"unit":"px","size":14,"sizes":[]},"icon_padding":{"unit":"em","size":1,"sizes":[]},"icon_padding_tablet":{"unit":"em","size":0.6999999999999999555910790149937383830547332763671875,"sizes":[]},"icon_spacing":{"unit":"px","size":"","sizes":[]},"__globals__":{"hover_primary_color":"","hover_secondary_color":"globals\/colors?id=primary"},"align":"right","hover_primary_color":"#FFC22200","hover_secondary_color":"#FFC222","_margin":{"unit":"px","top":"0","right":"-14","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false},{"id":"c607fef","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","structure":"30","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"background_background":"classic","z_index":999,"__globals__":{"background_color":"globals\/colors?id=26c59e90"},"padding_tablet":{"unit":"px","top":"20","right":"30","bottom":"20","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"10","right":"15","bottom":"10","left":"15","isLinked":false},"height":"min-height","custom_height":{"unit":"px","size":120,"sizes":[]},"css_classes":"sticky-header","sticky":"top","sticky_on":["desktop"],"sticky_effects_offset":90,"custom_height_tablet":{"unit":"px","size":0,"sizes":[]},"custom_height_mobile":{"unit":"px","size":0,"sizes":[]},"html_tag":"div"},"elements":[{"id":"4c083a4","elType":"column","settings":{"_column_size":33,"_inline_size":12,"space_between_widgets":0,"_inline_size_tablet":100,"content_position":"center","align":"space-between","padding":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"_inline_size_mobile":100,"padding_tablet":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"589ba17","elType":"widget","settings":{"_element_width":"auto","hide_desktop":"hidden-desktop"},"elements":[],"widgetType":"poco-vertical-menu"},{"id":"0b6b736","elType":"widget","settings":{"site_logo_aligrment":"left","_element_width":"auto","_margin_tablet":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"site_logo_aligrment_mobile":"center","site_logo_width_mobile":{"unit":"px","size":"","sizes":[]},"site_logo_width":{"unit":"px","size":125,"sizes":[]}},"elements":[],"widgetType":"poco-site-logo"},{"id":"3573675","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-phone-plus","library":"poco-icon"},"link":{"url":"tel:1718-904-4450","is_external":"","nofollow":"","custom_attributes":""},"size":{"unit":"px","size":27,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"-10","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"-10","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_element_width_tablet":"auto","hide_desktop":"hidden-desktop","__globals__":{"primary_color":""},"primary_color":"#1E1D23"},"elements":[],"widgetType":"icon"}],"isInner":false},{"id":"dfdba4a","elType":"column","settings":{"_column_size":33,"_inline_size":48.91499999999999914734871708787977695465087890625,"space_between_widgets":0,"content_position":"center","hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"dee73e3","elType":"widget","settings":{"nav_menu_aligrment":"left"},"elements":[],"widgetType":"poco-nav-menu"}],"isInner":false},{"id":"c820b2a","elType":"column","settings":{"_column_size":33,"_inline_size":38.74900000000000233058017329312860965728759765625,"space_between_widgets":0,"content_position":"center","hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","align":"flex-end","margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"ad5e1db","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-scooter","library":"poco-icon"},"title_text":"Call and Order in","description_text":"+1 718-904-4450","position":"left","primary_color":"#00A149","icon_size":{"unit":"px","size":45,"sizes":[]},"title_bottom_space":{"unit":"px","size":0,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":13,"sizes":[]},"title_typography_font_weight":"500","description_color":"#FFC222","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":24,"sizes":[]},"description_typography_font_weight":"700","description_typography_line_height":{"unit":"em","size":1,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","custom_css":"\n@media(max-width: 1200px){\n    selector .elementor-icon-box-icon{\n    display: none;\n}\n}","__globals__":{"title_color":"globals\/colors?id=1d12e908","description_color":"globals\/colors?id=primary","primary_color":"globals\/colors?id=secondary"}},"elements":[],"widgetType":"icon-box"},{"id":"0b16593","elType":"widget","settings":{"show_account":"yes","show_wishlist":"yes","show_cart":"yes","_element_width":"auto","_margin":{"unit":"px","top":"0","right":"-10","bottom":"0","left":"0","isLinked":false},"show_search":"yes"},"elements":[],"widgetType":"poco-header-group"}],"isInner":false}],"isInner":false}],"our-history":[{"id":"8f2e847","elType":"section","settings":{"content_width":{"unit":"px","size":700,"sizes":[]},"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_mobile":{"unit":"px","top":"10","right":0,"bottom":"60","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"cccd108","elType":"column","settings":{"_column_size":100,"_inline_size":null,"align":"center","space_between_widgets":0},"elements":[{"id":"a93a55d","elType":"widget","settings":{"title":"About Our Food","header_size":"h4","align":"center","align_mobile":"center","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":32,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":20,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":24,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":25,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":28,"sizes":[]},"typography_font_weight":"400"},"elements":[],"widgetType":"heading"},{"id":"1074549","elType":"widget","settings":{"title":"Delivering Awesome  Since 1960","align":"center","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height":{"unit":"em","size":1.1999999999999999555910790149937383830547332763671875,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"_element_width":"initial","_element_custom_width":{"unit":"px","size":470,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"heading"},{"id":"da34b21","elType":"widget","settings":{"editor":"Time flies when you do what you love. We know because we\u2019ve been making great pizza since 1967. Along the way, we\u2019ve grown to more than 750 restaurants from coast to coast, becoming a trusted brand and leader in the foodservice industry. We\u2019re proud of the quality food we make \u2013 and the difference we make in communities across Canada. We\u2019ve made a lot of pies \u2013 and memories \u2013 over the years. Find out what goes into both!","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"_element_width":"initial"},"elements":[],"widgetType":"text-editor"},{"id":"80d0c2c","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/history_donh-poco.png","id":2007}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"41a0ac6","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"content_width":{"unit":"px","size":1635,"sizes":[]},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"56c87a8","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"1b6ba01","elType":"widget","settings":{"title":"Our History","header_size":"h3","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":34,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"e42f760","elType":"widget","settings":{"timeline_list":[{"number_year":"1960","title":"The beginning","content":"Tom Managhan and brother, James bough \u201cPocoNick\u2019s\u201d \u2013 a pizza restaurant at Ypsilanti Mich with the price of 500 dollar and changed its name to \u201cPoco , Inc\u201d","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/history_1960.jpg","id":2082},"_id":"09b6a92"},{"number_year":"1968","title":"Bad Luck","content":"In 1968, Poco Pizza headquarter burn down by fire. In 1975, Amstar Corp, a sugar supplier name Poco sued Poco\'s Pizza for the name of Poco.\n","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/history_1968.jpg","id":2083},"_id":"2c4ac09"},{"number_year":"1970","title":"Growing","content":"Poco Pizza opened more 954 stores, increased total stores to 2,841 and became the fastest-growing pizza chain in the United States.\nThe first Poco Pizza store opened in the United Kingdom, in Luton\nThe Deep Pan Pizza","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/history_1980.jpg","id":2084},"_id":"1d320e5"},{"number_year":"1990","title":"Online Order","content":"Poco Pizza opened more 954 stores, increased total stores to 2,841 and became the fastest-growing pizza chain in the United States.\nThe first Poco Pizza store opened in the United Kingdom, in Luton\nThe Deep Pan Pizza","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/history_1990.jpg","id":2085},"_id":"92237ba"},{"number_year":"2010","title":"2,000th Store","content":"Poco Pizza International opened its 2,000th store outside the United States. Domino\'s celebrates 40 years of development around the world. At the same time, global sales reach more than $ 3.54 billion.","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/history_2010.jpg","id":2086},"_id":"15237ed"},{"number_year":"2020","title":"60 Years Celebrating","content":"In 2010, Poco Pizza celebrated 50 years of operating. First store opened in Vietnam on 19 November 2010","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/history_2020.jpg","id":2087},"_id":"c70f72a"}],"title_typography_typography":"custom","title_typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"content_typography_typography":"custom","__globals__":{"title_color":"globals\/colors?id=accent"},"title_typography_font_size":{"unit":"px","size":35,"sizes":[]},"title_typography_line_height_tablet":{"unit":"px","size":30,"sizes":[]},"number_typography_typography":"custom","number_typography_font_size_mobile":{"unit":"px","size":24,"sizes":[]}},"elements":[],"widgetType":"poco-timeline"}],"isInner":false}],"isInner":false}],"menu-restaurant":[{"id":"8505588","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"z_index":2,"margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"26b20eb","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"afcb541","elType":"widget","settings":{"title":"Menus of the day","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":36,"sizes":[]},"typography_text_transform":"capitalize","typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"},"_animation":"opal-move-up","animation_duration":"fast","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"116f6b3","elType":"widget","settings":{"tabs":[{"tab_title":"pizza","_id":"8f6b32a","product_type":"best_selling","product_layout":"list","list_layout":"2"},{"tab_title":"sushi","limit":8,"orderby":"title","product_layout":"list","_id":"4db1d15","list_layout":"2"},{"tab_title":"salats","limit":8,"product_type":"best_selling","product_layout":"list","_id":"3243272","list_layout":"2"},{"tab_title":"burger","limit":8,"product_layout":"list","_id":"eb12372","list_layout":"2"},{"tab_title":"Dersest","limit":8,"product_layout":"list","_id":"9c18288","list_layout":"2"}],"column":"2","tab_header_padding":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"align_items":"center","header_margin":{"unit":"px","size":10,"sizes":[]},"title_color":"#1E1D23","border_tabs_radius":{"unit":"px","top":"28","right":"28","bottom":"28","left":"28","isLinked":true},"__globals__":{"tab_typography_typography":""},"tab_typography_typography":"custom","tab_typography_font_size":{"unit":"px","size":14,"sizes":[]},"tab_typography_text_transform":"uppercase","tab_title_spacing":{"unit":"px","size":90,"sizes":[]},"tab_title_vertical_padding":{"unit":"px","size":15,"sizes":[]},"title_hover_border_color":"#FFC222","title_background_active_color":"#FFC222","title_active_border_color":"#FFC222","border_tabs_title_border":"solid","border_tabs_title_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_tabs_title_color":"#EDEDED","tab_title_spacing_tablet":{"unit":"px","size":70,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","tab_title_padding":{"unit":"px","top":"20","right":"45","bottom":"20","left":"45","isLinked":false},"tab_typography_font_weight":"bold"},"elements":[],"widgetType":"poco-products-tabs"}],"isInner":false}],"isInner":false},{"id":"efaca61","elType":"section","settings":{"layout":"full_width","gap":"no","custom_height":{"unit":"px","size":664,"sizes":[]},"overflow":"hidden","stretch_section":"section-stretched","structure":"20","content_position":"middle","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"html_tag":"div"},"elements":[{"id":"bff4535","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image4-h4.jpg","id":737},"background_position":"top center","background_repeat":"no-repeat","background_overlay_background":"classic","background_overlay_repeat":"no-repeat","background_overlay_opacity":{"unit":"px","size":0.59999999999999997779553950749686919152736663818359375,"sizes":[]},"__globals__":{"background_overlay_color":"","background_color":""},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"background_size":"cover","background_color":"#000","background_overlay_color":"#000","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"d610e30","elType":"widget","settings":{"space":{"unit":"px","size":220,"sizes":[]},"space_tablet":{"unit":"px","size":150,"sizes":[]},"space_mobile":{"unit":"px","size":80,"sizes":[]}},"elements":[],"widgetType":"spacer"},{"id":"b47b43b","elType":"widget","settings":{"title":"Explore the new taste","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":52,"sizes":[]},"__globals__":{"title_color":""},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":6,"color":"#000000"},"title_color":"#FFF","_animation":"opal-move-up","animation_duration":"fast","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"d4bf2b6","elType":"widget","settings":{"editor":"<p>Enjoy our luscious dishes wherever you want<\/p>","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"__globals__":{"text_color":""},"texteditor_shadow_text_shadow_type":"yes","texteditor_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#000000"},"_animation":"opal-move-up","animation_duration":"fast","text_color":"#FFF"},"elements":[],"widgetType":"text-editor"},{"id":"535aa06","elType":"widget","settings":{"text":"ORDER NOW","align":"center","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"},{"id":"713265e","elType":"widget","settings":{"space":{"unit":"px","size":220,"sizes":[]},"space_tablet":{"unit":"px","size":150,"sizes":[]},"space_mobile":{"unit":"px","size":80,"sizes":[]}},"elements":[],"widgetType":"spacer"}],"isInner":false},{"id":"88b4a55","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/bg1-h4.png","id":734},"padding_tablet":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":true},"align":"space-between","padding":{"unit":"px","top":"0","right":"160","bottom":"0","left":"160","isLinked":false},"background_color":"#F7F4EF","padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false}},"elements":[{"id":"d7fa225","elType":"widget","settings":{"title":"Pizza Hut","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","__globals__":{"title_color":""},"_animation":"opal-move-up","animation_duration":"fast","title_color":"#1E1D23"},"elements":[],"widgetType":"heading"},{"id":"b35f65d","elType":"widget","settings":{"title":"$4.95","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"31a674a","elType":"widget","settings":{"style":"dashed","text":"Divider","color":"#CCCCCC","gap":{"unit":"px","size":5,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"divider"},{"id":"9c17123","elType":"widget","settings":{"editor":"<p>Shrimp, Squid, Pineapple<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"05650b5","elType":"widget","settings":{"title":"Pepperoni Pizza","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","__globals__":{"title_color":""},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150,"title_color":"#1E1D23"},"elements":[],"widgetType":"heading"},{"id":"c5ebf8b","elType":"widget","settings":{"title":"$5.95","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"heading"},{"id":"7b279d7","elType":"widget","settings":{"style":"dashed","text":"Divider","color":"#CCCCCC","gap":{"unit":"px","size":5,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"divider"},{"id":"263b873","elType":"widget","settings":{"editor":"<p>Shrimp, Squid, Pineapple<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"text-editor"},{"id":"dcfa870","elType":"widget","settings":{"title":"Apricot Chicken","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","__globals__":{"title_color":""},"title_color":"#1E1D23","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"heading"},{"id":"aeb27aa","elType":"widget","settings":{"title":"$5.65","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"heading"},{"id":"11d096c","elType":"widget","settings":{"style":"dashed","text":"Divider","color":"#CCCCCC","gap":{"unit":"px","size":5,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"divider"},{"id":"b648c21","elType":"widget","settings":{"editor":"<p>Shrimp, Squid, Pineapple<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"text-editor"},{"id":"57c771e","elType":"widget","settings":{"title":"Summer Pizza","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","__globals__":{"title_color":""},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":450,"title_color":"#1E1D23"},"elements":[],"widgetType":"heading"},{"id":"fec3223","elType":"widget","settings":{"title":"$8.95","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":450},"elements":[],"widgetType":"heading"},{"id":"acb92c0","elType":"widget","settings":{"style":"dashed","text":"Divider","color":"#CCCCCC","gap":{"unit":"px","size":5,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":450},"elements":[],"widgetType":"divider"},{"id":"43ad802","elType":"widget","settings":{"editor":"<p>Shrimp, Squid, Pineapple<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":450},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"9608719","elType":"section","settings":{"content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","stretch_section":"section-stretched","structure":"30","margin":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"9ca6f42","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_inline_size_tablet":50,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"9b4a792","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-scooter","library":"poco-icon"},"title_text":"Free shipping ","description_text":"Sign up for updates and get free shipping","position":"left","primary_color":"#FFC222","icon_space":{"unit":"px","size":30,"sizes":[]},"icon_size":{"unit":"px","size":68,"sizes":[]},"content_vertical_alignment":"middle","title_bottom_space":{"unit":"px","size":0,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_color":"#999999","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":14,"sizes":[]},"_padding":{"unit":"px","top":"22","right":"30","bottom":"22","left":"30","isLinked":false},"_border_border":"dashed","_border_color":"#E5E5E5","_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"__globals__":{"title_color":""},"hover_animation":"grow","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"_border_hover_border":"dashed","_border_hover_color":"#FFC200","_border_hover_transition":{"unit":"px","size":0.5,"sizes":[]},"icon_space_mobile":{"unit":"px","size":0,"sizes":[]},"title_color":"#000"},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"4ba6fc9","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_inline_size_tablet":50,"animation":"opal-move-up","animation_duration":"fast","animation_delay":150},"elements":[{"id":"ddd6ce1","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-time","library":"poco-icon"},"title_text":"30 Minutes Delivery","description_text":"Everything you order will quickly delivered to your door.","position":"left","primary_color":"#FFC222","icon_space":{"unit":"px","size":30,"sizes":[]},"icon_size":{"unit":"px","size":68,"sizes":[]},"content_vertical_alignment":"middle","title_bottom_space":{"unit":"px","size":0,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_color":"#999999","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":14,"sizes":[]},"_padding":{"unit":"px","top":"22","right":"30","bottom":"22","left":"30","isLinked":false},"_border_border":"dashed","_border_color":"#E5E5E5","_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"__globals__":{"title_color":""},"hover_animation":"grow","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"20","right":"14","bottom":"20","left":"20","isLinked":false},"_border_hover_border":"dashed","_border_hover_color":"#FFC200","_border_hover_transition":{"unit":"px","size":0.5,"sizes":[]},"icon_space_mobile":{"unit":"px","size":0,"sizes":[]},"title_color":"#000"},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"c064d2a","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_inline_size_tablet":100,"align_tablet":"center","animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"836c173","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-pizza","library":"poco-icon"},"title_text":"Best Quality Guarantee","description_text":"Poco is an international chain of family restaurants.","position":"left","primary_color":"#FFC222","icon_space":{"unit":"px","size":30,"sizes":[]},"icon_size":{"unit":"px","size":68,"sizes":[]},"content_vertical_alignment":"middle","title_bottom_space":{"unit":"px","size":0,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_color":"#999999","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":14,"sizes":[]},"_padding":{"unit":"px","top":"22","right":"30","bottom":"22","left":"30","isLinked":false},"_border_border":"dashed","_border_color":"#E5E5E5","_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"__globals__":{"title_color":""},"hover_animation":"grow","_padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"_element_width_tablet":"initial","_element_custom_width_tablet":{"unit":"%","size":50,"sizes":[]},"_element_width_mobile":"inherit","_border_hover_border":"dashed","_border_hover_color":"#FFC200","_border_hover_transition":{"unit":"px","size":0.5,"sizes":[]},"icon_space_mobile":{"unit":"px","size":0,"sizes":[]},"title_color":"#000"},"elements":[],"widgetType":"icon-box"}],"isInner":false}],"isInner":false}],"widgetsblog-2":[{"id":"8c0b83d","elType":"section","settings":{"gap":"no","background_background":"classic","border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"padding":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"__globals__":{"background_color":""},"background_color":"#FFC222","html_tag":"div"},"elements":[{"id":"ec5222d","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"2310118","elType":"widget","settings":{"editor":"<p>Super Delicious<\/p>","align":"center","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":32,"sizes":[]},"typography_line_height":{"unit":"px","size":30,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"__globals__":{"text_color":"globals\/colors?id=26c59e90"}},"elements":[],"widgetType":"text-editor"},{"id":"28a84f6","elType":"widget","settings":{"title":"Chicken","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":50,"sizes":[]},"typography_line_height":{"unit":"px","size":50,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"5","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=secondary"}},"elements":[],"widgetType":"heading"},{"id":"e9d77bc","elType":"widget","settings":{"title":"call us now:","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]},"typography_line_height":{"unit":"px","size":13,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=26c59e90"}},"elements":[],"widgetType":"heading"},{"id":"750c656","elType":"widget","settings":{"title":"1-800-555-333","align":"center","title_color":"#F00000","typography_typography":"custom","typography_font_size":{"unit":"px","size":22,"sizes":[]},"typography_line_height":{"unit":"px","size":25,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"3bf0e3b","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/widgets_blog2.png","id":1728},"image_size":"full"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false}],"traditional-soft-pretzels-with-sweet-beer-cheese":null,"the-ultimate-hangover-burger-egg-in-a-hole-burger-grilled-cheese":[{"id":"6d6a7d","elType":"section","settings":{"gap":"no","html_tag":"div"},"elements":[{"id":"495df43d","elType":"column","settings":{"_column_size":100},"elements":[{"id":"77c3871a","elType":"widget","settings":{"editor":"<p>Ac haca ullamcorper donec ante habi tasse donec imperdiet eturpis varius per a augue magna hac. Nec hac et vestibulum duis a tincidunt per a aptent interdum purus feugiat a id aliquet erat himenaeos nunc torquent euismod adipiscing adipiscing dui gravida justo.<!--more--><\/p><p>Ultrices ut parturient morbi sit adipiscing sit a habitasse curabitur viverra at malesuada at vestibulum. Leo duis lacinia placerat parturient montes vulputate cubilia posuere parturient inceptos massa euismod curabitur dis dignissim vestibulum quam a urna.<\/p>"},"elements":[],"widgetType":"text-editor"},{"id":"d4adc72","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/blog-663.jpg","id":3235},"image_size":"full","image_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"image"},{"id":"9bfd513","elType":"widget","settings":{"editor":"<p>Netus pretium tellus nulla commodo massa adipiscing in elementum magna congue condimentum placerat habitasse potenti ac orci a quisque tristique elementum et viverra at condimentum scelerisque eu mi. Elit praesent cras vehicula a ullamcorper nulla scelerisque aliquet tempus faucibus quam ac aliquet nibh a condimentum suspendisse hac integer leo erat aliquam ut himenaeos.<\/p>","_padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"_element_width":"initial","_element_custom_width":{"unit":"%","size":50,"sizes":[]},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_element_width_mobile":"inherit"},"elements":[],"widgetType":"text-editor"},{"id":"a39fa38","elType":"widget","settings":{"testimonial_content":"Quisque porttitor ipsum vitae fermentum suscipit. Praesent vel semper ello. ","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-2-1.jpg","id":354},"testimonial_name":"Nina Margaret","testimonial_job":"CHEF","testimonial_alignment":"left","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":24,"sizes":[]},"content_typography_line_height":{"unit":"em","size":1.399999999999999911182158029987476766109466552734375,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":14,"sizes":[]},"name_typography_font_weight":"700","name_typography_text_transform":"uppercase","job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":13,"sizes":[]},"job_typography_line_height":{"unit":"em","size":2,"sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"_element_width":"initial","_element_custom_width":{"unit":"%","size":50,"sizes":[]},"__globals__":{"content_content_color":"globals\/colors?id=accent","name_text_color":"globals\/colors?id=accent","job_text_color":"globals\/colors?id=1d12e908"},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_element_width_mobile":"inherit"},"elements":[],"widgetType":"testimonial"},{"id":"96e58e1","elType":"widget","settings":{"editor":"<p>Elit praesent cras vehicula a ullamcorper nulla scelerisque aliquet tempus faucibus quam ac aliquet nibh a condimentum suspendisse hac integer leo erat aliquam ut himenaeos.<\/p><p>Leo duis lacinia placerat parturient montes vulputate cubilia posuere parturient inceptos massa euismod curabitur dis dignissim vestibulum quam a urna.<\/p>"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"home-2":[{"id":"781af84","elType":"section","settings":{"gap":"no","height":"min-height","custom_height":{"unit":"px","size":740,"sizes":[]},"stretch_section":"section-stretched","background_background":"classic","background_color":"#FFFFFF","structure":"20","background_position":"center right","background_repeat":"no-repeat","background_overlay_background":"classic","background_overlay_color":"#FFFFFF00","background_overlay_color_b":"#000000","background_overlay_gradient_type":"radial","background_overlay_opacity":{"unit":"px","size":1,"sizes":[]},"custom_height_tablet":{"unit":"px","size":520,"sizes":[]},"background_position_tablet":"top right","background_bg_width_tablet":{"unit":"px","size":2,"sizes":[]},"padding":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"custom_height_mobile":{"unit":"px","size":400,"sizes":[]},"background_position_mobile":"bottom center","background_overlay_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_ellipse.png","id":1618},"content_position":"middle","overflow":"hidden","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h2_shape.jpg","id":1629},"background_size":"cover","background_overlay_position":"initial","background_overlay_position_tablet":"initial","background_overlay_position_mobile":"initial","background_overlay_xpos":{"unit":"%","size":120.5,"sizes":[]},"background_overlay_xpos_tablet":{"unit":"%","size":120,"sizes":[]},"background_overlay_xpos_mobile":{"unit":"%","size":130,"sizes":[]},"background_overlay_ypos":{"unit":"px","size":-305,"sizes":[]},"background_overlay_ypos_tablet":{"unit":"%","size":-20,"sizes":[]},"background_overlay_ypos_mobile":{"unit":"%","size":120,"sizes":[]},"background_overlay_repeat":"no-repeat","background_overlay_size_tablet":"initial","background_overlay_size_mobile":"initial","background_overlay_bg_width_tablet":{"unit":"px","size":500,"sizes":[]},"background_overlay_bg_width_mobile":{"unit":"px","size":320,"sizes":[]},"overlay_blend_mode":"multiply","margin":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"bfc05af","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"motion_fx_translateY_effect":"yes","motion_fx_devices":["desktop","tablet"]},"elements":[{"id":"0b74516","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_pepper.png","id":1619},"image_size":"full","_element_width":"initial","_element_width_tablet":"initial","_element_width_mobile":"initial","_element_custom_width":{"unit":"px","size":107,"sizes":[]},"_element_custom_width_tablet":{"unit":"px","size":80,"sizes":[]},"_element_custom_width_mobile":{"unit":"px","size":60,"sizes":[]},"_position":"absolute","_offset_orientation_h":"end","_offset_x_end_tablet":{"size":22,"unit":"px"},"_offset_y":{"unit":"px","size":-220,"sizes":[]},"_offset_y_tablet":{"size":-148,"unit":"px"},"_offset_y_mobile":{"unit":"px","size":-95,"sizes":[]},"motion_fx_motion_fx_mouse":"yes","motion_fx_mouseTrack_effect":"yes","motion_fx_mouseTrack_direction":"negative","motion_fx_mouseTrack_speed":{"unit":"px","size":0.5,"sizes":[]},"_animation":"bounceIn"},"elements":[],"widgetType":"image"},{"id":"643e8e9","elType":"widget","settings":{"title":"American","typography_typography":"custom","typography_font_size":{"unit":"px","size":72,"sizes":[]},"typography_line_height":{"unit":"px","size":75,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":48,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":55,"sizes":[]},"_z_index_tablet":3,"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":53,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"_animation":"opal-move-up","animation_duration":"fast","typography_text_transform":"uppercase","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":6,"color":"#000000"},"_z_index":3},"elements":[],"widgetType":"heading"},{"id":"66ce2b3","elType":"widget","settings":{"title":"Burger","typography_typography":"custom","typography_font_size":{"unit":"px","size":120,"sizes":[]},"typography_line_height":{"unit":"px","size":98,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":70,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":62,"sizes":[]},"_z_index_tablet":3,"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":62,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":53,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=primary"},"_animation":"opal-move-up","animation_duration":"fast","typography_text_transform":"uppercase","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":6,"color":"#FFFFFF"},"_z_index":3,"text_shadow_text_shadow_type":"yes"},"elements":[],"widgetType":"heading"},{"id":"c1ad34b","elType":"widget","settings":{"title":"Medium 2-topping* pizza","header_size":"h4","title_color":"#00A149","typography_typography":"custom","typography_font_size":{"unit":"px","size":32,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_z_index_tablet":3,"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":28,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":24,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_z_index":3},"elements":[],"widgetType":"heading"},{"id":"3d9eb93","elType":"widget","settings":{"editor":"*Additional charge for premium toppings. Minimum of 2 required.","text_color":"#515151","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":0.450000000000000011102230246251565404236316680908203125,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_z_index_tablet":3,"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":16,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":"","sizes":[]},"typography_line_height_mobile":{"unit":"px","size":22,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index":3},"elements":[],"widgetType":"text-editor"},{"id":"b8c1268","elType":"widget","settings":{"text":"ORDER NOW","size":"md","_margin":{"unit":"px","top":"0","right":"40","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","icon_indent":{"unit":"px","size":0,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_z_index_tablet":3,"_element_width_tablet":"inherit","align_mobile":"center","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"},{"id":"0adb331","elType":"widget","settings":{"title":"$12.99","header_size":"h3","title_color":"#00A149","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","_z_index_tablet":3,"typography_line_height":{"unit":"px","size":55,"sizes":[]},"_animation":"tada"},"elements":[],"widgetType":"heading"},{"id":"78e3779","elType":"widget","settings":{"title":"$19.99","header_size":"h5","title_color":"#1E1D2361","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_element_width":"auto","_z_index_tablet":3,"_animation":"rollIn","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"b196948","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_tomato.png","id":1622},"image_size":"full","width_tablet":{"unit":"px","size":130,"sizes":[]},"width_mobile":{"unit":"px","size":"","sizes":[]},"_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":-315,"sizes":[]},"_offset_x_tablet":{"unit":"px","size":-30,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end":{"unit":"px","size":-250,"sizes":[]},"_offset_y_end_tablet":{"unit":"px","size":-187,"sizes":[]},"_offset_y_end_mobile":{"unit":"%","size":90,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_speed":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"457ca46","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"align":"flex-end","align_mobile":"center"},"elements":[{"id":"203853d","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_basil.png","id":1616},"image_size":"full","_element_width":"initial","_element_width_tablet":"initial","_element_width_mobile":"initial","_element_custom_width":{"unit":"px","size":891,"sizes":[]},"_element_custom_width_tablet":{"unit":"px","size":600,"sizes":[]},"_element_custom_width_mobile":{"unit":"px","size":380,"sizes":[]},"_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-130,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":-90,"sizes":[]},"_offset_x_end_mobile":{"unit":"px","size":-20,"sizes":[]},"_offset_y":{"unit":"px","size":-134,"sizes":[]},"_offset_y_tablet":{"unit":"px","size":-53,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_speed":{"unit":"px","size":3,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"opal-scale-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"image"},{"id":"f576bb0","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_shallot.png","id":1620},"image_size":"full","_element_width":"initial","_element_width_tablet":"initial","_element_width_mobile":"initial","_element_custom_width":{"unit":"px","size":874,"sizes":[]},"_element_custom_width_tablet":{"unit":"px","size":580,"sizes":[]},"_element_custom_width_mobile":{"unit":"px","size":360,"sizes":[]},"_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-150,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":-90,"sizes":[]},"_offset_x_end_mobile":{"unit":"px","size":-20,"sizes":[]},"_offset_y":{"unit":"px","size":-4,"sizes":[]},"_offset_y_mobile":{"unit":"px","size":0,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_devices":["desktop","tablet"],"_animation":"opal-scale-up","animation_duration":"fast","_animation_delay":80},"elements":[],"widgetType":"image"},{"id":"702bbb3","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_pepper.png","id":1619},"image_size":"full","width_tablet":{"unit":"px","size":100,"sizes":[]},"width_mobile":{"unit":"px","size":80,"sizes":[]},"_element_custom_width":{"unit":"px","size":891,"sizes":[]},"_position":"absolute","_offset_x":{"unit":"px","size":60,"sizes":[]},"_offset_x_tablet":{"size":-67,"unit":"px"},"_offset_x_mobile":{"size":-138,"unit":"px"},"_offset_x_end":{"unit":"px","size":"","sizes":[]},"_offset_orientation_v":"end","_offset_y":{"unit":"px","size":-4,"sizes":[]},"_offset_y_end":{"unit":"px","size":-150,"sizes":[]},"_offset_y_end_tablet":{"size":-101.53100000000000591171556152403354644775390625,"unit":"px"},"_offset_y_end_mobile":{"size":275.9379999999999881765688769519329071044921875,"unit":"px"},"motion_fx_motion_fx_mouse":"yes","motion_fx_mouseTrack_effect":"yes","_animation":"rotateInDownRight"},"elements":[],"widgetType":"image"},{"id":"3e43d14","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_burger.png","id":1617},"image_size":"full","align":"right","_margin":{"unit":"px","top":"0","right":"-90","bottom":"0","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"-20","bottom":"0","left":"-58","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_z_index_tablet":2,"motion_fx_motion_fx_scrolling":"yes","motion_fx_rotateZ_effect":"yes","motion_fx_rotateZ_speed":{"unit":"px","size":0.59999999999999997779553950749686919152736663818359375,"sizes":[]},"motion_fx_rotateZ_affectedRange":{"unit":"%","size":"","sizes":{"start":0,"end":80}},"motion_fx_devices":["desktop","tablet"],"_animation":"bounceIn"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"b07e387","elType":"section","settings":{"gap":"no","content_position":"middle","stretch_section":"section-stretched","structure":"20","margin":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding":{"unit":"px","top":"64","right":"30","bottom":"0","left":"30","isLinked":false},"html_tag":"div","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"64","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"05fd269","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[{"id":"250b07d","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector6-h3.png","id":670},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":70,"sizes":[]},"_offset_y":{"unit":"px","size":-64,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":0,"sizes":[]},"_offset_x_end_mobile":{"size":-15,"unit":"px"},"_offset_y_mobile":{"size":-84,"unit":"px"},"motion_fx_devices":["desktop","tablet"],"motion_fx_motion_fx_mouse":"yes","motion_fx_mouseTrack_effect":"yes","_animation":"opal-scale-up","animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"68eadae","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_shape-2.png","id":1026},"image_size":"full","align":"left","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"-75","isLinked":false},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"bounce"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"b38a160","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"bd6d95d","elType":"widget","settings":{"title":"About Our Food","header_size":"h4","align_mobile":"center","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":32,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":26,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":30,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"324ed90","elType":"widget","settings":{"title":"From Texas with  American Love","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_line_height":{"unit":"px","size":68,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-1.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"},"typography_font_size_tablet":{"unit":"px","size":48,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":54,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-1.1999999999999999555910790149937383830547332763671875,"sizes":[]},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-1,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"e1c30ec","elType":"widget","settings":{"editor":"Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. ","_margin":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"},{"id":"ddaa043","elType":"widget","settings":{"text":"Order now","typography_text_transform":"uppercase","align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"7e55b62","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","structure":"30","background_background":"classic","background_color":"#FBF7E8","padding":{"unit":"px","top":"100","right":"30","bottom":"100","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"html_tag":"div","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"c5802fb","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100,"align_tablet":"center"},"elements":[{"id":"ed0ecec","elType":"widget","settings":{"title":"Choose what  you want, select  a pick up time","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_element_width":"initial","_element_custom_width":{"unit":"px","size":370,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"align_tablet":"center","typography_font_size_tablet":{"unit":"px","size":32,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_element_width_tablet":"initial","_element_custom_width_tablet":{"unit":"px","size":500,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":35,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"8036677","elType":"widget","settings":{"editor":"As well known and we are very busy all days advice you. advice you to call us of before arriving, so we can guarantee your seat.","_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_element_width":"initial","_element_custom_width":{"unit":"px","size":380,"sizes":[]},"align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_element_width_tablet":"initial","_element_custom_width_tablet":{"unit":"px","size":650,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"0c20182","elType":"widget","settings":{"text":"Order now","typography_text_transform":"uppercase","align_tablet":"center"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"0d8ac76","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100,"margin_tablet":{"unit":"px","top":"40","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"30c1909","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_pizza-delivery.png","id":1053},"image_size":"full","hover_animation":"pulse","_z_index":1,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"size":-45.921999999999997044142219237983226776123046875,"unit":"px"},"_offset_y":{"size":-10,"unit":"px"},"_offset_x_end_tablet":{"unit":"px","size":100,"sizes":[]},"width_mobile":{"unit":"px","size":130,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_offset_x_end_mobile":{"unit":"px","size":0,"sizes":[]},"_animation":"opal-scale-up","animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"83383b1","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_shipper.png","id":1054},"image_size":"full","align":"center","width":{"unit":"px","size":416,"sizes":[]},"_z_index":2,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateX_effect":"yes","motion_fx_translateX_direction":"negative","motion_fx_translateX_speed":{"unit":"px","size":3,"sizes":[]},"align_tablet":"left","motion_fx_devices":["desktop","tablet"],"_animation":"opal-move-right","animation_duration":"fast"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"a2856ed","elType":"column","settings":{"_column_size":33,"_inline_size":null,"align":"flex-end","space_between_widgets":0,"_inline_size_tablet":100,"align_tablet":"center"},"elements":[{"id":"9e4689e","elType":"widget","settings":{"title":"Earn points  every time you  order online","align":"right","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_element_width":"initial","_element_custom_width":{"unit":"px","size":370,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"align_tablet":"center","typography_font_size_tablet":{"unit":"px","size":32,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_element_width_tablet":"initial","_element_custom_width_tablet":{"unit":"px","size":500,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":35,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"55dfb1b","elType":"widget","settings":{"editor":"As well known and we are very busy all days advice you. advice you to call us of before arriving, so we can guarantee your seat.","align":"right","_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_element_width":"initial","_element_custom_width":{"unit":"px","size":380,"sizes":[]},"align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_element_width_tablet":"initial","_element_custom_width_tablet":{"unit":"px","size":650,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"e2948eb","elType":"widget","settings":{"text":"Order now","align":"right","typography_text_transform":"uppercase","align_tablet":"center"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"5e1d394","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"110","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"background_background":"classic","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"5bdf334","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"content_position":"center"},"elements":[{"id":"71c5dea","elType":"section","settings":{"layout":"full_width","gap":"no","content_position":"middle","structure":"20","html_tag":"div"},"elements":[{"id":"a4de32c","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"8c2f52b","elType":"widget","settings":{"title":"Popular dishes","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"header_size":"h3","__globals__":{"title_color":"globals\/colors?id=accent"},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"20003e1","elType":"column","settings":{"_column_size":50,"_inline_size":null,"align":"flex-end","align_mobile":"center","space_between_widgets":0},"elements":[{"id":"b6c78c3","elType":"widget","settings":{"icon_list":[{"text":"See all","selected_icon":{"value":"","library":""},"_id":"ac595d4","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/shop\/","is_external":"","nofollow":"","custom_attributes":""}}],"_element_width":"auto","_offset_orientation_h":"end","_offset_x":{"unit":"px","size":30,"sizes":[]},"_offset_x_end":{"size":507.17200000000002546585164964199066162109375,"unit":"px"},"__globals__":{"text_color":"globals\/colors?id=accent","text_color_hover":"globals\/colors?id=primary"},"_padding":{"unit":"px","top":"0","right":"6","bottom":"0","left":"0","isLinked":false},"_offset_y":{"size":18,"unit":"px"}},"elements":[],"widgetType":"icon-list"},{"id":"f0cd6ec","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-angle-right","library":"poco-icon"},"view":"stacked","shape":"square","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"size":{"unit":"px","size":12,"sizes":[]},"border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"_element_width":"auto","_offset_orientation_h":"end","__globals__":{"primary_color":"globals\/colors?id=secondary","hover_primary_color":""},"primary_color":"#00A149","_padding":{"unit":"px","top":"8","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon"}],"isInner":true}],"isInner":true},{"id":"d9c774c","elType":"widget","settings":{"limit":8,"column":"4","enable_carousel":"yes","navigation":"arrows","_margin":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"_z_index":2,"next_horizontal":"right","next_horizontal_value_tablet":{"unit":"px","size":-15,"sizes":[]},"prev_horizontal":"left","prev_horizontal_value_tablet":{"unit":"px","size":-15,"sizes":[]},"_margin_tablet":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"poco-products"},{"id":"b4d8b5b","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector2-h3.png","id":585},"image_size":"full","_z_index":1,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"_element_width":"auto","_position":"absolute","_offset_x":{"unit":"%","size":40.5,"sizes":[]},"_offset_y":{"unit":"%","size":50,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end":{"unit":"px","size":-60,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"opal-move-down","animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"a252b9d","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector3-h3.png","id":586},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"size":-122,"unit":"px"},"_offset_orientation_v":"end","_offset_y_end":{"size":-106,"unit":"px"},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"motion_fx_translateY_direction":"negative","motion_fx_devices":["desktop","tablet"],"_animation":"opal-move-down","animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"8f4343a","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector1-h3.png","id":584},"image_size":"full","_z_index":1,"_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":-103,"sizes":[]},"_offset_y":{"unit":"px","size":230,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end":{"unit":"px","size":44,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"opal-move-down","animation_duration":"fast"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"5d598ec","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","background_background":"classic","background_color":"#F7F2E2","padding":{"unit":"px","top":"100","right":"30","bottom":"100","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"e8808f9","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"71f1b78","elType":"widget","settings":{"title":"What  your client says","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"header_size":"h3","__globals__":{"title_color":"globals\/colors?id=accent"},"align_mobile":"center","_element_width_mobile":"inherit","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"align":"center"},"elements":[],"widgetType":"heading"},{"id":"b0cc3c5","elType":"widget","settings":{"testimonials":[{"testimonial_icon":"","testimonial_title":"","testimonial_content":"\u201cForget the trendy pizza shops, This hidden spot makes the best New York-style pizza slice in naples\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-2.jpg","id":2532},"testimonial_name":"Nina Margaret ","testimonial_job":"CEO,apple","_id":"44240e3","testimonial_rating":"4"},{"testimonial_icon":"","testimonial_title":"","testimonial_content":"\"I would be lost without restaurant. I would like to personally thank you for your outstanding product.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-1.jpg","id":2531},"testimonial_name":"Rose","testimonial_job":"Design","_id":"5211bae","testimonial_rating":5},{"testimonial_icon":"","testimonial_title":"","testimonial_content":"\"I am completely blown away. I would also like to say thank you to all your staff. It\'s really wonderful.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-4.jpg","id":2535},"testimonial_name":"Clara","testimonial_job":"Design","_id":"e8cf9d6","testimonial_rating":"3"},{"testimonial_title":"Testimonial title","testimonial_content":"\"I am completely blown away. I would also like to say thank you to all your staff. It\'s really wonderful.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-3.jpg","id":2534},"testimonial_name":"John Doe","testimonial_job":"Design","_id":"b11e9eb","testimonial_rating":5}],"testimonial_alignment":"left","column":"3","enable_carousel":"yes","padding_estimonial_wrapper":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":true},"color_testimonial_wrapper":"#FFFFFF","wrapper_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"image_margin":{"unit":"px","top":"0","right":"15","bottom":"25","left":"0","isLinked":false},"navigation":"both","padding_estimonial_wrapper_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"next_horizontal":"right","next_horizontal_value_tablet":{"unit":"px","size":0,"sizes":[]},"prev_horizontal":"left","prev_horizontal_value_tablet":{"unit":"px","size":0,"sizes":[]},"column_tablet":"2"},"elements":[],"widgetType":"poco-testimonials"}],"isInner":false}],"isInner":false},{"id":"ec5cc3b","elType":"section","settings":{"layout":"full_width","gap":"no","overflow":"hidden","stretch_section":"section-stretched","structure":"30","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"background_background":"classic","background_color":"#FFC900","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"html_tag":"div"},"elements":[{"id":"81dec0f","elType":"column","settings":{"_column_size":33,"_inline_size":32.030000000000001136868377216160297393798828125,"space_between_widgets":0,"background_background":"classic","background_color":"#00A850","padding":{"unit":"px","top":"80","right":"30","bottom":"55","left":"60","isLinked":false},"z_index":1,"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"50","right":"30","bottom":"50","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"537a027","elType":"widget","settings":{"title":"Fash Food","header_size":"h3","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"typography_font_family":"Norican","typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"_z_index":2,"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#00A850"},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_line_height_tablet":{"unit":"px","size":26,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"d40c760","elType":"widget","settings":{"title":"meals","title_color":"#FFCD02","typography_typography":"custom","typography_font_size":{"unit":"px","size":90,"sizes":[]},"typography_text_transform":"capitalize","typography_line_height":{"unit":"px","size":90,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-2.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"_z_index":2,"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":80,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-1.850000000000000088817841970012523233890533447265625,"sizes":[]},"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":2,"vertical":0,"blur":6,"color":"#00A850"},"typography_font_size_mobile":{"unit":"px","size":48,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":55,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"c10a2c8","elType":"widget","settings":{"editor":"new phenomenon <br> burger taste","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":26,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":1.350000000000000088817841970012523233890533447265625,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index":2,"texteditor_shadow_text_shadow_type":"yes","texteditor_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#00A850"},"typography_font_size_mobile":{"unit":"px","size":16,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":20,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"c0b09fa","elType":"widget","settings":{"title":"$19.90","title_color":"#FFCD02","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":45,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index":2,"typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"3786c66","elType":"widget","settings":{"text":"ORDER NOW","_z_index":2,"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/menu-restaurant\/","is_external":"","nofollow":"","custom_attributes":""},"_animation":"opal-move-up","animation_duration":"fast","background_color":"#FFFFFF","button_background_hover_color":"#000000","__globals__":{"button_background_hover_color":""}},"elements":[],"widgetType":"button"},{"id":"9a25d4d","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_shape-8.png","id":2529},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-30,"sizes":[]},"_offset_y":{"unit":"px","size":-80,"sizes":[]},"_css_classes":"img-hover"},"elements":[],"widgetType":"image"},{"id":"789c2da","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_shape-2.png","id":942},"image_size":"full","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_element_width":"initial","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"size":-364.875,"unit":"px"},"_offset_orientation_v":"end","motion_fx_tilt_effect":"yes","motion_fx_tilt_speed":{"unit":"px","size":2,"sizes":[]},"width_tablet":{"unit":"px","size":420,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":-180,"sizes":[]},"_offset_y_end_tablet":{"unit":"px","size":50,"sizes":[]},"_element_custom_width":{"unit":"px","size":629,"sizes":[]},"_offset_y_end":{"size":-39,"unit":"px"},"motion_fx_motion_fx_scrolling":"yes","_element_width_tablet":"initial","_element_width_mobile":"initial","_element_custom_width_tablet":{"unit":"px","size":380,"sizes":[]},"_element_custom_width_mobile":{"unit":"px","size":270,"sizes":[]},"_offset_x_end_mobile":{"unit":"px","size":-130,"sizes":[]},"_offset_y_end_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-left","animation_duration":"fast"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"c6629e4","elType":"column","settings":{"_column_size":33,"_inline_size":35.92999999999999971578290569595992565155029296875,"space_between_widgets":0,"background_background":"classic","background_color":"#DB731E","padding":{"unit":"px","top":"80","right":"30","bottom":"55","left":"60","isLinked":false},"z_index":2,"_inline_size_tablet":50,"content_position_tablet":"center","padding_tablet":{"unit":"px","top":"50","right":"30","bottom":"50","left":"30","isLinked":false},"background_position":"center right","background_repeat":"no-repeat","padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"60342bb","elType":"widget","settings":{"title":"House","header_size":"h3","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"typography_font_family":"Norican","typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#DB731E"},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_line_height_tablet":{"unit":"px","size":26,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"2047c30","elType":"widget","settings":{"title":"Burgers","title_color":"#FFCD02","typography_typography":"custom","typography_font_size":{"unit":"px","size":90,"sizes":[]},"typography_text_transform":"capitalize","typography_line_height":{"unit":"px","size":90,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-2.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"_z_index":2,"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":80,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-1.850000000000000088817841970012523233890533447265625,"sizes":[]},"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":2,"vertical":0,"blur":6,"color":"#DB731E"},"typography_font_size_mobile":{"unit":"px","size":48,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":55,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"5538722","elType":"widget","settings":{"editor":"new phenomenon <br> burger taste","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":26,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":1.350000000000000088817841970012523233890533447265625,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index":2,"texteditor_shadow_text_shadow_type":"yes","texteditor_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#DB731E"},"typography_font_size_mobile":{"unit":"px","size":16,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":20,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"a6c079a","elType":"widget","settings":{"title":"$12.90","title_color":"#FFCD02","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":45,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index":2,"typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"094123f","elType":"widget","settings":{"text":"ORDER NOW","_z_index":2,"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/menu-restaurant\/","is_external":"","nofollow":"","custom_attributes":""},"_animation":"opal-move-up","animation_duration":"fast","background_color":"#FFFFFF","button_background_hover_color":"#000000","__globals__":{"button_background_hover_color":""}},"elements":[],"widgetType":"button"},{"id":"80ea2e5","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_shape-8.png","id":2529},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-30,"sizes":[]},"_offset_y":{"unit":"px","size":-80,"sizes":[]},"_css_classes":"img-hover"},"elements":[],"widgetType":"image"},{"id":"358c297","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_shape-3.png","id":949},"image_size":"full","_element_width":"initial","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"size":-240,"unit":"px"},"_offset_orientation_v":"end","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"motion_fx_mouseTrack_direction":"negative","motion_fx_tilt_effect":"yes","motion_fx_tilt_direction":"negative","motion_fx_tilt_speed":{"unit":"px","size":2,"sizes":[]},"_offset_y_end":{"size":"","unit":"px"},"width_tablet":{"unit":"px","size":300,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":-130,"sizes":[]},"_element_custom_width":{"unit":"px","size":478,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","_element_width_tablet":"initial","_element_width_mobile":"initial","_element_custom_width_tablet":{"unit":"px","size":280,"sizes":[]},"_element_custom_width_mobile":{"unit":"px","size":240,"sizes":[]},"_animation":"opal-move-left","animation_duration":"fast","_animation_delay":100},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"001cfd6","elType":"column","settings":{"_column_size":33,"_inline_size":31.70400000000000062527760746888816356658935546875,"space_between_widgets":0,"background_background":"classic","background_color":"#FFC900","padding":{"unit":"px","top":"80","right":"30","bottom":"55","left":"60","isLinked":false},"z_index":2,"_inline_size_tablet":55,"padding_tablet":{"unit":"px","top":"50","right":"50","bottom":"50","left":"30","isLinked":false},"align_tablet":"center","align_mobile":"flex-start","padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"bf02271","elType":"widget","settings":{"title":"Hot  Fresh","header_size":"h3","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"typography_font_family":"Norican","typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"_z_index_tablet":2,"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#FFC900"},"align_tablet":"center","align_mobile":"left","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_line_height_tablet":{"unit":"px","size":26,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":0,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"55543fd","elType":"widget","settings":{"title":"salats","title_color":"#CD4414","typography_typography":"custom","typography_font_size":{"unit":"px","size":90,"sizes":[]},"typography_text_transform":"capitalize","typography_line_height":{"unit":"px","size":90,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-2.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":60,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-1.850000000000000088817841970012523233890533447265625,"sizes":[]},"_z_index":2,"_z_index_tablet":2,"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":2,"vertical":0,"blur":6,"color":"#FFC900"},"align_tablet":"center","align_mobile":"left","typography_font_size_mobile":{"unit":"px","size":48,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":55,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"f080863","elType":"widget","settings":{"editor":"new phenomenon burger taste","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":26,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":1.350000000000000088817841970012523233890533447265625,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_z_index":2,"_z_index_tablet":2,"_element_width":"initial","_element_width_tablet":"initial","_element_custom_width":{"unit":"px","size":230,"sizes":[]},"_element_custom_width_tablet":{"unit":"px","size":300,"sizes":[]},"texteditor_shadow_text_shadow_type":"yes","texteditor_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#FFC900"},"align_tablet":"center","align_mobile":"left","typography_font_size_mobile":{"unit":"px","size":16,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":20,"sizes":[]},"_element_width_mobile":"initial","_element_custom_width_mobile":{"unit":"px","size":240,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"504727e","elType":"widget","settings":{"title":"$10.90","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":45,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"},"_z_index":2,"_z_index_tablet":2,"align_tablet":"center","align_mobile":"left","typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"adb4581","elType":"widget","settings":{"text":"ORDER NOW","_z_index":2,"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/menu-restaurant\/","is_external":"","nofollow":"","custom_attributes":""},"_animation":"opal-move-up","animation_duration":"fast","background_color":"#FFFFFF","button_background_hover_color":"#000000","__globals__":{"button_background_hover_color":""},"align_tablet":"center","align_mobile":"left"},"elements":[],"widgetType":"button"},{"id":"3f85278","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_shape-8.png","id":2529},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-30,"sizes":[]},"_offset_y":{"unit":"px","size":-80,"sizes":[]},"_css_classes":"img-hover","_offset_x_end_tablet":{"unit":"px","size":-300,"sizes":[]},"_offset_x_end_mobile":{"unit":"px","size":-30,"sizes":[]}},"elements":[],"widgetType":"image"},{"id":"0ac7bf3","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_shape-4.png","id":965},"image_size":"full","_element_width":"initial","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-394,"sizes":[]},"_offset_orientation_v":"end","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"motion_fx_mouseTrack_direction":"negative","motion_fx_tilt_effect":"yes","motion_fx_tilt_speed":{"unit":"px","size":2,"sizes":[]},"_offset_y_end":{"unit":"px","size":-115,"sizes":[]},"width_tablet":{"unit":"px","size":500,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":-430,"sizes":[]},"_element_custom_width":{"unit":"px","size":680,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","_element_width_tablet":"initial","_element_width_mobile":"initial","_element_custom_width_tablet":{"unit":"px","size":450,"sizes":[]},"_element_custom_width_mobile":{"unit":"px","size":350,"sizes":[]},"_offset_x_end_mobile":{"unit":"px","size":-190,"sizes":[]},"_offset_y_end_tablet":{"unit":"px","size":0,"sizes":[]},"_offset_y_end_mobile":{"unit":"px","size":-35,"sizes":[]},"_animation":"opal-move-left","animation_duration":"fast","_animation_delay":200},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"0af0d59","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"background_background":"classic","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"e0df9c5","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"content_position":"center","align":"space-between"},"elements":[{"id":"c79915b","elType":"section","settings":{"layout":"full_width","gap":"no","content_position":"middle","structure":"20","html_tag":"div"},"elements":[{"id":"83b44c4","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"a4cb05c","elType":"widget","settings":{"title":"Best pizza ","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"header_size":"h3","__globals__":{"title_color":"globals\/colors?id=accent"},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"80c4954","elType":"column","settings":{"_column_size":50,"_inline_size":null,"align":"flex-end","align_mobile":"center","space_between_widgets":0},"elements":[{"id":"a5650b0","elType":"widget","settings":{"icon_list":[{"text":"See all","selected_icon":{"value":"","library":""},"_id":"ac595d4","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/shop\/","is_external":"","nofollow":"","custom_attributes":""}}],"_element_width":"auto","_offset_orientation_h":"end","_offset_x":{"unit":"px","size":30,"sizes":[]},"_offset_x_end":{"size":507.17200000000002546585164964199066162109375,"unit":"px"},"__globals__":{"text_color":"globals\/colors?id=accent","text_color_hover":"globals\/colors?id=primary"},"_padding":{"unit":"px","top":"0","right":"6","bottom":"0","left":"0","isLinked":false},"_offset_y":{"size":18,"unit":"px"}},"elements":[],"widgetType":"icon-list"},{"id":"3129062","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-angle-right","library":"poco-icon"},"view":"stacked","shape":"square","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"size":{"unit":"px","size":12,"sizes":[]},"border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"_element_width":"auto","_offset_orientation_h":"end","__globals__":{"primary_color":"globals\/colors?id=secondary","hover_primary_color":""},"primary_color":"#00A149","_padding":{"unit":"px","top":"8","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon"}],"isInner":true}],"isInner":true},{"id":"1891266","elType":"widget","settings":{"limit":8,"column":"4","navigation":"arrows","_margin":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"_z_index":2,"_margin_tablet":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"poco-products"},{"id":"620e81f","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector2-h3.png","id":585},"image_size":"full","_z_index":1,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"_element_width":"auto","_position":"absolute","_offset_x":{"unit":"%","size":40.5,"sizes":[]},"_offset_y":{"unit":"%","size":50,"sizes":[]},"_offset_y_end":{"unit":"%","size":45,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"opal-helix"},"elements":[],"widgetType":"image"},{"id":"e04c113","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector3-h3.png","id":586},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-122,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end":{"unit":"%","size":40,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"opal-move-down","animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"9c02183","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector1-h3.png","id":584},"image_size":"full","_z_index":1,"_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":-103,"sizes":[]},"_offset_y":{"unit":"px","size":320,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":1,"sizes":[]},"_offset_y_end":{"unit":"px","size":44,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_animation":"opal-move-down","animation_duration":"fast"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"41f4e50","elType":"section","settings":{"gap":"no","height":"min-height","custom_height":{"unit":"px","size":506,"sizes":[]},"overflow":"hidden","stretch_section":"section-stretched","structure":"20","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_bg.jpg","id":1115},"background_motion_fx_translateY_effect":"yes","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"padding":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"background_position":"center center","custom_height_tablet":{"unit":"px","size":420,"sizes":[]},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"reverse_order_mobile":"reverse-mobile","html_tag":"div","padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"d9bdaa0","elType":"column","settings":{"_column_size":50,"_inline_size":59.7000000000000028421709430404007434844970703125,"space_between_widgets":0,"_inline_size_tablet":45,"margin_mobile":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center"},"elements":[{"id":"019713f","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_50.png","id":1146},"image_size":"full","align":"right","_padding":{"unit":"px","top":"0","right":"140","bottom":"0","left":"0","isLinked":false},"width_tablet":{"unit":"px","size":150,"sizes":[]},"_margin_mobile":{"unit":"px","top":"-40","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"motion_fx_motion_fx_mouse":"yes","motion_fx_mouseTrack_effect":"yes","motion_fx_mouseTrack_speed":{"unit":"px","size":0.59999999999999997779553950749686919152736663818359375,"sizes":[]},"_animation":"tada","_animation_delay":150,"align_mobile":"center","_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"160","isLinked":false},"_z_index":2},"elements":[],"widgetType":"image"},{"id":"9ea7e1a","elType":"widget","settings":{"space":{"unit":"px","size":217,"sizes":[]}},"elements":[],"widgetType":"spacer"},{"id":"2889f50","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/h1_shape-7.png","id":2507},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":-450,"sizes":[]},"_offset_y":{"unit":"px","size":-205,"sizes":[]},"width_tablet":{"unit":"px","size":260,"sizes":[]},"width_mobile":{"unit":"px","size":120,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":3,"sizes":[]},"motion_fx_devices":["tablet"],"_animation":"opal-move-right","_offset_x_tablet":{"unit":"px","size":-30,"sizes":[]},"_offset_y_tablet":{"unit":"px","size":-125,"sizes":[]},"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone"},"elements":[],"widgetType":"image"},{"id":"d5d0df0","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_pizza.png","id":565},"image_size":"full","align":"left","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":-145,"sizes":[]},"_offset_y":{"unit":"px","size":60,"sizes":[]},"width":{"unit":"px","size":780,"sizes":[]},"width_mobile":{"unit":"px","size":350,"sizes":[]},"_z_index_mobile":2,"_offset_x_tablet":{"unit":"px","size":-60,"sizes":[]},"_offset_x_mobile":{"unit":"%","size":0,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":3,"sizes":[]},"motion_fx_devices":["desktop"],"_animation":"opal-scale-up","animation_duration":"fast","align_mobile":"center","_element_width_mobile":"inherit","_z_index":3},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"ca755cb","elType":"column","settings":{"_column_size":50,"_inline_size":40.2999999999999971578290569595992565155029296875,"space_between_widgets":0,"_inline_size_tablet":55,"content_position_tablet":"center","padding_tablet":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[{"id":"724042f","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_shape-4.png","id":1189},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-209,"sizes":[]},"_offset_y":{"unit":"px","size":-157,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":-100,"sizes":[]},"_offset_x_end_mobile":{"unit":"px","size":-120,"sizes":[]},"_offset_y_tablet":{"unit":"px","size":-102,"sizes":[]},"_offset_y_mobile":{"unit":"px","size":-70,"sizes":[]},"_animation":"rotateInDownRight"},"elements":[],"widgetType":"image"},{"id":"bbbc9ad","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_pizza-1.png","id":1193},"image_size":"full","width":{"unit":"px","size":880,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"-183","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"size":-300,"unit":"px"},"_offset_y":{"size":-525,"unit":"px"},"width_tablet":{"unit":"px","size":550,"sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":-100,"sizes":[]},"_offset_y_tablet":{"unit":"px","size":-380,"sizes":[]},"hide_mobile":"hidden-phone","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_speed":{"unit":"px","size":3,"sizes":[]},"_animation":"opal-move-down","animation_duration":"fast","hide_tablet":"hidden-tablet"},"elements":[],"widgetType":"image"},{"id":"5acbfef","elType":"widget","settings":{"title":"Super","header_size":"h3","title_color":"#FFFFFF","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":84,"sizes":[]},"typography_line_height":{"unit":"px","size":90,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":48,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":42,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":52,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":48,"sizes":[]},"_padding_mobile":{"unit":"px","top":"0","right":"80","bottom":"0","left":"0","isLinked":false},"_z_index_mobile":2,"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#000000"}},"elements":[],"widgetType":"heading"},{"id":"285e357","elType":"widget","settings":{"title":"Delicious","header_size":"h3","title_color":"#FFFFFF","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":84,"sizes":[]},"typography_line_height":{"unit":"px","size":90,"sizes":[]},"_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":177,"sizes":[]},"_offset_y":{"unit":"px","size":77,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":48,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":42,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":52,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":48,"sizes":[]},"_offset_x_tablet":{"unit":"px","size":115,"sizes":[]},"_offset_y_tablet":{"unit":"px","size":75,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_offset_y_mobile":{"unit":"px","size":43,"sizes":[]},"align_mobile":"center","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#000000"},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"80","isLinked":false},"_element_width_mobile":"inherit","_offset_x_mobile":{"unit":"px","size":0,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"7803df4","elType":"widget","settings":{"title":"Pizza","header_size":"h3","title_color":"#FFC222","typography_typography":"custom","typography_font_size":{"unit":"px","size":210,"sizes":[]},"typography_line_height":{"unit":"px","size":210,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"-9","isLinked":false},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":140,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":90,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":160,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"40","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#000000"}},"elements":[],"widgetType":"heading"},{"id":"d5ab3f8","elType":"widget","settings":{"title":"Feel Hunger! Order Your Favouriate Food.","header_size":"h4","title_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":22,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":25,"sizes":[]},"_z_index_mobile":2,"_animation":"opal-move-up","animation_duration":"fast","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#000000"}},"elements":[],"widgetType":"heading"},{"id":"31891e6","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_shape-5.png","id":1190},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-190,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end":{"unit":"px","size":-175,"sizes":[]},"_animation":"rotateIn"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"ba23f76","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"background_background":"classic","z_index":2,"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"efb9e89","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"content_position":"center","align":"space-between"},"elements":[{"id":"c2092f0","elType":"section","settings":{"layout":"full_width","gap":"no","content_position":"middle","structure":"20","html_tag":"div"},"elements":[{"id":"96e7c8f","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"f928af5","elType":"widget","settings":{"title":"Latest news","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":45,"sizes":[]},"header_size":"h3","__globals__":{"title_color":"globals\/colors?id=accent"},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"71c7203","elType":"column","settings":{"_column_size":50,"_inline_size":null,"align":"flex-end","align_mobile":"center","space_between_widgets":0},"elements":[{"id":"d3423eb","elType":"widget","settings":{"icon_list":[{"text":"See all","selected_icon":{"value":"","library":""},"_id":"ac595d4","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/blog\/","is_external":"","nofollow":"","custom_attributes":""}}],"_element_width":"auto","_offset_orientation_h":"end","_offset_x":{"unit":"px","size":30,"sizes":[]},"_offset_x_end":{"size":507.17200000000002546585164964199066162109375,"unit":"px"},"__globals__":{"text_color":"globals\/colors?id=accent","text_color_hover":"globals\/colors?id=primary"},"_padding":{"unit":"px","top":"0","right":"6","bottom":"0","left":"0","isLinked":false},"_offset_y":{"size":18,"unit":"px"}},"elements":[],"widgetType":"icon-list"},{"id":"eb56b29","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-angle-right","library":"poco-icon"},"view":"stacked","shape":"square","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"size":{"unit":"px","size":12,"sizes":[]},"border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"_element_width":"auto","_offset_orientation_h":"end","__globals__":{"primary_color":"globals\/colors?id=secondary","hover_primary_color":""},"primary_color":"#00A149","_padding":{"unit":"px","top":"8","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon"}],"isInner":true}],"isInner":true},{"id":"e88ed58","elType":"widget","settings":{"posts_per_page":3,"pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","_margin":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"column_tablet":"2","enable_carousel":"yes","_margin_tablet":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"poco-post-grid"}],"isInner":false}],"isInner":false}],"demo":[{"id":"d8483f4","elType":"section","settings":{"html_tag":"div"},"elements":[{"id":"9fc0276","elType":"column","settings":{"_column_size":100,"_inline_size":null},"elements":[{"id":"1148e6a","elType":"widget","settings":{"video_link":"https:\/\/www.youtube.com\/watch?v=dLC54mz--Dk","title":"play video","icon_font":"poco-icon-group-1"},"elements":[],"widgetType":"poco-video-popup"}],"isInner":false}],"isInner":false}],"blog":null,"home-4":[{"id":"4936975","elType":"section","settings":{"gap":"no","height":"min-height","custom_height":{"unit":"px","size":827,"sizes":[]},"stretch_section":"section-stretched","structure":"20","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/slider1-h4.jpg","id":1075},"background_repeat":"no-repeat","custom_height_tablet":{"unit":"px","size":0,"sizes":[]},"html_tag":"div"},"elements":[{"id":"96dd7de","elType":"column","settings":{"_column_size":50,"_inline_size":null,"align":"center","space_between_widgets":0,"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false}},"elements":[{"id":"49b1278","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/shap3-slider-h4.png","id":1166},"image_size":"full","width_tablet":{"unit":"%","size":55,"sizes":[]},"_animation":"opal-move-down","_animation_delay":700,"_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"%","size":-10,"sizes":[]},"_offset_x_end_tablet":{"unit":"%","size":-6,"sizes":[]},"_offset_y":{"unit":"%","size":-27,"sizes":[]},"_offset_y_tablet":{"unit":"%","size":-10,"sizes":[]},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"image"},{"id":"e336cd2","elType":"widget","settings":{"title":"Pene Salmone ","typography_typography":"custom","typography_font_size":{"unit":"px","size":72,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":120,"sizes":[]},"_padding":{"unit":"px","top":"0","right":"20","bottom":"30","left":"45","isLinked":false},"_background_background":"classic","_background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/shap1-slider-h4.png","id":1073},"_background_repeat":"no-repeat","__globals__":{"title_color":"globals\/colors?id=26c59e90"},"_animation":"opal-move-up","align_tablet":"center","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":30,"sizes":[]},"_padding_tablet":{"unit":"px","top":"0","right":"45","bottom":"42","left":"45","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_background_position_tablet":"center center","_background_size_mobile":"initial","_background_bg_width_mobile":{"unit":"px","size":0,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"63f9a15","elType":"widget","settings":{"title":"Sale 50% Start 22h:00","align":"center","title_color":"#00A149","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_line_height":{"unit":"px","size":80,"sizes":[]},"_margin":{"unit":"px","top":"-40","right":"0","bottom":"30","left":"0","isLinked":false},"_background_background":"classic","_background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/shap2-slider-h4.png","id":1074},"_background_position":"center center","_background_repeat":"no-repeat","__globals__":{"title_color":""},"_animation":"opal-move-up","_animation_delay":200,"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_background_size_mobile":"initial","_background_bg_width_mobile":{"unit":"px","size":0,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"68d90be","elType":"widget","settings":{"editor":"<p>Extra-virgin olive oil, garlic, mozzarella cheese, onions, mushrooms, green olives, black olives, fresh tomatoes.<\/p>","align":"center","typography_typography":"custom","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_element_width":"initial","_element_custom_width":{"unit":"%","size":50,"sizes":[]},"__globals__":{"text_color":""},"text_color":"#FFF","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_line_height":{"unit":"px","size":32,"sizes":[]},"_animation":"opal-move-up","_animation_delay":350,"_element_width_mobile":"inherit"},"elements":[],"widgetType":"text-editor"},{"id":"8106fea","elType":"widget","settings":{"text":"Order now","align":"center","_animation":"opal-move-up","_animation_delay":500},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"ce79bea","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[],"isInner":false}],"isInner":false},{"id":"ae5db1f","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","structure":"20","background_background":"classic","background_color":"#F7F4EF","padding":{"unit":"px","top":"100","right":"30","bottom":"100","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"80","left":"15","isLinked":false},"html_tag":"div"},"elements":[{"id":"600fe5b","elType":"column","settings":{"_column_size":50,"_inline_size":41.659999999999996589394868351519107818603515625,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"65","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"a4a0e73","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector1-h3.png","id":584},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"%","size":-40,"sizes":[]},"_offset_y":{"unit":"%","size":5,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes"},"elements":[],"widgetType":"image"},{"id":"0820d76","elType":"widget","settings":{"editor":"Wellome!","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_text_transform":"capitalize","align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"4eb938a","elType":"widget","settings":{"title":"Best burger ideas \n& traditions from the \nwhole world","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_line_height":{"unit":"px","size":60,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"__globals__":{"title_color":""},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"title_color":"#1E1D23","align_mobile":"center"},"elements":[],"widgetType":"heading"},{"id":"c362de2","elType":"widget","settings":{"editor":"Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"},{"id":"7d0861d","elType":"widget","settings":{"text":"Order now","align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"d4ed973","elType":"column","settings":{"_column_size":50,"_inline_size":58.340000000000003410605131648480892181396484375,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"60","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"df665e4","elType":"section","settings":{"gap":"no","structure":"20","html_tag":"div"},"elements":[{"id":"e989c5c","elType":"column","settings":{"_column_size":50,"_inline_size":41.659999999999996589394868351519107818603515625,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"30","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[{"id":"189fd86","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image1-h4.jpg","id":744},"image_size":"full","image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"hover_animation":"float","motion_fx_translateY_effect":"yes","_animation":"opal-move-up","_animation_delay":200,"align_mobile":"center","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"},{"id":"1c6af2a","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector2-h3.png","id":585},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"%","size":-40,"sizes":[]},"_offset_orientation_v":"end","_offset_y":{"unit":"%","size":-10,"sizes":[]},"_offset_y_end":{"unit":"%","size":20,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true},{"id":"0772046","elType":"column","settings":{"_column_size":50,"_inline_size":58.31099999999999994315658113919198513031005859375,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"10","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"3f29164","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image2-h4.jpg","id":745},"image_size":"full","image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"hover_animation":"float","motion_fx_translateY_speed":{"unit":"px","size":"","sizes":[]},"_animation":"opal-move-up","_animation_delay":400,"align_mobile":"center"},"elements":[],"widgetType":"image"},{"id":"c09eb93","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image3-h4.jpg","id":746},"image_size":"full","align":"left","image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"hover_animation":"float","motion_fx_translateY_effect":"yes","_animation":"opal-move-up","_animation_delay":600,"align_mobile":"center"},"elements":[],"widgetType":"image"},{"id":"f1b011a","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector3-h3.png","id":586},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x":{"unit":"%","size":-40,"sizes":[]},"_offset_y":{"unit":"%","size":45,"sizes":[]},"_offset_y_end":{"unit":"%","size":13,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"f204508","elType":"section","settings":{"layout":"full_width","gap":"no","custom_height":{"unit":"px","size":664,"sizes":[]},"overflow":"hidden","stretch_section":"section-stretched","structure":"20","content_position":"middle","html_tag":"div","margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"20","left":0,"isLinked":false}},"elements":[{"id":"da33c6b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image4-h4.jpg","id":737},"background_position":"top center","background_repeat":"no-repeat","background_overlay_background":"classic","background_overlay_repeat":"no-repeat","background_overlay_opacity":{"unit":"px","size":0.59999999999999997779553950749686919152736663818359375,"sizes":[]},"__globals__":{"background_overlay_color":"globals\/colors?id=48e5bc8c","background_color":"globals\/colors?id=48e5bc8c"},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"background_size":"cover","padding_mobile":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true}},"elements":[{"id":"9b66d49","elType":"widget","settings":{"space":{"unit":"px","size":200,"sizes":[]},"space_tablet":{"unit":"px","size":150,"sizes":[]},"space_mobile":{"unit":"px","size":80,"sizes":[]}},"elements":[],"widgetType":"spacer"},{"id":"f5f18c9","elType":"widget","settings":{"title":"Explore the new taste","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":52,"sizes":[]},"__globals__":{"title_color":""},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":6,"color":"#000000"},"title_color":"#FFF","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"4a638ed","elType":"widget","settings":{"editor":"<p>Enjoy our luscious dishes wherever you want<\/p>","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"__globals__":{"text_color":""},"texteditor_shadow_text_shadow_type":"yes","texteditor_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"#000000"},"_animation":"opal-move-up","animation_duration":"fast","text_color":"#FFF"},"elements":[],"widgetType":"text-editor"},{"id":"47ee89f","elType":"widget","settings":{"text":"ORDER NOW","align":"center","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"},{"id":"b055c44","elType":"widget","settings":{"space":{"unit":"px","size":200,"sizes":[]},"space_tablet":{"unit":"px","size":150,"sizes":[]},"space_mobile":{"unit":"px","size":80,"sizes":[]}},"elements":[],"widgetType":"spacer"}],"isInner":false},{"id":"696d710","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/bg1-h4.png","id":734},"padding_tablet":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":true},"align":"space-between","padding":{"unit":"px","top":"0","right":"160","bottom":"0","left":"160","isLinked":false},"padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false}},"elements":[{"id":"6ee9d48","elType":"widget","settings":{"title":"Pizza Hut","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","__globals__":{"title_color":"globals\/colors?id=accent"},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"c6b428f","elType":"widget","settings":{"title":"$4.95","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"72f1b9d","elType":"widget","settings":{"style":"dashed","text":"Divider","color":"#CCCCCC","gap":{"unit":"px","size":5,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"divider"},{"id":"e3fd612","elType":"widget","settings":{"editor":"<p>Shrimp, Squid, Pineapple<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"c0f4af0","elType":"widget","settings":{"title":"Pepperoni Pizza","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","__globals__":{"title_color":"globals\/colors?id=accent"},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"heading"},{"id":"dcc8c11","elType":"widget","settings":{"title":"$5.95","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"heading"},{"id":"e3701be","elType":"widget","settings":{"style":"dashed","text":"Divider","color":"#CCCCCC","gap":{"unit":"px","size":5,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"divider"},{"id":"f9e7cd5","elType":"widget","settings":{"editor":"<p>Shrimp, Squid, Pineapple<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"text-editor"},{"id":"1f08676","elType":"widget","settings":{"title":"Apricot Chicken","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","__globals__":{"title_color":""},"title_color":"#1E1D23","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"heading"},{"id":"79011ce","elType":"widget","settings":{"title":"$5.65","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"heading"},{"id":"65ae765","elType":"widget","settings":{"style":"dashed","text":"Divider","color":"#CCCCCC","gap":{"unit":"px","size":5,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"divider"},{"id":"21566dd","elType":"widget","settings":{"editor":"<p>Shrimp, Squid, Pineapple<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"text-editor"},{"id":"16304fe","elType":"widget","settings":{"title":"Summer Pizza","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","__globals__":{"title_color":"globals\/colors?id=accent"},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":450},"elements":[],"widgetType":"heading"},{"id":"9ea849f","elType":"widget","settings":{"title":"$8.95","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"_element_width":"auto","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":450},"elements":[],"widgetType":"heading"},{"id":"808201b","elType":"widget","settings":{"style":"dashed","text":"Divider","color":"#CCCCCC","gap":{"unit":"px","size":5,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":450},"elements":[],"widgetType":"divider"},{"id":"8fd3b26","elType":"widget","settings":{"editor":"<p>Shrimp, Squid, Pineapple<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":450},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"b55c980","elType":"section","settings":{"content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","stretch_section":"section-stretched","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image8-h4.png","id":1222},"padding":{"unit":"px","top":"90","right":"15","bottom":"110","left":"15","isLinked":false},"margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"15","bottom":"100","left":"15","isLinked":false},"overflow":"hidden","background_color":"#F7F4EF","background_position":"initial","background_ypos":{"unit":"%","size":120,"sizes":[]},"background_repeat":"no-repeat","background_motion_fx_translateY_effect":"yes","background_motion_fx_mouseTrack_effect":"yes","background_overlay_background":"classic","padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"80","left":"0","isLinked":false},"html_tag":"div"},"elements":[{"id":"d801db8","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"64da17e","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image5-h4.png","id":1219},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_animation":"opal-move-left","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x":{"size":0,"unit":"%"},"_offset_x_end":{"size":-25.5450000000000017053025658242404460906982421875,"unit":"%"},"_offset_y":{"size":-1.8810000000000000053290705182007513940334320068359375,"unit":"%"},"hide_mobile":"hidden-phone","hide_tablet":"hidden-tablet"},"elements":[],"widgetType":"image"},{"id":"001fe95","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image6-h4.png","id":1220},"image_size":"full","_z_index":0,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_animation":"opal-move-up","_animation_delay":600,"_element_width":"auto","_position":"absolute","_offset_x":{"size":-25,"unit":"%"},"_offset_x_end":{"unit":"%","size":-26,"sizes":[]},"_offset_orientation_v":"end","_offset_y":{"size":0,"unit":"px"},"_offset_y_end":{"unit":"%","size":-60,"sizes":[]},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"image"},{"id":"f8c650c","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image7-h4.png","id":1221},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_animation":"opal-move-right","_animation_delay":300,"_element_width":"auto","_position":"absolute","_offset_x":{"size":-25,"unit":"%"},"_offset_x_end":{"unit":"%","size":-26,"sizes":[]},"_offset_y":{"size":0,"unit":"px"},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"image"},{"id":"a505e59","elType":"widget","settings":{"editor":"always Quality","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":32,"sizes":[]},"typography_text_transform":"capitalize","align":"center","_animation":"opal-move-up","animation_duration":"fast","typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":30,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"000a62f","elType":"widget","settings":{"title":"Our Servcies","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":52,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"},"align":"center","_animation":"opal-move-up","animation_duration":"fast","typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"b64a102","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"30","html_tag":"div"},"elements":[{"id":"bec5381","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"background_background":"classic","border_radius":{"unit":"px","top":"4","right":"4","bottom":"4","left":"4","isLinked":true},"__globals__":{"background_color":""},"background_hover_background":"classic","background_hover_color":"#FBF7E8","background_color":"#FFF","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"577f48b","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-burger","library":"poco-icon"},"view":"stacked","title_text":"Quality Foods","description_text":"Everything you order will be quickly delivered to your door.","primary_color":"#FFC222","secondary_color":"#333333","hover_animation":"grow","icon_space":{"unit":"px","size":20,"sizes":[]},"icon_size":{"unit":"px","size":70,"sizes":[]},"icon_padding":{"unit":"px","size":20,"sizes":[]},"title_color":"#1E1D23","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20,"sizes":[]},"title_typography_text_transform":"uppercase","description_color":"#808080","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":15,"sizes":[]},"_padding":{"unit":"px","top":"40","right":"60","bottom":"40","left":"60","isLinked":false},"__globals__":{"_background_color":""},"_padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"icon_size_tablet":{"unit":"px","size":50,"sizes":[]}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"079041d","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"background_background":"classic","border_radius":{"unit":"px","top":"4","right":"4","bottom":"4","left":"4","isLinked":true},"margin_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"__globals__":{"background_color":""},"background_hover_background":"classic","background_hover_color":"#FBF7E8","background_color":"#FFF","animation":"opal-move-up","animation_duration":"fast","animation_delay":150},"elements":[{"id":"d2c3cd0","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-chicken","library":"poco-icon"},"view":"stacked","title_text":"Original Recipes","description_text":"Poco is an international chain of family restaurants.","primary_color":"#FFC222","secondary_color":"#333333","hover_animation":"grow","icon_space":{"unit":"px","size":20,"sizes":[]},"icon_size":{"unit":"px","size":70,"sizes":[]},"icon_padding":{"unit":"px","size":20,"sizes":[]},"title_color":"#1E1D23","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20,"sizes":[]},"title_typography_text_transform":"uppercase","description_color":"#808080","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":15,"sizes":[]},"_padding":{"unit":"px","top":"40","right":"60","bottom":"40","left":"60","isLinked":false},"__globals__":{"_background_color":""},"_padding_tablet":{"unit":"px","top":"30","right":"20","bottom":"30","left":"20","isLinked":false},"icon_size_tablet":{"unit":"px","size":50,"sizes":[]}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"5b9c271","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"background_background":"classic","border_radius":{"unit":"px","top":"4","right":"4","bottom":"4","left":"4","isLinked":true},"__globals__":{"background_color":""},"background_hover_background":"classic","background_hover_color":"#FBF7E8","background_color":"#FFF","animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"12992f3","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-food-delivery","library":"poco-icon"},"view":"stacked","title_text":"fast delivery","description_text":"Sign up for updates and get free shipping","primary_color":"#FFC222","secondary_color":"#333333","hover_animation":"grow","icon_space":{"unit":"px","size":20,"sizes":[]},"icon_size":{"unit":"px","size":70,"sizes":[]},"icon_padding":{"unit":"px","size":20,"sizes":[]},"title_color":"#1E1D23","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20,"sizes":[]},"title_typography_text_transform":"uppercase","description_color":"#808080","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":15,"sizes":[]},"_padding":{"unit":"px","top":"40","right":"60","bottom":"40","left":"60","isLinked":false},"__globals__":{"_background_color":""},"_padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"icon_size_tablet":{"unit":"px","size":50,"sizes":[]}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"cbceeaa","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"cb09cff","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"29aab29","elType":"widget","settings":{"title":"Popular dishes","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","__globals__":{"title_color":"globals\/colors?id=accent"},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"4292154","elType":"widget","settings":{"tabs":[{"tab_title":"pizza","_id":"8f6b32a","limit":8,"product_type":"best_selling"},{"tab_title":"sushi","limit":8,"orderby":"title","_id":"4db1d15"},{"tab_title":"salats","limit":8,"product_type":"best_selling","_id":"3243272"},{"tab_title":"burger","limit":8,"_id":"eb12372"},{"tab_title":"Dersest","limit":8,"_id":"9c18288"}],"column":"4","tab_header_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"align_items":"center","header_margin":{"unit":"px","size":10,"sizes":[]},"title_color":"#1E1D23","border_tabs_radius":{"unit":"px","top":"28","right":"28","bottom":"28","left":"28","isLinked":true},"__globals__":{"tab_typography_typography":""},"tab_typography_typography":"custom","tab_typography_font_family":"Lilita One","tab_typography_font_size":{"unit":"px","size":14,"sizes":[]},"tab_typography_text_transform":"uppercase","tab_title_spacing":{"unit":"px","size":90,"sizes":[]},"tab_title_vertical_padding":{"unit":"px","size":15,"sizes":[]},"title_hover_border_color":"#FFC222","title_background_active_color":"#FFC222","title_active_border_color":"#FFC222","border_tabs_title_border":"solid","border_tabs_title_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_tabs_title_color":"#EDEDED","column_tablet":"3","tab_title_spacing_tablet":{"unit":"px","size":70,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","header_margin_tablet":{"unit":"px","size":6,"sizes":[]},"tab_title_padding":{"unit":"px","top":"20","right":"45","bottom":"20","left":"45","isLinked":false},"tab_header_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"poco-products-tabs"},{"id":"bd1ac7a","elType":"widget","settings":{"text":"All products ","align":"center","_animation":"opal-move-up","animation_duration":"fast","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/shop\/","is_external":"","nofollow":"","custom_attributes":""}},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"0852d24","elType":"section","settings":{"content_width":{"unit":"px","size":1070,"sizes":[]},"gap":"no","height":"min-height","custom_height":{"unit":"px","size":420,"sizes":[]},"stretch_section":"section-stretched","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/bg3-h4.jpg","id":736},"background_repeat":"no-repeat","background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","background_overlay_background":"classic","background_overlay_opacity":{"unit":"px","size":0.59999999999999997779553950749686919152736663818359375,"sizes":[]},"margin":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"__globals__":{"background_overlay_color":"globals\/colors?id=48e5bc8c"},"custom_height_tablet":{"unit":"px","size":380,"sizes":[]},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"animation_duration":"fast","html_tag":"div","padding":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"49b69de","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"a701f43","elType":"widget","settings":{"testimonials":[{"testimonial_icon":"fa fa-quote-left","testimonial_title":"","testimonial_content":"\u201cForget the trendy pizza shops, This hidden spot makes the best New York-style pizza slice in naples\u201d","testimonial_name":"Stephen Tindle","testimonial_job":"CEO,apple","testimonial_rating":"4","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-1.jpg","id":2531},"_id":"c4af6a8"},{"testimonial_title":"","testimonial_content":"\"I would be lost without restaurant. I would like to personally thank you for your outstanding product.\"","testimonial_name":"Nina Margaret ","testimonial_job":"CEO,apple","_id":"362dce0","testimonial_icon":"fa fa-quote-left","testimonial_rating":"5","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-2.jpg","id":2532}},{"testimonial_rating":"4","testimonial_content":"\"I am completely blown away. I would also like to say thank you to all your staff. It\'s really wonderful.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-4.jpg","id":2535},"testimonial_name":"Clara","testimonial_job":"Manager","_id":"4caa9d3"},{"testimonial_rating":"5","testimonial_content":"\"Without food, we would have gone bankrupt by now. Thanks food! The service was excellent.\"","testimonial_name":"John Doe","testimonial_job":"Manager","_id":"2966dc3","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-3.jpg","id":2534}}],"padding_estimonial_wrapper":{"unit":"%","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"icon_color":"#FFCC00","icon_size":{"unit":"px","size":40,"sizes":[]},"name_text_color":"#FFFFFF","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_text_transform":"uppercase","enable_carousel":"yes","__globals__":{"content_content_color":"globals\/colors?id=26c59e90"},"navigation":"both","_animation":"opal-move-up","animation_duration":"fast","icon_spacing":{"unit":"px","size":0,"sizes":[]},"content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":30,"sizes":[]},"button_color":"#FFFFFF","testimonial_style":"style2","content_typography_font_weight":"normal","name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"name_padding":{"unit":"px","top":"25","right":"0","bottom":"3","left":"0","isLinked":false},"button_color_normal":"#FFFFFF42","padding_estimonial_wrapper_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"content_typography_line_height":{"unit":"px","size":42,"sizes":[]},"content_spacing":{"unit":"px","size":15,"sizes":[]},"image_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"name_typography_line_height":{"unit":"px","size":20,"sizes":[]},"job_text_color":"#FFFFFF","job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":15,"sizes":[]}},"elements":[],"widgetType":"poco-testimonials"}],"isInner":false}],"isInner":false},{"id":"98ed1a2","elType":"section","settings":{"gap":"no","content_position":"middle","stretch_section":"section-stretched","structure":"20","margin":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"20","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"334e049","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"align_mobile":"center","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"5","left":"0","isLinked":false}},"elements":[{"id":"8fcb324","elType":"widget","settings":{"title":"Our Talented Chefs","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"_element_width":"auto","typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"e5b888b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"align":"flex-end","space_between_widgets":0,"align_mobile":"center"},"elements":[{"id":"b76c10b","elType":"widget","settings":{"icon_list":[{"text":"See all","selected_icon":{"value":"","library":""},"_id":"ac595d4","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/our-teams\/","is_external":"","nofollow":"","custom_attributes":""}}],"_element_width":"auto","_offset_orientation_h":"end","_offset_x":{"unit":"px","size":30,"sizes":[]},"_offset_x_end":{"unit":"px","size":30,"sizes":[]},"__globals__":{"text_color":"globals\/colors?id=accent","text_color_hover":"globals\/colors?id=primary"},"_padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-list"},{"id":"b9e72ef","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-angle-right","library":"poco-icon"},"view":"stacked","shape":"square","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"size":{"unit":"px","size":12,"sizes":[]},"border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"_element_width":"auto","_offset_orientation_h":"end","__globals__":{"primary_color":"globals\/colors?id=secondary","hover_primary_color":""},"primary_color":"#00A149","_margin":{"unit":"px","top":"5","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon"}],"isInner":false}],"isInner":false},{"id":"7911ed4","elType":"section","settings":{"content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","stretch_section":"section-stretched","structure":"30","margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"2781ddd","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","margin_mobile":{"unit":"px","top":"0","right":"15","bottom":"30","left":"15","isLinked":false},"align_mobile":"center"},"elements":[{"id":"b19149b","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-1-2.jpg","id":353},"name":"william smith","job":"Chef","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","__globals__":{"job_text_color":""},"name_typography_font_weight":"700","name_typography_text_transform":"uppercase","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false},{"id":"a5dc42b","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":150,"margin_mobile":{"unit":"px","top":"0","right":"15","bottom":"30","left":"15","isLinked":false},"align_mobile":"center"},"elements":[{"id":"d1a2d63","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-2-1.jpg","id":354},"name":"John Doe","job":"Manager","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":""},"name_typography_text_transform":"uppercase","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false},{"id":"49f1d65","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":300,"align_mobile":"center"},"elements":[{"id":"13d3b9e","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-6-1.jpg","id":358},"name":"Bradd L.","job":"Chef","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":""},"name_typography_text_transform":"uppercase","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false}],"isInner":false},{"id":"9aa88b2","elType":"section","settings":{"layout":"full_width","gap":"no","content_position":"middle","stretch_section":"section-stretched","structure":"20","background_background":"classic","background_color":"#FBF7E8","html_tag":"div"},"elements":[{"id":"b797080","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"7493c58","elType":"widget","settings":{"address":"London Eye, London, United Kingdom","height":{"unit":"px","size":720,"sizes":[]},"height_tablet":{"unit":"px","size":600,"sizes":[]},"height_mobile":{"unit":"px","size":400,"sizes":[]}},"elements":[],"widgetType":"google_maps"}],"isInner":false},{"id":"6985bff","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"40","right":"130","bottom":"40","left":"130","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"b732621","elType":"widget","settings":{"editor":"reservation","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_text_transform":"capitalize","align":"center","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"ef24e76","elType":"widget","settings":{"title":"Book Your Table","typography_typography":"custom","typography_font_size":{"unit":"px","size":52,"sizes":[]},"typography_line_height":{"unit":"px","size":52,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"},"align":"center","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"57f34c3","elType":"widget","settings":{"form_name":"New Form","form_fields":[{"custom_id":"name","placeholder":"Your name","width":"50","_id":"6b3c83a"},{"custom_id":"email","field_type":"email","required":"true","placeholder":"Your email","width":"50","_id":"7a9e0a8"},{"custom_id":"message","placeholder":"Your phone","_id":"2b55567"},{"_id":"816f17a","field_type":"date","placeholder":"--\/--\/--","width":"50","custom_id":"field_816f17a"},{"_id":"8905f84","field_type":"time","placeholder":"00:00 Am","width":"50","custom_id":"field_8905f84"},{"_id":"f80ea7e","field_type":"select","field_options":"1 people\n2 people\n3 people\n4 people","custom_id":"field_f80ea7e"}],"show_labels":"","button_align":"center","step_next_label":"Next","step_previous_label":"Previous","button_text":"Book now","email_to":"admin@admin.com","email_subject":"New message from \"poco\"","email_content":"[all-fields]","email_from":"email@dev.wpopal.com","email_from_name":"poco","email_to_2":"admin@admin.com","email_subject_2":"New message from \"poco\"","email_content_2":"[all-fields]","email_from_2":"email@dev.wpopal.com","email_from_name_2":"poco","email_reply_to_2":"admin@admin.com","success_message":"The form was sent successfully.","error_message":"An error occured.","required_field_message":"This field is required.","invalid_message":"There\'s something wrong. The form is invalid.","column_gap":{"unit":"px","size":20,"sizes":[]},"row_gap":{"unit":"px","size":20,"sizes":[]},"label_spacing":{"unit":"px","size":"","sizes":[]},"field_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"field_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"field_text_padding":{"unit":"px","top":"18","right":"20","bottom":"18","left":"20","isLinked":false},"button_typography_typography":"custom","button_typography_text_transform":"uppercase","button_background_color":"#FFC222","button_text_color":"#1E1D23","button_text_padding":{"unit":"px","top":"20","right":"45","bottom":"20","left":"45","isLinked":false},"mailchimp_fields_map":[],"drip_fields_map":[],"activecampaign_fields_map":[],"getresponse_fields_map":[],"convertkit_fields_map":[],"mailerlite_fields_map":[],"__globals__":{"button_background_hover_color":"","button_hover_color":"globals\/colors?id=26c59e90"},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"form"}],"isInner":false}],"isInner":false}],"home-3":[{"id":"557b6cd","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"80","background_background":"classic","background_color":"#00A149","padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"html_tag":"div","content_position":"bottom"},"elements":[{"id":"594c163","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_inline_size_mobile":50},"elements":[{"id":"d119fc7","elType":"widget","settings":{"categories":"burgers","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/category-11.png","id":2986},"tilte_typography_typography":"custom","__globals__":{"title_color":""},"title_color":"#FFF","tilte_typography_font_weight":"bold"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"4f5f2f7","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_inline_size_mobile":50},"elements":[{"id":"14b68e4","elType":"widget","settings":{"categories":"pasta","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/category-22.png","id":2987},"tilte_typography_typography":"custom","__globals__":{"title_color":""},"title_color":"#FFF","tilte_typography_font_weight":"bold"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"20c0956","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_inline_size_mobile":50},"elements":[{"id":"8acfc73","elType":"widget","settings":{"categories":"pizza","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/category3.png","id":395},"tilte_typography_typography":"custom","__globals__":{"title_color":""},"title_color":"#FFF","tilte_typography_font_weight":"bold"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"7ecadbd","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_inline_size_mobile":50},"elements":[{"id":"a5899b4","elType":"widget","settings":{"categories":"hot-drinks","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/category-44.png","id":2989},"tilte_typography_typography":"custom","__globals__":{"title_color":""},"title_color":"#FFF","tilte_typography_font_weight":"bold"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"98d3ae6","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":25,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_inline_size_mobile":50},"elements":[{"id":"eb2d457","elType":"widget","settings":{"categories":"burgers","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/category5.png","id":397},"tilte_typography_typography":"custom","__globals__":{"title_color":""},"title_color":"#FFF","tilte_typography_font_weight":"bold"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"f5c5f70","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":25,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_inline_size_mobile":50},"elements":[{"id":"6179719","elType":"widget","settings":{"categories":"hot-drinks","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/category-33.png","id":2988},"tilte_typography_typography":"custom","__globals__":{"title_color":""},"categories_name":"Chicken","title_color":"#FFF","tilte_typography_font_weight":"bold"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"378bd63","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":25,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_inline_size_mobile":50},"elements":[{"id":"2bcc8a3","elType":"widget","settings":{"categories":"pasta","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/category7.png","id":399},"tilte_typography_typography":"custom","__globals__":{"title_color":""},"title_color":"#FFF","tilte_typography_font_weight":"bold"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false},{"id":"207aeac","elType":"column","settings":{"_column_size":12,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":25,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_inline_size_mobile":50},"elements":[{"id":"2a3357a","elType":"widget","settings":{"categories":"cold-drinks","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/category-55.png","id":2990},"tilte_typography_typography":"custom","__globals__":{"title_color":""},"title_color":"#FFF","tilte_typography_font_weight":"bold"},"elements":[],"widgetType":"poco-product-categories"}],"isInner":false}],"isInner":false},{"id":"d2c8106","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","height":"min-height","custom_height":{"unit":"px","size":890,"sizes":[]},"structure":"20","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/slider1-h3.jpg","id":443},"background_repeat":"no-repeat","background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","background_motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"motion_fx_translateY_effect":"yes","custom_height_mobile":{"unit":"px","size":450,"sizes":[]},"background_position_tablet":"bottom center","background_position_mobile":"top right","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"custom_height_tablet":{"unit":"px","size":700,"sizes":[]},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"ec4b496","elType":"column","settings":{"_column_size":50,"_inline_size":58.340000000000003410605131648480892181396484375,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"50","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":30},"elements":[{"id":"c8b1d80","elType":"widget","settings":{"space_mobile":{"unit":"px","size":0,"sizes":[]}},"elements":[],"widgetType":"spacer"},{"id":"7eb0370","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image1-slider-h3.png","id":1044},"image_size":"full","motion_fx_motion_fx_mouse":"yes","motion_fx_tilt_effect":"yes","_animation":"fadeInLeft","_animation_delay":750,"_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_orientation_v":"end","_offset_y":{"unit":"%","size":14,"sizes":[]},"_offset_y_end":{"unit":"px","size":70,"sizes":[]},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"0cef013","elType":"column","settings":{"_column_size":50,"_inline_size":41.659999999999996589394868351519107818603515625,"space_between_widgets":0,"_inline_size_tablet":70},"elements":[{"id":"8c503c6","elType":"widget","settings":{"editor":"<p>Buy one get one<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":62,"sizes":[]},"typography_line_height":{"unit":"px","size":70,"sizes":[]},"_animation":"opal-move-up","_animation_delay":200,"__globals__":{"text_color":""},"typography_font_family":"Norican","typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"text_color":"#FFF","texteditor_shadow_text_shadow_type":"yes","texteditor_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"},{"id":"8427416","elType":"widget","settings":{"title":"pizza time","title_color":"#FFC200","typography_typography":"custom","typography_font_size":{"unit":"px","size":100,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":110,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"opal-move-up","_animation_delay":350,"typography_font_size_mobile":{"unit":"px","size":55,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":65,"sizes":[]},"text_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"typography_font_size_tablet":{"unit":"px","size":90,"sizes":[]},"text_shadow_text_shadow_type":"yes","align_mobile":"center"},"elements":[],"widgetType":"heading"},{"id":"c010319","elType":"widget","settings":{"editor":"Extra-virgin olive oil, garlic, mozzarella cheese, onions, mushrooms, green olives, black olives, fresh tomatoes.","column_gap":{"unit":"%","size":"","sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","_animation_delay":450,"_element_width":"initial","_element_custom_width":{"unit":"%","size":60,"sizes":[]},"__globals__":{"text_color":""},"typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_line_height":{"unit":"px","size":32,"sizes":[]},"_element_width_mobile":"inherit","text_color":"#FFF","texteditor_shadow_text_shadow_type":"yes","texteditor_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":6,"color":"rgba(0, 0, 0, 0.5)"},"_element_width_tablet":"inherit","align_mobile":"center"},"elements":[],"widgetType":"text-editor"},{"id":"9e4dd81","elType":"widget","settings":{"text":"Order now","_animation":"opal-move-up","_animation_delay":550,"align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"28bb1d0","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","structure":"30","margin":{"unit":"px","top":"-110","right":0,"bottom":"40","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"30","right":0,"bottom":"80","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"f0579c1","elType":"column","settings":{"_column_size":33,"_inline_size":41.659999999999996589394868351519107818603515625,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"15","bottom":"20","left":"15","isLinked":false}},"elements":[{"id":"b50591a","elType":"widget","settings":{"title":"Burger","description":"* one phone call away","button":"Hot & spicy","bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/banner1-h3.jpg","id":2134},"bg_image_size":"full","subtitle":"American","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"min-height":{"unit":"px","size":532,"sizes":[]},"alignment":"left","vertical_position":"top","box_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"description_typography_typography":"custom","description_spacing":{"unit":"px","size":30,"sizes":[]},"subtitle_typography_typography":"custom","subtitle_typography_font_family":"Norican","subtitle_typography_font_size":{"unit":"px","size":35,"sizes":[]},"subtitle_typography_line_height":{"unit":"px","size":35,"sizes":[]},"subtitle_spacing":{"unit":"px","size":0,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":70,"sizes":[]},"title_typography_line_height":{"unit":"px","size":70,"sizes":[]},"title_spacing":{"unit":"px","size":0,"sizes":[]},"title_color":"#FFC222","content_animation":"","effect_duration":{"unit":"px","size":400,"sizes":[]},"__globals__":{"description_typography_typography":"globals\/typography?id=primary","title_color":"","button_background_color":"globals\/colors?id=primary","button_text_color":"globals\/colors?id=accent","button_hover_text_color":"globals\/colors?id=26c59e90"},"description_typography_font_size":{"unit":"px","size":18,"sizes":[]},"title_typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"title_typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"subtitle_typography_font_size_tablet":{"unit":"px","size":20,"sizes":[]},"subtitle_typography_line_height_tablet":{"unit":"px","size":20,"sizes":[]},"min-height_tablet":{"unit":"px","size":450,"sizes":[]},"title_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"subtitle_shadow_text_shadow_type":"yes","subtitle_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":6,"color":"rgba(0, 0, 0, 0.5)"},"description_shadow_text_shadow_type":"yes","description_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":6,"color":"rgba(0, 0, 0, 0.5)"},"button_typography_typography":"custom","button_typography_text_transform":"uppercase","button_border_radius":{"unit":"px","size":8,"sizes":[]},"title_shadow_text_shadow_type":"yes","button_typography_font_weight":"bold","min-height_mobile":{"unit":"px","size":350,"sizes":[]},"description_spacing_mobile":{"unit":"px","size":20,"sizes":[]}},"elements":[],"widgetType":"poco-banner"}],"isInner":false},{"id":"af65ee6","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"6fafcdb","elType":"widget","settings":{"title":"Food","description":"For Online Orders<br>\nin Wendesdays.","button":"Order now","bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/banner2-h3.jpg","id":2155},"bg_image_size":"full","subtitle":"Good ","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"min-height":{"unit":"px","size":245,"sizes":[]},"vertical_position":"top","box_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"description_typography_typography":"custom","description_spacing":{"unit":"px","size":30,"sizes":[]},"subtitle_typography_typography":"custom","subtitle_typography_font_family":"Norican","subtitle_typography_font_size":{"unit":"px","size":35,"sizes":[]},"subtitle_typography_line_height":{"unit":"px","size":40,"sizes":[]},"subtitle_spacing":{"unit":"px","size":2,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":40,"sizes":[]},"title_typography_line_height":{"unit":"px","size":40,"sizes":[]},"title_spacing":{"unit":"px","size":10,"sizes":[]},"content_animation":"","effect_duration":{"unit":"px","size":400,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"__globals__":{"description_typography_typography":"","title_color":"globals\/colors?id=26c59e90","button_text_color":"globals\/colors?id=accent","button_background_color":"globals\/colors?id=primary","subtitle_color":"globals\/colors?id=26c59e90","button_hover_text_color":"globals\/colors?id=26c59e90"},"title_typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"subtitle_typography_font_size_tablet":{"unit":"px","size":20,"sizes":[]},"subtitle_typography_line_height_tablet":{"unit":"px","size":20,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"min-height_tablet":{"unit":"px","size":185,"sizes":[]},"title_shadow_text_shadow_type":"yes","title_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"subtitle_shadow_text_shadow_type":"yes","subtitle_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"alignment":"left","description_typography_font_size":{"unit":"px","size":16,"sizes":[]},"description_typography_line_height":{"unit":"px","size":16,"sizes":[]},"description_shadow_text_shadow_type":"yes","description_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"button_typography_typography":"custom","button_typography_text_transform":"uppercase","button_border_radius":{"unit":"px","size":8,"sizes":[]},"padding_tablet":{"unit":"px","top":"25","right":"25","bottom":"25","left":"25","isLinked":true},"padding_mobile":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"button_typography_font_weight":"bold","min-height_mobile":{"unit":"px","size":350,"sizes":[]}},"elements":[],"widgetType":"poco-banner"},{"id":"ea68fc1","elType":"widget","settings":{"title":"Combo","description":"For Online Orders<br>\nin Wendesdays.","button":"Order now","bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/banner3-h33.jpg","id":3104},"bg_image_size":"full","subtitle":"Fastboy","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"min-height":{"unit":"px","size":245,"sizes":[]},"alignment":"left","vertical_position":"top","box_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":16,"sizes":[]},"description_typography_line_height":{"unit":"px","size":16,"sizes":[]},"description_spacing":{"unit":"px","size":30,"sizes":[]},"subtitle_typography_typography":"custom","subtitle_typography_font_family":"Norican","subtitle_typography_font_size":{"unit":"px","size":35,"sizes":[]},"subtitle_typography_line_height":{"unit":"px","size":40,"sizes":[]},"subtitle_spacing":{"unit":"px","size":0,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":40,"sizes":[]},"title_typography_line_height":{"unit":"px","size":40,"sizes":[]},"title_spacing":{"unit":"px","size":10,"sizes":[]},"subtitle_color":"#FFC222","content_animation":"","effect_duration":{"unit":"px","size":400,"sizes":[]},"__globals__":{"description_typography_typography":"","title_color":"globals\/colors?id=26c59e90","button_text_color":"globals\/colors?id=accent","button_background_color":"globals\/colors?id=primary","button_hover_text_color":"globals\/colors?id=26c59e90"},"title_typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"subtitle_typography_font_size_tablet":{"unit":"px","size":20,"sizes":[]},"subtitle_typography_line_height_tablet":{"unit":"px","size":20,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"min-height_tablet":{"unit":"px","size":185,"sizes":[]},"button_typography_typography":"custom","button_typography_text_transform":"uppercase","button_border_radius":{"unit":"px","size":8,"sizes":[]},"title_shadow_text_shadow_type":"yes","title_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"subtitle_shadow_text_shadow_type":"yes","subtitle_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"description_shadow_text_shadow_type":"yes","description_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"padding_tablet":{"unit":"px","top":"25","right":"25","bottom":"25","left":"25","isLinked":true},"padding_mobile":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"button_typography_font_weight":"bold","min-height_mobile":{"unit":"px","size":350,"sizes":[]}},"elements":[],"widgetType":"poco-banner"}],"isInner":false},{"id":"1596a50","elType":"column","settings":{"_column_size":33,"_inline_size":24.672000000000000596855898038484156131744384765625,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"a70b33a","elType":"widget","settings":{"title":"Hotdog","description":"Double Sauce","button":"Order now","bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/banner4-h3.jpg","id":2157},"bg_image_size":"full","subtitle":"America","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"min-height":{"unit":"px","size":532,"sizes":[]},"vertical_position":"top","box_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":16,"sizes":[]},"description_typography_line_height":{"unit":"px","size":16,"sizes":[]},"description_spacing":{"unit":"px","size":40,"sizes":[]},"subtitle_typography_typography":"custom","subtitle_typography_font_family":"Norican","subtitle_typography_font_size":{"unit":"px","size":35,"sizes":[]},"subtitle_typography_line_height":{"unit":"px","size":40,"sizes":[]},"subtitle_spacing":{"unit":"px","size":0,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":40,"sizes":[]},"title_typography_line_height":{"unit":"px","size":40,"sizes":[]},"title_spacing":{"unit":"px","size":10,"sizes":[]},"subtitle_color":"#FFC222","content_animation":"","effect_duration":{"unit":"px","size":400,"sizes":[]},"__globals__":{"description_typography_typography":"","title_color":"globals\/colors?id=26c59e90","button_text_color":"globals\/colors?id=accent","button_background_color":"globals\/colors?id=26c59e90","button_hover_background_color":"globals\/colors?id=primary","button_hover_text_color":"globals\/colors?id=26c59e90"},"padding_tablet":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true},"title_typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"subtitle_typography_font_size_tablet":{"unit":"px","size":20,"sizes":[]},"subtitle_typography_line_height_tablet":{"unit":"px","size":20,"sizes":[]},"padding_mobile":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"min-height_tablet":{"unit":"px","size":450,"sizes":[]},"button_typography_typography":"custom","button_typography_text_transform":"uppercase","button_border_radius":{"unit":"px","size":8,"sizes":[]},"title_shadow_text_shadow_type":"yes","title_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"subtitle_shadow_text_shadow_type":"yes","subtitle_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"description_shadow_text_shadow_type":"yes","description_shadow_text_shadow":{"horizontal":1,"vertical":0,"blur":5,"color":"rgba(0, 0, 0, 0.5)"},"title_color":"#FFF","button_text_color":"#1E1D23","button_background_color":"#FFF","button_hover_text_color":"#FFF","button_typography_font_weight":"bold","min-height_mobile":{"unit":"px","size":350,"sizes":[]},"description_spacing_mobile":{"unit":"px","size":20,"sizes":[]},"button_typography_font_size_tablet":{"unit":"px","size":12,"sizes":[]}},"elements":[],"widgetType":"poco-banner"}],"isInner":false}],"isInner":false},{"id":"66629c5","elType":"section","settings":{"content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","stretch_section":"section-stretched","structure":"30","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"94361a1","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_inline_size_tablet":50,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"2e82390","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-scooter","library":"poco-icon"},"title_text":"Free shipping ","description_text":"Sign up for updates and get free shipping","position":"left","primary_color":"#FFC222","icon_space":{"unit":"px","size":30,"sizes":[]},"icon_size":{"unit":"px","size":68,"sizes":[]},"content_vertical_alignment":"middle","title_bottom_space":{"unit":"px","size":0,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_color":"#999999","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":14,"sizes":[]},"_padding":{"unit":"px","top":"22","right":"30","bottom":"22","left":"30","isLinked":false},"_border_border":"dashed","_border_color":"#E5E5E5","_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"__globals__":{"title_color":""},"hover_animation":"grow","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"_border_hover_border":"dashed","_border_hover_color":"#FFC200","_border_hover_transition":{"unit":"px","size":0.5,"sizes":[]},"icon_space_mobile":{"unit":"px","size":0,"sizes":[]},"title_color":"#000"},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"9c77902","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_inline_size_tablet":50,"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"cf9e978","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-time","library":"poco-icon"},"title_text":"30 Minutes Delivery","description_text":"Everything you order will be quickly delivered to your door.","position":"left","primary_color":"#FFC222","icon_space":{"unit":"px","size":30,"sizes":[]},"icon_size":{"unit":"px","size":68,"sizes":[]},"content_vertical_alignment":"middle","title_bottom_space":{"unit":"px","size":0,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_color":"#999999","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":14,"sizes":[]},"_padding":{"unit":"px","top":"22","right":"30","bottom":"22","left":"30","isLinked":false},"_border_border":"dashed","_border_color":"#E5E5E5","_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"__globals__":{"title_color":""},"hover_animation":"grow","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"_border_hover_border":"dashed","_border_hover_color":"#FFC200","_border_hover_transition":{"unit":"px","size":0.5,"sizes":[]},"icon_space_mobile":{"unit":"px","size":0,"sizes":[]},"title_color":"#000"},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"ba7a70a","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_inline_size_tablet":100,"align_tablet":"center","animation":"opal-move-up","animation_duration":"fast","animation_delay":350},"elements":[{"id":"20495e7","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-pizza","library":"poco-icon"},"title_text":"Best Quality Guarantee","description_text":"Poco is an international chain of family restaurants.","position":"left","primary_color":"#FFC222","icon_space":{"unit":"px","size":30,"sizes":[]},"icon_size":{"unit":"px","size":68,"sizes":[]},"content_vertical_alignment":"middle","title_bottom_space":{"unit":"px","size":0,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_color":"#999999","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":14,"sizes":[]},"_padding":{"unit":"px","top":"22","right":"30","bottom":"22","left":"30","isLinked":false},"_border_border":"dashed","_border_color":"#E5E5E5","_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"__globals__":{"title_color":""},"hover_animation":"grow","_padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"_element_width_tablet":"initial","_element_custom_width_tablet":{"unit":"%","size":50,"sizes":[]},"_element_width_mobile":"inherit","_border_hover_border":"dashed","_border_hover_color":"#FFC200","_border_hover_transition":{"unit":"px","size":0.5,"sizes":[]},"icon_space_mobile":{"unit":"px","size":0,"sizes":[]},"title_color":"#000"},"elements":[],"widgetType":"icon-box"}],"isInner":false}],"isInner":false},{"id":"470a948","elType":"section","settings":{"gap":"no","content_position":"middle","stretch_section":"section-stretched","structure":"20","margin":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","html_tag":"div","margin_mobile":{"unit":"px","top":"20","right":0,"bottom":"20","left":0,"isLinked":true},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"383b662","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"align_mobile":"center"},"elements":[{"id":"4b99262","elType":"widget","settings":{"title":"Popular dishes","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"_element_width":"auto","__globals__":{"title_color":"globals\/colors?id=accent"},"typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"b42f85f","elType":"column","settings":{"_column_size":50,"_inline_size":null,"align":"flex-end","space_between_widgets":0,"align_mobile":"center"},"elements":[{"id":"4196a7d","elType":"widget","settings":{"icon_list":[{"text":"See all","selected_icon":{"value":"","library":""},"_id":"ac595d4","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/product-category\/cold-drinks\/","is_external":"","nofollow":"","custom_attributes":""}}],"_element_width":"auto","_offset_orientation_h":"end","_offset_x":{"unit":"px","size":30,"sizes":[]},"_offset_x_end":{"unit":"px","size":30,"sizes":[]},"__globals__":{"text_color":"globals\/colors?id=accent","text_color_hover":"globals\/colors?id=primary"},"_padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-list"},{"id":"c01ca29","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-angle-right","library":"poco-icon"},"view":"stacked","shape":"square","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"size":{"unit":"px","size":12,"sizes":[]},"border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"_element_width":"auto","_offset_orientation_h":"end","__globals__":{"primary_color":"globals\/colors?id=secondary","hover_primary_color":""},"primary_color":"#00A149","_margin":{"unit":"px","top":"5","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon"}],"isInner":false}],"isInner":false},{"id":"bf8ac70","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"a7da90a","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"63b7baf","elType":"widget","settings":{"limit":4,"column":"4","_z_index":4,"column_tablet":"3","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"poco-products"},{"id":"f735a15","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector3-h3.png","id":586},"image_size":"full","_z_index":1,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x":{"unit":"px","size":-100,"sizes":[]},"_offset_x_end":{"unit":"px","size":-100,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end":{"unit":"px","size":-3,"sizes":[]}},"elements":[],"widgetType":"image"},{"id":"ec5255c","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector2-h3.png","id":585},"image_size":"full","_z_index":1,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"%","size":41,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end":{"unit":"%","size":10,"sizes":[]}},"elements":[],"widgetType":"image"},{"id":"482e3aa","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector1-h3.png","id":584},"image_size":"full","_z_index":1,"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":-100,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end":{"unit":"px","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"2892ea7","elType":"section","settings":{"gap":"no","height":"min-height","custom_height":{"unit":"px","size":664,"sizes":[]},"stretch_section":"section-stretched","structure":"20","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_bg.jpg","id":1115},"margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"custom_height_mobile":{"unit":"px","size":350,"sizes":[]},"background_position_tablet":"center right","background_repeat":"no-repeat","background_size":"cover","margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"overflow":"hidden","background_position":"center center","background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","background_motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"html_tag":"div","padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"custom_height_tablet":{"unit":"px","size":570,"sizes":[]}},"elements":[{"id":"30dd324","elType":"column","settings":{"_column_size":50,"_inline_size":58.340000000000003410605131648480892181396484375,"space_between_widgets":0,"_inline_size_tablet":100,"align_mobile":"center"},"elements":[{"id":"7832e03","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector4-h3.png","id":622},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":85,"sizes":[]},"_offset_y":{"unit":"px","size":0,"sizes":[]},"motion_fx_motion_fx_mouse":"yes","motion_fx_mouseTrack_effect":"yes","hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","_animation":"opal-move-down","_animation_delay":1000},"elements":[],"widgetType":"image"},{"id":"f852d54","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_shape-3.png","id":1181},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":-315,"sizes":[]},"_offset_y":{"unit":"px","size":-250,"sizes":[]},"height_tablet":{"unit":"px","size":0,"sizes":[]},"_offset_x_tablet":{"unit":"px","size":0,"sizes":[]},"_offset_y_tablet":{"unit":"px","size":0,"sizes":[]},"_animation":"opal-move-right","_animation_delay":600},"elements":[],"widgetType":"image"},{"id":"a1125f4","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h1_pizza.png","id":565},"image_size":"full","align":"left","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"px","size":-160,"sizes":[]},"_offset_y":{"unit":"px","size":45,"sizes":[]},"width":{"unit":"px","size":780,"sizes":[]},"width_tablet":{"unit":"%","size":35,"sizes":[]},"height_tablet":{"unit":"px","size":0,"sizes":[]},"_animation":"opal-move-up","_animation_delay":800},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"2ccc65c","elType":"column","settings":{"_column_size":50,"_inline_size":41.659999999999996589394868351519107818603515625,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"e2917bd","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_shape-4.png","id":1189},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-209,"sizes":[]},"_offset_y":{"unit":"px","size":-157,"sizes":[]},"width_tablet":{"unit":"%","size":44,"sizes":[]},"_animation":"opal-move-left"},"elements":[],"widgetType":"image"},{"id":"adf8c38","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_pizza-1.png","id":1193},"image_size":"full","width":{"unit":"px","size":880,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"-183","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"size":-300,"unit":"px"},"_offset_y":{"size":-525,"unit":"px"},"width_tablet":{"unit":"%","size":32,"sizes":[]},"_offset_y_tablet":{"unit":"px","size":-90,"sizes":[]},"_animation":"opal-move-left","_animation_delay":200},"elements":[],"widgetType":"image"},{"id":"24d5fc5","elType":"widget","settings":{"editor":"<p>Super<\/p>","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":82,"sizes":[]},"typography_line_height":{"unit":"px","size":82,"sizes":[]},"_element_width":"auto","__globals__":{"text_color":"globals\/colors?id=26c59e90"},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"-25","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_element_width_mobile":"inherit"},"elements":[],"widgetType":"text-editor"},{"id":"e8c5b57","elType":"widget","settings":{"editor":"<p>Delicious<\/p>","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":82,"sizes":[]},"typography_line_height":{"unit":"px","size":82,"sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"165","isLinked":false},"_element_width":"auto","__globals__":{"text_color":"globals\/colors?id=26c59e90"},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"align_mobile":"center","_element_width_mobile":"inherit"},"elements":[],"widgetType":"text-editor"},{"id":"9edbcb3","elType":"widget","settings":{"title":"Pizza","title_color":"#FFCC00","typography_typography":"custom","typography_font_size":{"unit":"px","size":210,"sizes":[]},"typography_line_height":{"unit":"px","size":210,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":65,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":80,"sizes":[]},"_margin":{"unit":"px","top":"-60","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"heading"},{"id":"2fcec66","elType":"widget","settings":{"title":"Feel Hunger! Order Your Favouriate Food.","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_line_height":{"unit":"px","size":24,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=26c59e90"},"align_mobile":"center"},"elements":[],"widgetType":"heading"},{"id":"bc49861","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/h2_shape-5.png","id":1190},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":-190,"sizes":[]},"_offset_orientation_v":"end","_offset_y_end":{"unit":"px","size":-190,"sizes":[]},"_animation":"opal-move-left","_animation_delay":400},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"d03c288","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"-180","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"z_index":2,"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"html_tag":"div","margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"2356c23","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"8202c8e","elType":"widget","settings":{"title":"Our menu","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"},"_animation":"opal-move-up","animation_duration":"fast","typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"45af91c","elType":"widget","settings":{"tabs":[{"tab_title":"pizza","_id":"8f6b32a","product_type":"best_selling","product_layout":"list","list_layout":"2"},{"tab_title":"sushi","limit":8,"orderby":"title","product_layout":"list","_id":"4db1d15","list_layout":"2"},{"tab_title":"salats","limit":8,"product_type":"best_selling","product_layout":"list","_id":"3243272","list_layout":"2"},{"tab_title":"burger","limit":8,"product_layout":"list","_id":"eb12372","list_layout":"2"},{"tab_title":"Dersest","limit":8,"product_layout":"list","_id":"9c18288","list_layout":"2"}],"column":"2","tab_header_padding":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"align_items":"center","header_margin":{"unit":"px","size":10,"sizes":[]},"title_color":"#1E1D23","border_tabs_radius":{"unit":"px","top":"28","right":"28","bottom":"28","left":"28","isLinked":true},"__globals__":{"tab_typography_typography":""},"tab_typography_typography":"custom","tab_typography_font_size":{"unit":"px","size":14,"sizes":[]},"tab_typography_text_transform":"uppercase","tab_title_spacing":{"unit":"px","size":90,"sizes":[]},"tab_title_vertical_padding":{"unit":"px","size":15,"sizes":[]},"title_hover_border_color":"#FFC222","title_background_active_color":"#FFC222","title_active_border_color":"#FFC222","border_tabs_title_border":"solid","border_tabs_title_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_tabs_title_color":"#EDEDED","tab_title_spacing_tablet":{"unit":"px","size":70,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","header_margin_tablet":{"unit":"px","size":6,"sizes":[]},"tab_title_padding":{"unit":"px","top":"20","right":"45","bottom":"20","left":"45","isLinked":false},"tab_typography_font_weight":"bold","tab_header_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"poco-products-tabs"}],"isInner":false}],"isInner":false},{"id":"bf1c2aa","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","structure":"20","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image1-h3.png","id":1586},"background_position":"top left","background_repeat":"no-repeat","background_overlay_background":"classic","background_overlay_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector5-h3.png","id":669},"background_overlay_position":"top right","background_overlay_repeat":"no-repeat","padding":{"unit":"%","top":"20","right":"5","bottom":"14","left":"5","isLinked":false},"z_index":1,"background_size_tablet":"initial","background_bg_width_tablet":{"unit":"px","size":0,"sizes":[]},"margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding_tablet":{"unit":"%","top":"12","right":"4","bottom":"12","left":"4","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false},"background_overlay_size_mobile":"initial","background_overlay_bg_width_mobile":{"unit":"px","size":0,"sizes":[]},"background_ypos":{"unit":"px","size":-50,"sizes":[]},"margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"background_motion_fx_mouseTrack_effect":"yes","html_tag":"div"},"elements":[{"id":"bc20de0","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"50","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"content_position":"bottom"},"elements":[{"id":"c720f40","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector6-h3.png","id":670},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","width_tablet":{"unit":"%","size":80,"sizes":[]},"width_mobile":{"unit":"%","size":54,"sizes":[]},"_animation":"opal-move-left","_animation_delay":500,"_offset_y_mobile":{"unit":"px","size":-61,"sizes":[]}},"elements":[],"widgetType":"image"},{"id":"3d14db8","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/logo-pizzaguy.png","id":1556},"image_size":"full","_element_width":"auto","_position":"absolute","width_tablet":{"unit":"%","size":100,"sizes":[]},"width_mobile":{"unit":"%","size":38,"sizes":[]},"_offset_x":{"unit":"px","size":50,"sizes":[]},"_offset_y":{"unit":"px","size":-15,"sizes":[]},"_animation":"opal-move-down","_animation_delay":300,"_offset_x_tablet":{"unit":"px","size":-50,"sizes":[]},"_offset_y_tablet":{"unit":"px","size":60,"sizes":[]},"hide_mobile":"hidden-phone","motion_fx_motion_fx_mouse":"yes"},"elements":[],"widgetType":"image"},{"id":"4c53779","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image9-h4.png","id":1555},"image_size":"full","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"-100","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-right"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"0fcbb55","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"305018d","elType":"widget","settings":{"editor":"<p>Always Fresh<\/p>","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_text_transform":"capitalize","typography_font_size_tablet":{"unit":"px","size":30,"sizes":[]},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"},{"id":"08f5441","elType":"widget","settings":{"title":"Made Right. Make Delicious.\nMade Especially For You.","typography_typography":"custom","typography_font_size":{"unit":"px","size":51,"sizes":[]},"typography_line_height":{"unit":"px","size":58,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"__globals__":{"title_color":"globals\/colors?id=accent"},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"4483884","elType":"widget","settings":{"editor":"Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris.","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_element_width":"initial","_element_width_tablet":"inherit","_element_custom_width":{"unit":"%","size":85,"sizes":[]},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"},{"id":"c227731","elType":"widget","settings":{"text":"Order now","typography_typography":"custom","align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"a6354e1","elType":"section","settings":{"layout":"full_width","gap":"no","stretch_section":"section-stretched","html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"8f17330","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"39b512d","elType":"widget","settings":{"gallery":[{"id":738,"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/img1-h3.jpg"},{"id":739,"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/img2-h3.jpg"},{"id":740,"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/img3-h3.jpg"},{"id":741,"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/img4-h3.jpg"}],"galleries":[{"gallery_title":"New Gallery","_id":"2ae0eb9"}],"gap":{"unit":"px","size":0,"sizes":[]},"aspect_ratio":"4:3","thumbnail_image_size":"full","show_all_galleries_label":"All","image_hover_animation":"grow","image_animation_duration":{"unit":"px","size":500,"sizes":[]},"background_overlay_hover_animation":"enter-from-bottom","background_overlay_animation_duration":{"unit":"px","size":500,"sizes":[]},"gap_tablet":{"unit":"px","size":0,"sizes":[]},"gap_mobile":{"unit":"px","size":0,"sizes":[]}},"elements":[],"widgetType":"gallery"}],"isInner":false}],"isInner":false},{"id":"fc0bd87","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","background_background":"classic","background_color":"#F7F2E2","padding":{"unit":"px","top":"100","right":"30","bottom":"100","left":"30","isLinked":false},"margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"14c65b8","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"2a5a298","elType":"widget","settings":{"title":"What  your client says","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"header_size":"h3","__globals__":{"title_color":"globals\/colors?id=accent"},"align_mobile":"center","_element_width_mobile":"inherit","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"align":"center","typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"0bff326","elType":"widget","settings":{"testimonials":[{"testimonial_icon":"","testimonial_title":"","testimonial_content":"\u201cForget the trendy pizza shops, This hidden spot makes the best New York-style pizza slice in naples\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-2.jpg","id":2532},"testimonial_name":"Nina Margaret ","testimonial_job":"CEO,apple","_id":"44240e3","testimonial_rating":"4"},{"testimonial_icon":"","testimonial_title":"","testimonial_content":"\"I would be lost without restaurant. I would like to personally thank you for your outstanding product.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-1.jpg","id":2531},"testimonial_name":"Rose","testimonial_job":"Design","_id":"5211bae","testimonial_rating":5},{"testimonial_icon":"","testimonial_title":"","testimonial_content":"\"I am completely blown away. I would also like to say thank you to all your staff. It\'s really wonderful.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-4.jpg","id":2535},"testimonial_name":"Clara","testimonial_job":"Design","_id":"e8cf9d6","testimonial_rating":"3"},{"testimonial_title":"Testimonial title","testimonial_content":"\"I am completely blown away. I would also like to say thank you to all your staff. It\'s really wonderful.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-3.jpg","id":2534},"testimonial_name":"John Doe","testimonial_job":"Design","_id":"b11e9eb","testimonial_rating":5}],"testimonial_alignment":"left","column":"3","enable_carousel":"yes","padding_estimonial_wrapper":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":true},"color_testimonial_wrapper":"#FFFFFF","wrapper_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"image_margin":{"unit":"px","top":"0","right":"15","bottom":"25","left":"0","isLinked":false},"navigation":"both","padding_estimonial_wrapper_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"next_horizontal":"right","next_horizontal_value_tablet":{"unit":"px","size":0,"sizes":[]},"prev_horizontal":"left","prev_horizontal_value_tablet":{"unit":"px","size":0,"sizes":[]},"name_typography_typography":"custom","job_typography_typography":"custom"},"elements":[],"widgetType":"poco-testimonials"}],"isInner":false}],"isInner":false},{"id":"ed444ed","elType":"section","settings":{"gap":"no","content_position":"middle","stretch_section":"section-stretched","structure":"20","margin":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","html_tag":"div","margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"20","left":0,"isLinked":false}},"elements":[{"id":"dba0668","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"align_mobile":"center"},"elements":[{"id":"f9220b9","elType":"widget","settings":{"title":"Latest news","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"_element_width":"auto","__globals__":{"title_color":"globals\/colors?id=accent"},"typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"b88b953","elType":"column","settings":{"_column_size":50,"_inline_size":null,"align":"flex-end","space_between_widgets":0,"align_mobile":"center"},"elements":[{"id":"3421dd1","elType":"widget","settings":{"icon_list":[{"text":"See all","selected_icon":{"value":"","library":""},"_id":"ac595d4","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/blog\/","is_external":"","nofollow":"","custom_attributes":""}}],"_element_width":"auto","_offset_orientation_h":"end","_offset_x":{"unit":"px","size":30,"sizes":[]},"_offset_x_end":{"unit":"px","size":30,"sizes":[]},"__globals__":{"text_color":"globals\/colors?id=accent","text_color_hover":"globals\/colors?id=primary"},"_padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-list"},{"id":"586f63a","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-angle-right","library":"poco-icon"},"view":"stacked","shape":"square","link":{"url":"#","is_external":"","nofollow":"","custom_attributes":""},"size":{"unit":"px","size":12,"sizes":[]},"border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"_element_width":"auto","_offset_orientation_h":"end","__globals__":{"primary_color":"globals\/colors?id=secondary","hover_primary_color":""},"primary_color":"#00A149","_margin":{"unit":"px","top":"5","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon"}],"isInner":false}],"isInner":false},{"id":"8a1343d","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"a5f7be2","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"581230e","elType":"widget","settings":{"posts_per_page":3,"pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","column_tablet":"3","enable_carousel":"yes","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"poco-post-grid"}],"isInner":false}],"isInner":false},{"id":"216435d","elType":"section","settings":{"gap":"no","height":"min-height","custom_height":{"unit":"px","size":460,"sizes":[]},"stretch_section":"section-stretched","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/bg3-h3-3.jpg","id":3113},"background_position":"top center","background_repeat":"no-repeat","background_size":"cover","custom_height_mobile":{"unit":"px","size":470,"sizes":[]},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"html_tag":"div"},"elements":[{"id":"f3aec6c","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"a522933","elType":"widget","settings":{"editor":"<p>We guarantee<\/p>","align":"center","text_color":"#FFC222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_line_height":{"unit":"px","size":50,"sizes":[]},"typography_font_family":"Norican","_animation":"opal-move-up","animation_duration":"fast","typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"a92f3a9","elType":"widget","settings":{"title":"30 Minutes Delivery!","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_line_height":{"unit":"px","size":70,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"typography_font_size_mobile":{"unit":"px","size":36,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"ffdd3de","elType":"widget","settings":{"editor":"If you\'re having a meeting, working late at night and need an extra push.<br> Let us know and we will be there","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"42239e8","elType":"widget","settings":{"text":"make an order","align":"center","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"contact-us":[{"id":"abbbd88","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"10","right":0,"bottom":"80","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"html_tag":"div"},"elements":[{"id":"196dadc","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"d493646","elType":"widget","settings":{"title":"Call us or visit place","align":"left","align_tablet":"center","title_color":"#1E1D23","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":""},"typography_letter_spacing":{"unit":"px","size":-1.399999999999999911182158029987476766109466552734375,"sizes":[]},"text_shadow_text_shadow":{"horizontal":0,"vertical":-1,"blur":10,"color":"rgba(0,0,0,0.3)"},"typography_line_height":{"unit":"px","size":35,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.8000000000000000444089209850062616169452667236328125,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-1.0500000000000000444089209850062616169452667236328125,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"1f69a2f","elType":"widget","settings":{"editor":"Lorem ipsum dolor sit amet, consectetur adipiscing elit. ","_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"align_mobile":"center","align_tablet":"center","align":"left"},"elements":[],"widgetType":"text-editor"},{"id":"a1b19c1","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"30","html_tag":"div"},"elements":[{"id":"bc20640","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"2311c06","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-mobile-android-alt","library":"poco-icon"},"title_text":"Phone: ","description_text":"+ 44 123 456 78 90 <br\/>\n+ 844 123 444 77 88","icon_space":{"unit":"px","size":25,"sizes":[]},"icon_space_tablet":{"unit":"px","size":15,"sizes":[]},"icon_space_mobile":{"unit":"px","size":5,"sizes":[]},"text_align":"left","text_align_tablet":"center","title_bottom_space_tablet":{"unit":"px","size":5,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":16,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"574d53e","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"5b64efa","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-map-marker-check","library":"poco-icon"},"title_text":"Address","description_text":"Box 565, Pinney\'s Beach, Charlestown,<br\/> Nevis, West Indies, Caribbean","icon_space":{"unit":"px","size":25,"sizes":[]},"icon_space_tablet":{"unit":"px","size":15,"sizes":[]},"icon_space_mobile":{"unit":"px","size":5,"sizes":[]},"text_align":"left","text_align_tablet":"center","title_bottom_space_tablet":{"unit":"px","size":5,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":16,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"71d678d","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"e7ce84d","elType":"widget","settings":{"selected_icon":{"value":"poco-icon- poco-icon-envelope","library":"poco-icon"},"title_text":"Email: ","description_text":"contact@example.com <br\/>\ninfo@example.com","icon_space":{"unit":"px","size":25,"sizes":[]},"icon_space_tablet":{"unit":"px","size":15,"sizes":[]},"icon_space_mobile":{"unit":"px","size":5,"sizes":[]},"text_align":"left","text_align_tablet":"center","title_bottom_space_tablet":{"unit":"px","size":5,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":16,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"16a7b13","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"html_tag":"div"},"elements":[{"id":"773e7f4","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"border_border":"solid","border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_width_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_color":"#E1E1E1","border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true}},"elements":[{"id":"fb7a2f3","elType":"section","settings":{"layout":"full_width","gap":"no","content_position":"middle","structure":"20","html_tag":"div"},"elements":[{"id":"a27afc5","elType":"column","settings":{"_column_size":50,"_inline_size":null,"_inline_size_tablet":100,"space_between_widgets":0,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"40","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"487695b","elType":"widget","settings":{"address":"EAST NEW YORK","height":{"unit":"px","size":660,"sizes":[]},"height_mobile":{"unit":"px","size":320,"sizes":[]},"_border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"0","isLinked":false},"_border_color":"#020101F0","_box_shadow_box_shadow":{"horizontal":0,"vertical":5,"blur":11,"spread":0,"color":"rgba(0,0,0,0.5)"},"_background_hover_transition":{"unit":"px","size":0,"sizes":[]},"height_tablet":{"unit":"px","size":480,"sizes":[]},"css_filters_css_filter":"custom","_border_radius":{"unit":"px","top":"5","right":"0","bottom":"0","left":"5","isLinked":false},"_border_radius_tablet":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true}},"elements":[],"widgetType":"google_maps"}],"isInner":true},{"id":"83aaabb","elType":"column","settings":{"_column_size":50,"_inline_size":null,"_inline_size_tablet":100,"align_tablet":"center","space_between_widgets":0,"padding":{"unit":"px","top":"30","right":"80","bottom":"30","left":"80","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"23db60b","elType":"widget","settings":{"title":"Send us a message","align":"left","align_tablet":"center","title_color":"#1E1D23","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":""},"typography_letter_spacing":{"unit":"px","size":-1.399999999999999911182158029987476766109466552734375,"sizes":[]},"text_shadow_text_shadow":{"horizontal":0,"vertical":-1,"blur":10,"color":"rgba(0,0,0,0.3)"},"typography_line_height":{"unit":"px","size":35,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.8000000000000000444089209850062616169452667236328125,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-1.0500000000000000444089209850062616169452667236328125,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"21609c4","elType":"widget","settings":{"editor":"Lorem ipsum dolor sit amet, consectetur adipiscing elit. ","_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"align_mobile":"center","align_tablet":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"7c177ba","elType":"widget","settings":{"form_name":"New Form","form_fields":[{"custom_id":"name","placeholder":" Your name","_id":"3e7ea59"},{"custom_id":"email","field_type":"email","required":"true","placeholder":"Email","_id":"7707ab7"},{"custom_id":"field_44fbad9","required":"true","placeholder":"Subject","_id":"44fbad9"},{"field_type":"textarea","rows":8,"custom_id":"field_e8d520d","_id":"e8d520d","placeholder":"Comment"}],"input_size":"xs","button_size":"md","button_align":"start","step_next_label":"Next","step_previous_label":"Previous","button_text":"submit","email_to":"admin@admin.com","email_subject":"New message from \"poco\"","email_content":"[all-fields]","email_from":"email@dev.wpopal.com","email_from_name":"poco","email_to_2":"admin@admin.com","email_subject_2":"New message from \"poco\"","email_content_2":"[all-fields]","email_from_2":"email@dev.wpopal.com","email_from_name_2":"poco","email_reply_to_2":"admin@admin.com","success_message":"The form was sent successfully.","error_message":"An error occured.","required_field_message":"This field is required.","invalid_message":"There\'s something wrong. The form is invalid.","column_gap":{"unit":"px","size":30,"sizes":[]},"row_gap":{"unit":"px","size":15,"sizes":[]},"field_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"field_border_radius":{"unit":"px","top":"8","right":"8","bottom":"8","left":"8","isLinked":true},"field_text_padding":{"unit":"px","top":"10","right":"10","bottom":"10","left":"10","isLinked":true},"field_text_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_background_color":"#FFC222","button_text_color":"#000000","previous_button_text_color":"#000000","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"field_typography_typography":"custom","field_typography_font_size":{"unit":"px","size":15,"sizes":[]},"field_background_color":"#FFFFFF","field_border_color":"#E1E1E1","button_typography_line_height":{"unit":"px","size":"","sizes":[]},"button_border_radius":{"unit":"%","top":"","right":"","bottom":"","left":"","isLinked":true},"button_text_padding":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"label_spacing":{"unit":"px","size":"","sizes":[]},"html_spacing":{"unit":"px","size":"","sizes":[]},"mailchimp_fields_map":[],"drip_fields_map":[],"activecampaign_fields_map":[],"getresponse_fields_map":[],"convertkit_fields_map":[],"mailerlite_fields_map":[],"__globals__":{"button_background_color":"","field_text_color":"globals\/colors?id=1d12e908"},"button_align_tablet":"center","button_align_mobile":"center","_element_width_tablet":"initial","_element_custom_width_tablet":{"unit":"px","size":550,"sizes":[]}},"elements":[],"widgetType":"form"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false}],"faq":[{"id":"25be7b8","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":850,"sizes":[]},"gap":"no","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"30","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"html_tag":"div","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false}},"elements":[{"id":"b7e7e8f","elType":"column","settings":{"_column_size":100,"_inline_size":null},"elements":[{"id":"c7bf02a","elType":"widget","settings":{"tabs":[{"tab_title":"How does this work?","tab_content":"<p>Simply put, we deliver your favourite menu from fast-food restaurant of choice. Our platform enables you to enter your postcode and select a nearby restaurant of choice e.g McDonalds, KFC, ...Wagamama e.t.c for delivery. Within each of these restaurants you will find their menus which you can add to basket, choose your payment method (PayPal or Credit \/ Debit Card) and submit. There you go, your order is sent to the selected restaurant or the nearby delivery driver where applicable.<\/p>","_id":"dac1e75"},{"tab_title":"Can I order from different restaurant at the same time?","tab_content":"<p>Simply put, we deliver your favourite menu from fast-food restaurant of choice. Our platform enables you to enter your postcode and select a nearby restaurant of choice e.g McDonalds, KFC, ...Wagamama e.t.c for delivery. Within each of these restaurants you will find their menus which you can add to basket, choose your payment method (PayPal or Credit \/ Debit Card) and submit. There you go, your order is sent to the selected restaurant or the nearby delivery driver where applicable.<\/p>","_id":"d4cfe79"},{"tab_title":"Are your menu prices the same as those at the restaurant?","tab_content":"<p>Simply put, we deliver your favourite menu from fast-food restaurant of choice. Our platform enables you to enter your postcode and select a nearby restaurant of choice e.g McDonalds, KFC, ...Wagamama e.t.c for delivery. Within each of these restaurants you will find their menus which you can add to basket, choose your payment method (PayPal or Credit \/ Debit Card) and submit. There you go, your order is sent to the selected restaurant or the nearby delivery driver where applicable.<\/p>","_id":"075f4fd"},{"tab_title":"Some menus are missing on a restaurant page?","tab_content":"<p>Simply put, we deliver your favourite menu from fast-food restaurant of choice. Our platform enables you to enter your postcode and select a nearby restaurant of choice e.g McDonalds, KFC, ...Wagamama e.t.c for delivery. Within each of these restaurants you will find their menus which you can add to basket, choose your payment method (PayPal or Credit \/ Debit Card) and submit. There you go, your order is sent to the selected restaurant or the nearby delivery driver where applicable.<\/p>","_id":"d92430f"},{"tab_title":"Do any of your cheeses contain enzymes derived from animal sources?","tab_content":"<p>Simply put, we deliver your favourite menu from fast-food restaurant of choice. Our platform enables you to enter your postcode and select a nearby restaurant of choice e.g McDonalds, KFC, ...Wagamama e.t.c for delivery. Within each of these restaurants you will find their menus which you can add to basket, choose your payment method (PayPal or Credit \/ Debit Card) and submit. There you go, your order is sent to the selected restaurant or the nearby delivery driver where applicable.<\/p>","_id":"b8cfcdb"},{"tab_title":"Is the sugar used in your dough refined through animal bone char?","tab_content":"<p>Simply put, we deliver your favourite menu from fast-food restaurant of choice. Our platform enables you to enter your postcode and select a nearby restaurant of choice e.g McDonalds, KFC, ...Wagamama e.t.c for delivery. Within each of these restaurants you will find their menus which you can add to basket, choose your payment method (PayPal or Credit \/ Debit Card) and submit. There you go, your order is sent to the selected restaurant or the nearby delivery driver where applicable.<\/p>","_id":"ba7a033"},{"tab_title":"Does your pizza contain peanuts or peanut oil?","tab_content":"<p>Simply put, we deliver your favourite menu from fast-food restaurant of choice. Our platform enables you to enter your postcode and select a nearby restaurant of choice e.g McDonalds, KFC, ...Wagamama e.t.c for delivery. Within each of these restaurants you will find their menus which you can add to basket, choose your payment method (PayPal or Credit \/ Debit Card) and submit. There you go, your order is sent to the selected restaurant or the nearby delivery driver where applicable.<\/p>","_id":"1eccc68"},{"tab_title":"Are your doughs vegan or vegetarian friendly?","tab_content":"<p>Simply put, we deliver your favourite menu from fast-food restaurant of choice. Our platform enables you to enter your postcode and select a nearby restaurant of choice e.g McDonalds, KFC, ...Wagamama e.t.c for delivery. Within each of these restaurants you will find their menus which you can add to basket, choose your payment method (PayPal or Credit \/ Debit Card) and submit. There you go, your order is sent to the selected restaurant or the nearby delivery driver where applicable.<\/p>","_id":"c73c613"},{"tab_title":"Does your pepperoni contain gluten?","tab_content":"<p>Simply put, we deliver your favourite menu from fast-food restaurant of choice. Our platform enables you to enter your postcode and select a nearby restaurant of choice e.g McDonalds, KFC, ...Wagamama e.t.c for delivery. Within each of these restaurants you will find their menus which you can add to basket, choose your payment method (PayPal or Credit \/ Debit Card) and submit. There you go, your order is sent to the selected restaurant or the nearby delivery driver where applicable.<\/p>","_id":"e2bb790"}],"icon_align":"right","content_typography_font_size":{"unit":"px","size":14,"sizes":[]},"border_width":{"unit":"px","size":1,"sizes":[]},"_box_shadow_box_shadow":{"horizontal":-12,"vertical":0,"blur":10,"spread":0,"color":"rgba(0,0,0,0.5)"},"border_color":"#F7F4EF","content_padding_mobile":{"unit":"px","top":"15","right":"15","bottom":"30","left":"15","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"__dynamic__":[],"style_theme":"yes","content_typography_typography":"custom","content_typography_line_height":{"unit":"px","size":31,"sizes":[]},"title_typography_typography":"custom","title_typography_font_weight":"600","title_typography_line_height_mobile":{"unit":"px","size":"","sizes":[]},"title_padding_mobile":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true}},"elements":[],"widgetType":"accordion"}],"isInner":false}],"isInner":false}],"our-teams":[{"id":"b1009da","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"30","padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"margin":{"unit":"px","top":"0","right":0,"bottom":"30","left":0,"isLinked":false},"html_tag":"div","content_width":{"unit":"px","size":1320,"sizes":[]}},"elements":[{"id":"fa3245e","elType":"column","settings":{"_column_size":33,"_inline_size":null,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"space_between_widgets":0,"align_mobile":"center"},"elements":[{"id":"f5c8df4","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-1-2.jpg","id":353},"name":"william smith","job":"Chef","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false},{"id":"4c52f77","elType":"column","settings":{"_column_size":33,"_inline_size":null,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center"},"elements":[{"id":"8f94265","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-2-1.jpg","id":354},"name":"John Doe","job":"Manager","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false},{"id":"b390565","elType":"column","settings":{"_column_size":33,"_inline_size":null,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center"},"elements":[{"id":"47acddc","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-3-1.jpg","id":355},"name":"Bradd L.","job":"Chef","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false}],"isInner":false},{"id":"572a025","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"30","padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"html_tag":"div","content_width":{"unit":"px","size":1320,"sizes":[]},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false}},"elements":[{"id":"d41a5d9","elType":"column","settings":{"_column_size":33,"_inline_size":null,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"space_between_widgets":0,"align_mobile":"center"},"elements":[{"id":"db7692e","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-4-2.jpg","id":356},"name":"william smith","job":"Chef","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false},{"id":"ed9d069","elType":"column","settings":{"_column_size":33,"_inline_size":null,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center"},"elements":[{"id":"e6ec806","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-5-1.jpg","id":357},"name":"John Doe","job":"Manager","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false},{"id":"3d46abc","elType":"column","settings":{"_column_size":33,"_inline_size":null,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center"},"elements":[{"id":"11badcc","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-6-1.jpg","id":358},"name":"Bradd L.","job":"Chef","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false}],"isInner":false}],"about-us":[{"id":"4b2032e","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","structure":"20","padding":{"unit":"px","top":"0","right":"30","bottom":"100","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"80","left":"15","isLinked":false},"html_tag":"div"},"elements":[{"id":"332527e","elType":"column","settings":{"_column_size":50,"_inline_size":41.659999999999996589394868351519107818603515625,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"50","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"087a4ee","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector1-h3.png","id":584},"image_size":"full","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"%","size":-40,"sizes":[]},"_offset_y":{"unit":"%","size":5,"sizes":[]},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes"},"elements":[],"widgetType":"image"},{"id":"9e9c374","elType":"widget","settings":{"editor":"Wellome!","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_text_transform":"capitalize","align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":24,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"64782fe","elType":"widget","settings":{"title":"Best burger ideas \n& traditions from the \nwhole world","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_line_height":{"unit":"px","size":60,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"__globals__":{"title_color":""},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"title_color":"#1E1D23","align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"28db4fa","elType":"widget","settings":{"editor":"Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.<br><br>\nMauris tempus erat laoreet turpis lobortis, eu tincidunt erat fermentum. Aliquam non tincidunt urna. Integer tincidunt nec nisl vitae ullamcorper. Proin sed ultrices erat.","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"},{"id":"5cf05e2","elType":"widget","settings":{"text":"Contact now","align_mobile":"center","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/contact-us\/","is_external":"","nofollow":"","custom_attributes":""}},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"b6e3738","elType":"column","settings":{"_column_size":50,"_inline_size":58.340000000000003410605131648480892181396484375,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"60","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[{"id":"aa50968","elType":"section","settings":{"gap":"no","structure":"20","html_tag":"div"},"elements":[{"id":"0074f23","elType":"column","settings":{"_column_size":50,"_inline_size":41.659999999999996589394868351519107818603515625,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"30","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[{"id":"9a9c926","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image1-h4.jpg","id":744},"image_size":"full","image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"hover_animation":"float","motion_fx_translateY_effect":"yes","_animation":"opal-move-up","_animation_delay":200,"align_mobile":"center"},"elements":[],"widgetType":"image"},{"id":"32c0075","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector2-h3.png","id":585},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_element_width":"auto","_position":"absolute","_offset_x":{"unit":"%","size":-40,"sizes":[]},"_offset_orientation_v":"end","_offset_y":{"unit":"%","size":-10,"sizes":[]},"_offset_y_end":{"unit":"%","size":20,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true},{"id":"e2a38c9","elType":"column","settings":{"_column_size":50,"_inline_size":58.31099999999999994315658113919198513031005859375,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"10","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"8fb646b","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image2-h4.jpg","id":745},"image_size":"full","image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"hover_animation":"float","motion_fx_translateY_speed":{"unit":"px","size":"","sizes":[]},"_animation":"opal-move-up","_animation_delay":400,"align_mobile":"center","_element_custom_width_mobile":{"unit":"%","size":50,"sizes":[]}},"elements":[],"widgetType":"image"},{"id":"5525bc7","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/image3-h4.jpg","id":746},"image_size":"full","align":"left","image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"hover_animation":"float","motion_fx_translateY_effect":"yes","_animation":"opal-move-up","_animation_delay":600,"align_mobile":"center"},"elements":[],"widgetType":"image"},{"id":"7d21a14","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/vector3-h3.png","id":586},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","_element_width":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x":{"unit":"%","size":-40,"sizes":[]},"_offset_y":{"unit":"%","size":45,"sizes":[]},"_offset_y_end":{"unit":"%","size":13,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"ec6c8a9","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","custom_height":{"unit":"px","size":560,"sizes":[]},"height":"min-height","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/bg-video.jpg","id":3321},"background_repeat":"no-repeat","background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","background_overlay_background":"classic","background_overlay_color":"#000000","background_overlay_opacity":{"unit":"px","size":0.59999999999999997779553950749686919152736663818359375,"sizes":[]},"background_motion_fx_translateY_speed":{"unit":"px","size":7,"sizes":[]},"custom_height_tablet":{"unit":"px","size":460,"sizes":[]},"custom_height_mobile":{"unit":"px","size":360,"sizes":[]},"background_position":"center center","padding":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false},"html_tag":"div"},"elements":[{"id":"3b71bab","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"7b92722","elType":"widget","settings":{"video_link":"https:\/\/www.youtube.com\/watch?v=dLC54mz--Dk","_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"video_hover_bgcolor":"#EEAC00","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"poco-video-popup"},{"id":"65c9cdd","elType":"widget","settings":{"title":"Make the thing Anything is Possible","typography_typography":"custom","typography_font_size":{"unit":"px","size":52,"sizes":[]},"typography_line_height":{"unit":"px","size":50,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"__globals__":{"title_color":""},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"title_color":"#FFFFFF","align_mobile":"center","align":"center","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":36,"sizes":[]},"typography_letter_spacing_tablet":{"unit":"px","size":-0.1000000000000000055511151231257827021181583404541015625,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.08000000000000000166533453693773481063544750213623046875,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"bd59024","elType":"widget","settings":{"editor":"Enjoy our luscious dishes wherever you want ","align":"center","text_color":"#FFFFFF","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_font_weight":"500","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":18,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":16,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":22,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"38ac398","elType":"widget","settings":{"text":"ORDER NOW","align_mobile":"center","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/contact-us\/","is_external":"","nofollow":"","custom_attributes":""},"align":"center"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"60e1100","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","custom_height":{"unit":"px","size":650,"sizes":[]},"structure":"20","margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"custom_height_mobile":{"unit":"px","size":350,"sizes":[]},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"reverse_order_mobile":"reverse-mobile","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"html_tag":"div"},"elements":[{"id":"1ae36cc","elType":"column","settings":{"_column_size":50,"_inline_size":45,"content_position":"center","padding":{"unit":"px","top":"150","right":"120","bottom":"100","left":"0","isLinked":false},"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"4b6013e","elType":"widget","settings":{"editor":"<p>Our Quality<\/p>","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":25,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"typography_font_size_mobile":{"unit":"px","size":20,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"0cc2dc9","elType":"widget","settings":{"title":"Chicken","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":68,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.8000000000000000444089209850062616169452667236328125,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"c6ea710","elType":"widget","settings":{"editor":"<p>Quality is our #1 ingredient. That\u2019s why our Chicken Wings, Chicken Bites and Grilled Chicken Topping are made from chickens raised without antibiotics and fed an all vegetable-grain diet, with no animal by-products. Plus, our Bites are made with 100% chicken breast meat.<\/p>","align":"left","typography_typography":"custom","typography_line_height":{"unit":"px","size":30,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"cbf0620","elType":"widget","settings":{"text":"ORDER NOW","typography_font_weight":"400","typography_line_height":{"unit":"px","size":20,"sizes":[]},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":"","vertical":0,"blur":10,"spread":0,"color":"rgba(0,0,0,0.5)"},"align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"00fc4ef","elType":"column","settings":{"_column_size":50,"_inline_size":55,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-right","margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"content_position":"center","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-4.png","id":1536},"background_position":"center center","background_repeat":"no-repeat","background_size":"auto","background_size_tablet":"contain","background_size_mobile":"initial","background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","background_motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"space_between_widgets":0,"background_bg_width_mobile":{"unit":"%","size":0,"sizes":[]}},"elements":[{"id":"cffea48","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-5.png","id":1497},"image_size":"full","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"0","isLinked":false},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"space_mobile":{"unit":"px","size":"","sizes":[]},"motion_fx_devices":["desktop","tablet"],"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"27ac1f2","elType":"section","settings":{"gap":"no","custom_height":{"unit":"px","size":650,"sizes":[]},"stretch_section":"section-stretched","structure":"20","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"custom_height_mobile":{"unit":"px","size":350,"sizes":[]},"margin_mobile":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"0985c62","elType":"column","settings":{"_column_size":50,"_inline_size":50,"animation":"opal-move-left","margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"content_position":"center","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-4.png","id":1536},"background_position":"center center","background_repeat":"no-repeat","background_size":"auto","background_size_tablet":"contain","background_size_mobile":"initial","background_motion_fx_translateY_effect":"yes","background_motion_fx_translateY_speed":{"unit":"px","size":"","sizes":[]},"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"space_between_widgets":0,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"background_bg_width_mobile":{"unit":"%","size":0,"sizes":[]}},"elements":[{"id":"33744a5","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-6.png","id":1540},"image_size":"full","motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"align_mobile":"center","space_mobile":{"unit":"%","size":80,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"9583f46","elType":"column","settings":{"_column_size":50,"_inline_size":50,"content_position":"center","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"125","isLinked":false},"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"04878fe","elType":"widget","settings":{"editor":"<p>Our Quaity<\/p>","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":25,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":20,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"8cb3663","elType":"widget","settings":{"title":"Burger","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":68,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":0.8000000000000000444089209850062616169452667236328125,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"7e5f49e","elType":"widget","settings":{"editor":"<p>Some of the world\u2019s best cheese is made close to home! All our deliciously melty Mozzarella is made with 100% Canadian milk. We\u2019re proud to support Canadian dairy farmers.<\/p>","align":"left","typography_typography":"custom","typography_line_height":{"unit":"px","size":30,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"6c96e13","elType":"widget","settings":{"text":"ORDER NOW","typography_font_weight":"400","typography_line_height":{"unit":"px","size":20,"sizes":[]},"align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"12319ab","elType":"section","settings":{"gap":"no","custom_height":{"unit":"px","size":600,"sizes":[]},"stretch_section":"section-stretched","structure":"20","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"custom_height_mobile":{"unit":"px","size":350,"sizes":[]},"reverse_order_mobile":"reverse-mobile","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"html_tag":"div"},"elements":[{"id":"58b987b","elType":"column","settings":{"_column_size":50,"_inline_size":45,"content_position":"center","padding":{"unit":"px","top":"100","right":"120","bottom":"150","left":"0","isLinked":false},"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"ec1acd2","elType":"widget","settings":{"editor":"<p>Our Quaity<\/p>","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":25,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":20,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"51d7f5c","elType":"widget","settings":{"title":"Pizza Douch","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_line_height":{"unit":"px","size":68,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":-0.25,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":42,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.8000000000000000444089209850062616169452667236328125,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"a124c03","elType":"widget","settings":{"editor":"<p>Quality is our #1 ingredient. That\u2019s why our Chicken Wings, Chicken Bites and Grilled Chicken Topping are made from chickens raised without antibiotics and fed an all vegetable-grain diet, with no animal by-products. Plus, our Bites are made with 100% chicken breast meat.<\/p>","align":"left","typography_typography":"custom","typography_line_height":{"unit":"px","size":30,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"f6bc3e0","elType":"widget","settings":{"text":"ORDER NOW","typography_font_weight":"400","typography_line_height":{"unit":"px","size":20,"sizes":[]},"align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"27feb1f","elType":"column","settings":{"_column_size":50,"_inline_size":55,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-right","margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"15","right":"0","bottom":"15","left":"0","isLinked":false},"content_position":"center","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-4.png","id":1536},"background_position":"center center","background_repeat":"no-repeat","background_size":"auto","background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","background_motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"space_between_widgets":0,"background_position_tablet":"center center","background_size_tablet":"contain","background_size_mobile":"initial","background_bg_width_mobile":{"unit":"%","size":0,"sizes":[]}},"elements":[{"id":"bd29427","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/about-imager-7.png","id":1546},"image_size":"full","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"0","isLinked":false},"motion_fx_motion_fx_scrolling":"yes","motion_fx_translateY_effect":"yes","motion_fx_translateY_direction":"negative","motion_fx_translateY_speed":{"unit":"px","size":2,"sizes":[]},"motion_fx_devices":["desktop","tablet"],"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"5d39c94","elType":"section","settings":{"content_width":{"unit":"px","size":1070,"sizes":[]},"gap":"no","height":"min-height","custom_height":{"unit":"px","size":420,"sizes":[]},"stretch_section":"section-stretched","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/bg3-h4.jpg","id":736},"background_repeat":"no-repeat","background_motion_fx_motion_fx_scrolling":"yes","background_motion_fx_translateY_effect":"yes","background_overlay_background":"classic","background_overlay_opacity":{"unit":"px","size":0.59999999999999997779553950749686919152736663818359375,"sizes":[]},"margin":{"unit":"px","top":"30","right":0,"bottom":"80","left":0,"isLinked":false},"__globals__":{"background_overlay_color":"globals\/colors?id=48e5bc8c"},"custom_height_tablet":{"unit":"px","size":380,"sizes":[]},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"animation_duration":"fast","html_tag":"div","padding":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"6c07e8f","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"2e4f063","elType":"widget","settings":{"testimonials":[{"testimonial_icon":"fa fa-quote-left","testimonial_title":"","testimonial_content":"\u201cForget the trendy pizza shops, This hidden spot makes the best New York-style pizza slice in naples\u201d","testimonial_name":"Stephen Tindle","testimonial_job":"CEO,apple","testimonial_rating":"4","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-1.jpg","id":2531},"_id":"c4af6a8"},{"testimonial_title":"","testimonial_content":"\"I would be lost without restaurant. I would like to personally thank you for your outstanding product.\"","testimonial_name":"Nina Margaret ","testimonial_job":"CEO,apple","_id":"362dce0","testimonial_icon":"fa fa-quote-left","testimonial_rating":"5","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-2.jpg","id":2532}},{"testimonial_rating":"4","testimonial_content":"\"I am completely blown away. I would also like to say thank you to all your staff. It\'s really wonderful.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-4.jpg","id":2535},"testimonial_name":"Clara","testimonial_job":"Manager","_id":"4caa9d3"},{"testimonial_rating":"5","testimonial_content":"\"Without food, we would have gone bankrupt by now. Thanks food! The service was excellent.\"","testimonial_name":"John Doe","testimonial_job":"Manager","_id":"2966dc3","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/avatar-3.jpg","id":2534}}],"padding_estimonial_wrapper":{"unit":"%","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"icon_color":"#FFCC00","icon_size":{"unit":"px","size":40,"sizes":[]},"name_text_color":"#FFFFFF","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_text_transform":"uppercase","enable_carousel":"yes","__globals__":{"content_content_color":"globals\/colors?id=26c59e90"},"navigation":"both","_animation":"opal-move-up","animation_duration":"fast","icon_spacing":{"unit":"px","size":0,"sizes":[]},"content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":30,"sizes":[]},"button_color":"#FFFFFF","testimonial_style":"style2","content_typography_font_weight":"normal","name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"name_padding":{"unit":"px","top":"25","right":"0","bottom":"3","left":"0","isLinked":false},"button_color_normal":"#FFFFFF42","padding_estimonial_wrapper_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"content_typography_line_height":{"unit":"px","size":42,"sizes":[]},"content_spacing":{"unit":"px","size":15,"sizes":[]},"image_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"name_typography_line_height":{"unit":"px","size":20,"sizes":[]},"job_text_color":"#FFFFFF","job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":15,"sizes":[]},"content_typography_font_size_mobile":{"unit":"px","size":22,"sizes":[]},"content_typography_line_height_mobile":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"poco-testimonials"}],"isInner":false}],"isInner":false},{"id":"14a6308","elType":"section","settings":{"gap":"no","content_position":"middle","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"30","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"cffd4d8","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"align_mobile":"center","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"5","left":"0","isLinked":false}},"elements":[{"id":"e3ebbc9","elType":"widget","settings":{"editor":"Always Quality","text_color":"#FFC222","typography_typography":"custom","typography_font_family":"Norican","typography_font_size":{"unit":"px","size":25,"sizes":[]},"typography_line_height":{"unit":"px","size":36,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":22,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"align":"center"},"elements":[],"widgetType":"text-editor"},{"id":"48f4cf2","elType":"widget","settings":{"title":"Our Talented Chefs","typography_typography":"custom","typography_font_size":{"unit":"px","size":42,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"__globals__":{"title_color":"globals\/colors?id=accent"},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"align":"center","typography_line_height_mobile":{"unit":"px","size":36,"sizes":[]}},"elements":[],"widgetType":"heading"}],"isInner":false}],"isInner":false},{"id":"74a999d","elType":"section","settings":{"content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","stretch_section":"section-stretched","structure":"30","margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"html_tag":"div","padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"96c7a6a","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","margin_mobile":{"unit":"px","top":"0","right":"15","bottom":"30","left":"15","isLinked":false},"align_mobile":"center"},"elements":[{"id":"25e8af8","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-1-2.jpg","id":353},"name":"william smith","job":"Chef","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false},{"id":"2951a13","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":150,"margin_mobile":{"unit":"px","top":"0","right":"15","bottom":"30","left":"15","isLinked":false},"align_mobile":"center"},"elements":[{"id":"fb0d17e","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-2-1.jpg","id":354},"name":"John Doe","job":"Manager","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false},{"id":"6f14617","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":300,"align_mobile":"center"},"elements":[{"id":"4f5271b","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/08\/box-team-6-1.jpg","id":358},"name":"Bradd L.","job":"Chef","description":"Everything We Pizza, We Pizza With Love. \nDesigner Fastfood.","facebook":"https:\/\/www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","image_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_offset_x":{"unit":"px","size":-25,"sizes":[]},"name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":18,"sizes":[]},"name_typography_line_height":{"unit":"px","size":"","sizes":[]},"name_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14,"sizes":[]},"job_typography_line_height":{"unit":"px","size":"","sizes":[]},"job_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"image_border_radius":{"unit":"px","top":"5","right":"5","bottom":"0","left":"0","isLinked":false},"name_space":{"unit":"px","size":20,"sizes":[]},"job_typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#EBEBEB","__globals__":{"job_text_color":"","color_icon_social":"globals\/colors?id=accent","color_icon_social_hover":"globals\/colors?id=primary"},"name_typography_font_weight":"bold","name_typography_text_transform":"uppercase","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":1,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":"inset","_element_width_mobile":"auto"},"elements":[],"widgetType":"poco-team-box"}],"isInner":false}],"isInner":false},{"id":"9bb0e2d","elType":"section","settings":{"gap":"no","custom_height":{"unit":"px","size":370,"sizes":[]},"stretch_section":"section-stretched","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/poco\/wp-content\/uploads\/2020\/09\/bg3-h3-3.jpg","id":3113},"margin":{"unit":"px","top":"0","right":0,"bottom":"-40","left":0,"isLinked":false},"padding":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"background_xpos_tablet":{"unit":"px","size":-1000,"sizes":[]},"background_repeat":"no-repeat","background_size":"cover","margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"background_color":"#F3F0E7","html_tag":"div","background_position":"center center","height":"min-height","custom_height_tablet":{"unit":"px","size":300,"sizes":[]},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"f7f6023","elType":"column","settings":{"_column_size":100,"_inline_size":null,"padding_mobile":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false},"space_between_widgets":0,"space_between_widgets_mobile":0,"align":"center"},"elements":[{"id":"71480f2","elType":"widget","settings":{"editor":"<p>We guarantee<\/p>","align":"center","text_color":"#FFC222","typography_typography":"custom","typography_font_size":{"unit":"px","size":32,"sizes":[]},"typography_line_height":{"unit":"px","size":30,"sizes":[]},"typography_font_family":"Norican","_animation":"fadeInUp","animation_duration":"fast","typography_font_size_tablet":{"unit":"px","size":28,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"typography_font_size_mobile":{"unit":"px","size":24,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"5","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"377a0ca","elType":"widget","settings":{"title":"30 Minutes Delivery!","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_line_height":{"unit":"px","size":70,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"fadeInUp","__globals__":{"title_color":"globals\/colors?id=accent"},"typography_font_size_mobile":{"unit":"px","size":28,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation_duration":"fast","typography_font_size_tablet":{"unit":"px","size":36,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":48,"sizes":[]},"typography_letter_spacing_mobile":{"unit":"px","size":-0.8000000000000000444089209850062616169452667236328125,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"8cb2306","elType":"widget","settings":{"editor":"If you\'re having a meeting, working late at night and need an extra push. Let us know and we will be there","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"fadeInUp","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation_duration":"fast","_element_width":"initial","_element_width_tablet":"initial","_element_custom_width":{"unit":"px","size":510,"sizes":[]},"_element_custom_width_tablet":{"unit":"px","size":450,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"feb54e1","elType":"widget","settings":{"text":"make an order","align":"center","typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":20,"sizes":[]},"_animation":"fadeInUp","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"default-kit":[]}', true);
	}
}

return new Poco_Merlin_Config();
